# Copyright (c) 2023 Darren Erik Vengroff
"""Places in West Virginia."""


ACCOVILLE_CDP = "00196"
ADDISON_WEBSTER_SPRINGS_TOWN = "00364"
ADRIAN_CDP = "00460"
ALBRIGHT_TOWN = "00748"
ALDERSON_TOWN = "00772"
ALUM_CREEK_CDP = "01396"
AMHERSTDALE_CDP = "01660"
ANAWALT_TOWN = "01780"
ANMOORE_TOWN = "01900"
ANSTED_TOWN = "01996"
APPLE_GROVE_CDP = "02188"
ARBOVALE_CDP = "02260"
ARTHURDALE_CDP = "02908"
ATHENS_TOWN = "03292"
AUBURN_TOWN = "03364"
AURORA_CDP = "03460"
BANCROFT_TOWN = "04204"
BARBOURSVILLE_VILLAGE = "04276"
BARRACKVILLE_TOWN = "04612"
BARTLEY_CDP = "04732"
BARTOW_CDP = "04780"
BATH_BERKELEY_SPRINGS_TOWN = "04876"
BAXTER_CDP = "04900"
BAYARD_TOWN = "04924"
BEARDS_FORK_CDP = "05068"
BEAVER_CDP = "05260"
BECKLEY_CITY = "05332"
BEECH_BOTTOM_VILLAGE = "05452"
BELINGTON_TOWN = "05788"
BELLE_TOWN = "05836"
BELMONT_CITY = "06004"
BELVA_CDP = "06052"
BENWOOD_CITY = "06340"
BERGOO_CDP = "06436"
BERWIND_CDP = "06748"
BETHANY_TOWN = "06844"
BETHLEHEM_VILLAGE = "06940"
BEVERLY_TOWN = "06988"
BIG_CHIMNEY_CDP = "07204"
BIG_CREEK_CDP = "07228"
BIG_SANDY_CDP = "07516"
BIRCH_RIVER_CDP = "07756"
BLACKSVILLE_TOWN = "08092"
BLENNERHASSETT_CDP = "08308"
BLUEFIELD_CITY = "08524"
BLUEWELL_CDP = "08764"
BOAZ_CDP = "08836"
BOLIVAR_TOWN = "08932"
BOLT_CDP = "08956"
BOOMER_CDP = "09100"
BOOTH_CDP = "09148"
BOWDEN_CDP = "09364"
BRADLEY_CDP = "09676"
BRADSHAW_TOWN = "09700"
BRAMWELL_TOWN = "09796"
BRANDONVILLE_TOWN = "09844"
BRANDYWINE_CDP = "09868"
BRENTON_CDP = "09964"
BRIDGEPORT_CITY = "10180"
BROOKHAVEN_CDP = "10420"
BRUCETON_MILLS_TOWN = "10852"
BRUNO_CDP = "10876"
BRUSH_FORK_CDP = "10948"
BUCKHANNON_CITY = "11188"
BUD_CDP = "11212"
BUFFALO_TOWN = "11284"
BURLINGTON_CDP = "11620"
BURNSVILLE_TOWN = "11716"
CAIRO_TOWN = "12124"
CAMDEN_ON_GAULEY_TOWN = "12436"
CAMERON_CITY = "12484"
CAPON_BRIDGE_TOWN = "13108"
CAROLINA_CDP = "13468"
CARPENDALE_TOWN = "13525"
CASS_CDP = "13684"
CASSVILLE_CDP = "13756"
CEDAR_GROVE_TOWN = "13924"
CENTURY_CDP = "14212"
CEREDO_CITY = "14308"
CHAPMANVILLE_TOWN = "14524"
CHARLES_TOWN_CITY = "14610"
CHARLESTON_CITY = "14600"
CHARLTON_HEIGHTS_CDP = "14630"
CHATTAROY_CDP = "14692"
CHAUNCEY_CDP = "14716"
CHEAT_LAKE_CDP = "14775"
CHELYAN_CDP = "14812"
CHESAPEAKE_TOWN = "15028"
CHESTER_CITY = "15076"
CLARKSBURG_CITY = "15628"
CLAY_TOWN = "15676"
CLEARVIEW_VILLAGE = "15916"
CLENDENIN_TOWN = "16012"
CLIFTON_CDP = "16132"
COAL_CITY_CDP = "16516"
COAL_FORK_CDP = "16612"
COLCORD_CDP = "16972"
COLLIERS_CDP = "17140"
COMFORT_CDP = "17380"
CORINNE_CDP = "17836"
COTTAGEVILLE_CDP = "18124"
COVEL_CDP = "18388"
COWEN_TOWN = "18412"
CRAB_ORCHARD_CDP = "18508"
CRAIGSVILLE_CDP = "18604"
CROOKED_CREEK_CDP = "19060"
CROSS_LANES_CDP = "19108"
CRUM_CDP = "19300"
CRUMPLER_CDP = "19324"
CUCUMBER_CDP = "19492"
CULLODEN_CDP = "19516"
CUNARD_CDP = "19588"
DAILEY_CDP = "19948"
DANIELS_CDP = "20164"
DANVILLE_TOWN = "20212"
DAVIS_TOWN = "20428"
DAVY_TOWN = "20500"
DEEP_WATER_CDP = "20764"
DELBARTON_TOWN = "20980"
DESPARD_CDP = "21316"
DIXIE_CDP = "21628"
DOROTHY_CDP = "21964"
DUNBAR_CITY = "22564"
DUPONT_CITY_CDP = "22828"
DURBIN_TOWN = "22852"
EARLING_CDP = "23020"
EAST_BANK_TOWN = "23092"
EAST_DAILEY_CDP = "23140"
EAST_VIEW_CDP = "23524"
ECCLES_CDP = "23644"
ELEANOR_TOWN = "24292"
ELIZABETH_TOWN = "24364"
ELK_GARDEN_TOWN = "24484"
ELKINS_CITY = "24580"
ELKVIEW_CDP = "24748"
ELLENBORO_TOWN = "24844"
ENTERPRISE_CDP = "25516"
ESKDALE_CDP = "25732"
FAIRLEA_CDP = "26428"
FAIRMONT_CITY = "26452"
FAIRVIEW_TOWN = "26524"
FALLING_SPRING_TOWN = "26692"
FALLING_WATERS_CDP = "26716"
FALLS_VIEW_CDP = "26812"
FARMINGTON_TOWN = "26932"
FAYETTEVILLE_TOWN = "27028"
FENWICK_CDP = "27196"
FLATWOODS_TOWN = "27868"
FLEMINGTON_TOWN = "27940"
FOLLANSBEE_CITY = "28204"
FORT_ASHBY_CDP = "28444"
FORT_GAY_TOWN = "28516"
FRANK_CDP = "28948"
FRANKLIN_TOWN = "29044"
FRIENDLY_TOWN = "29404"
GALLIPOLIS_FERRY_CDP = "29716"
GALLOWAY_CDP = "29740"
GARTEN_CDP = "30148"
GARY_CITY = "30196"
GASSAWAY_TOWN = "30220"
GATEWOOD_CDP = "30316"
GAULEY_BRIDGE_TOWN = "30364"
GHENT_CDP = "30724"
GILBERT_CREEK_CDP = "30777"
GILBERT_TOWN = "30772"
GLASGOW_TOWN = "31324"
GLEN_DALE_CITY = "31492"
GLEN_FERRIS_CDP = "31732"
GLEN_FORK_CDP = "31756"
GLEN_JEAN_CDP = "31876"
GLEN_WHITE_CDP = "32068"
GLENVILLE_TOWN = "32044"
GRAFTON_CITY = "32716"
GRANT_TOWN_TOWN = "32908"
GRANTSVILLE_TOWN = "32884"
GRANVILLE_TOWN = "32932"
GREAT_CACAPON_CDP = "33100"
GREEN_BANK_CDP = "33124"
GREEN_SPRING_CDP = "33436"
GREENVIEW_CDP = "33580"
GREENVILLE_CDP = "33604"
GYPSY_CDP = "34180"
HAMBLETON_TOWN = "34492"
HAMLIN_TOWN = "34516"
HANDLEY_TOWN = "34756"
HANSFORD_CDP = "34852"
HARMAN_TOWN = "35092"
HARPERS_FERRY_TOWN = "35284"
HARRISVILLE_TOWN = "35428"
HARTFORD_CITY_TOWN = "35500"
HARTS_CDP = "35596"
HEDGESVILLE_TOWN = "36220"
HELEN_CDP = "36292"
HELVETIA_CDP = "36340"
HENDERSON_TOWN = "36436"
HENDRICKS_TOWN = "36460"
HENLAWSON_CDP = "36484"
HEPZIBAH_CDP = "36628"
HICO_CDP = "37036"
HILLSBORO_TOWN = "37372"
HILLTOP_CDP = "37444"
HINKLEVILLE_CDP = "37612"
HINTON_CITY = "37636"
HOLDEN_CDP = "37948"
HOLLYGROVE_CDP = "38092"
HOMETOWN_CDP = "38260"
HOOVERSON_HEIGHTS_CDP = "38476"
HUNDRED_TOWN = "39340"
HUNTERSVILLE_CDP = "39412"
HUNTINGTON_CITY = "39460"
HURRICANE_CITY = "39532"
HUTTONSVILLE_TOWN = "39628"
IAEGER_TOWN = "39652"
IDAMAY_CDP = "39676"
INSTITUTE_CDP = "40156"
INWOOD_CDP = "40204"
ITMANN_CDP = "40444"
JACKSONBURG_CDP = "40636"
JANE_LEW_TOWN = "40828"
JEFFERSON_CDP = "41010"
JUNIOR_TOWN = "42244"
JUSTICE_ADDITION_CDP = "42316"
JUSTICE_CDP = "42292"
KANAWHA_CDP = "42388"
KENOVA_CITY = "43180"
KERMIT_TOWN = "43300"
KEYSER_CITY = "43492"
KEYSTONE_CITY = "43516"
KIMBALL_TOWN = "43780"
KIMBERLY_CDP = "43828"
KINCAID_CDP = "43852"
KINGWOOD_CITY = "44044"
KISTLER_CDP = "44188"
KOPPERSTON_CDP = "44548"
LASHMEET_CDP = "45292"
LAVALETTE_CDP = "45580"
LEON_TOWN = "46300"
LESAGE_CDP = "46420"
LESTER_TOWN = "46468"
LEWISBURG_CITY = "46636"
LITTLETON_CDP = "47788"
LOGAN_CITY = "48148"
LOST_CREEK_TOWN = "48748"
LUBECK_CDP = "49156"
LUMBERPORT_TOWN = "49252"
MABSCOTT_TOWN = "49492"
MACARTHUR_CDP = "49564"
MADISON_CITY = "50524"
MALDEN_CDP = "50836"
MALLORY_CDP = "50860"
MAN_TOWN = "50932"
MANNINGTON_CITY = "51100"
MARLINTON_TOWN = "51676"
MARMET_CITY = "51724"
MARTINSBURG_CITY = "52060"
MASON_TOWN = "52180"
MASONTOWN_TOWN = "52228"
MATEWAN_TOWN = "52324"
MATHENY_CDP = "52372"
MATOAKA_TOWN = "52420"
MAYBEURY_CDP = "52588"
MCCONNELL_CDP = "49732"
MCMECHEN_CITY = "50260"
MEADOW_BRIDGE_TOWN = "52780"
MIDDLEBOURNE_TOWN = "53572"
MIDDLEWAY_CDP = "53692"
MILL_CREEK_TOWN = "54100"
MILTON_TOWN = "54484"
MINERALWELLS_CDP = "54580"
MITCHELL_HEIGHTS_TOWN = "54892"
MONAVILLE_CDP = "55132"
MONONGAH_TOWN = "55276"
MONTCALM_CDP = "55372"
MONTGOMERY_CITY = "55468"
MONTROSE_TOWN = "55540"
MOOREFIELD_TOWN = "55588"
MORGANTOWN_CITY = "55756"
MOUNDSVILLE_CITY = "56020"
MOUNT_CARBON_CDP = "56212"
MOUNT_GAY_SHAMROCK_CDP = "56342"
MOUNT_HOPE_CITY = "56404"
MULLENS_CITY = "57148"
NEIBERT_CDP = "57916"
NETTIE_CDP = "58180"
NEW_CUMBERLAND_CITY = "58372"
NEW_HAVEN_TOWN = "58564"
NEW_MARTINSVILLE_CITY = "58684"
NEW_RICHMOND_CDP = "58756"
NEWARK_CDP = "58252"
NEWBURG_TOWN = "58300"
NEWELL_CDP = "58420"
NITRO_CITY = "59068"
NORTH_HILLS_TOWN = "59458"
NORTHFORK_TOWN = "59428"
NORTON_CDP = "59668"
NUTTER_FORT_TOWN = "59836"
OAK_HILL_CITY = "60028"
OAKVALE_TOWN = "60196"
OCEANA_TOWN = "60364"
OMAR_CDP = "60628"
OSAGE_CDP = "61180"
PADEN_CITY_CITY = "61636"
PAGE_CDP = "61660"
PAGETON_CDP = "61684"
PARCOAL_CDP = "62044"
PARKERSBURG_CITY = "62140"
PARSONS_CITY = "62284"
PAW_PAW_TOWN = "62332"
PAX_TOWN = "62356"
PEA_RIDGE_CDP = "62488"
PEACH_CREEK_CDP = "62428"
PENNSBORO_CITY = "62764"
PENTRESS_CDP = "62788"
PETERSBURG_CITY = "62956"
PETERSTOWN_TOWN = "63052"
PHILIPPI_CITY = "63292"
PICKENS_CDP = "63484"
PIEDMONT_TOWN = "63604"
PINCH_CDP = "63772"
PINE_GROVE_TOWN = "63892"
PINEVILLE_TOWN = "63940"
PINEY_VIEW_CDP = "63988"
PLEASANT_VALLEY_CITY = "64228"
POCA_TOWN = "64516"
POINT_PLEASANT_CITY = "64708"
POWELLTON_CDP = "65284"
PRATT_TOWN = "65356"
PRICHARD_CDP = "65596"
PRINCE_CDP = "65668"
PRINCETON_CITY = "65692"
PROSPERITY_CDP = "65836"
PULLMAN_TOWN = "65956"
QUINWOOD_TOWN = "66412"
RACHEL_CDP = "66460"
RACINE_CDP = "66484"
RAINELLE_TOWN = "66652"
RALEIGH_CDP = "66748"
RAND_CDP = "66892"
RANSON_CORPORATION = "66988"
RAVENSWOOD_CITY = "67108"
RAYMOND_CITY_CDP = "67204"
RAYSAL_CDP = "67228"
READER_CDP = "67252"
RED_JACKET_CDP = "67396"
REEDSVILLE_TOWN = "67636"
REEDY_TOWN = "67660"
REYNOLDSVILLE_CDP = "67972"
RHODELL_TOWN = "67996"
RICHWOOD_CITY = "68116"
RIDGELEY_TOWN = "68260"
RIPLEY_CITY = "68596"
RIVESVILLE_TOWN = "68908"
ROBINETTE_CDP = "69100"
ROCK_CAVE_CDP = "69244"
RODERFIELD_CDP = "69844"
ROMNEY_CITY = "70084"
RONCEVERTE_CITY = "70156"
ROSSMORE_CDP = "70468"
ROWLESBURG_TOWN = "70588"
RUPERT_TOWN = "70828"
SALEM_CITY = "71380"
SALT_ROCK_CDP = "71476"
SAND_FORK_TOWN = "71620"
SARAH_ANN_CDP = "72004"
SCARBRO_CDP = "72292"
SHADY_SPRING_CDP = "73108"
SHANNONDALE_CDP = "73252"
SHENANDOAH_JUNCTION_CDP = "73444"
SHEPHERDSTOWN_TOWN = "73468"
SHINNSTON_CITY = "73636"
SHREWSBURY_CDP = "73876"
SISSONVILLE_CDP = "74356"
SISTERSVILLE_CITY = "74380"
SMITHERS_CITY = "74740"
SMITHFIELD_TOWN = "74788"
SOPHIA_TOWN = "75172"
SOUTH_CHARLESTON_CITY = "75292"
SPELTER_CDP = "75796"
SPENCER_CITY = "75820"
SPRAGUE_CDP = "75868"
SPRINGFIELD_CDP = "76084"
ST_ALBANS_CITY = "71212"
ST_GEORGE_CDP = "71284"
ST_MARYS_CITY = "71356"
STANAFORD_CDP = "76444"
STAR_CITY_TOWN = "76516"
STOLLINGS_CDP = "76996"
STONEWOOD_CITY = "77188"
SUMMERSVILLE_CITY = "77980"
SUTTON_TOWN = "78580"
SWITZER_CDP = "78796"
SYLVESTER_TOWN = "78964"
TEAYS_VALLEY_CDP = "79545"
TERRA_ALTA_TOWN = "79708"
THOMAS_CITY = "80020"
THURMOND_TOWN = "80284"
TIOGA_CDP = "80476"
TORNADO_CDP = "80764"
TRIADELPHIA_TOWN = "80932"
TUNNELTON_TOWN = "81268"
TWILIGHT_CDP = "81484"
UNION_TOWN = "81940"
VALLEY_BEND_CDP = "82564"
VALLEY_GROVE_VILLAGE = "82732"
VALLEY_HEAD_CDP = "82756"
VAN_CDP = "82852"
VERDUNVILLE_CDP = "83332"
VIENNA_CITY = "83500"
VIVIAN_CDP = "83764"
WALLACE_CDP = "84172"
WAR_CITY = "84484"
WARDENSVILLE_TOWN = "84580"
WASHINGTON_CDP = "84724"
WAVERLY_CDP = "84916"
WAYNE_TOWN = "84940"
WEIRTON_CITY = "85156"
WELCH_CITY = "85228"
WELLSBURG_CITY = "85324"
WEST_DUNBAR_CDP = "85636"
WEST_HAMLIN_TOWN = "85804"
WEST_LIBERTY_TOWN = "85876"
WEST_LOGAN_TOWN = "85900"
WEST_MILFORD_TOWN = "85924"
WEST_UNION_TOWN = "86116"
WESTON_CITY = "85972"
WESTOVER_CITY = "85996"
WHEELING_CITY = "86452"
WHITE_HALL_TOWN = "86620"
WHITE_SULPHUR_SPRINGS_CITY = "86812"
WHITESVILLE_TOWN = "86836"
WHITMER_CDP = "86932"
WILEY_FORD_CDP = "87316"
WILLIAMSON_CITY = "87508"
WILLIAMSTOWN_CITY = "87556"
WINDSOR_HEIGHTS_VILLAGE = "87892"
WINFIELD_TOWN = "87988"
WOLF_SUMMIT_CDP = "88276"
WOMELSDORF_COALTON_TOWN = "88324"
WORTHINGTON_TOWN = "88708"
