# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Virginia."""


ABBS_VALLEY_CDP = "00110"
ABINGDON_TOWN = "00148"
ACCOMAC_TOWN = "00180"
ADWOLF_CDP = "00468"
AFTON_CDP = "00484"
ALBERTA_TOWN = "00724"
ALDIE_CDP = "00772"
ALEXANDRIA_CITY = "01000"
ALLISON_GAP_CDP = "01240"
ALLISONIA_CDP = "01256"
ALTAVISTA_TOWN = "01528"
AMELIA_COURT_HOUSE_CDP = "01640"
AMHERST_TOWN = "01672"
AMONATE_CDP = "01752"
ANNANDALE_CDP = "01912"
APPALACHIA_TOWN = "02040"
APPLE_MOUNTAIN_LAKE_CDP = "02064"
APPOMATTOX_TOWN = "02072"
AQUIA_HARBOUR_CDP = "02112"
ARCOLA_CDP = "02248"
ARLINGTON_CDP = "03000"
ARRINGTON_CDP = "03208"
ASHBURN_CDP = "03320"
ASHLAND_TOWN = "03368"
ATKINS_CDP = "03512"
ATLANTIC_CDP = "03528"
AUGUSTA_SPRINGS_CDP = "03608"
AUSTINVILLE_CDP = "03656"
BAILEYS_CROSSROADS_CDP = "04088"
BARBOURSVILLE_CDP = "04392"
BASKERVILLE_CDP = "04856"
BASSETT_CDP = "04872"
BASTIAN_CDP = "04904"
BASYE_CDP = "04920"
BAYSIDE_CDP = "05200"
BAYWOOD_CDP = "05256"
BEALETON_CDP = "05336"
BEDFORD_TOWN = "05544"
BELLE_HAVEN_CDP = "05928"
BELLE_HAVEN_TOWN = "05912"
BELLWOOD_CDP = "06216"
BELMONT_CDP = "06275"
BELMONT_ESTATES_CDP = "06336"
BELSPRING_CDP = "06424"
BELVIEW_CDP = "06512"
BENNS_CHURCH_CDP = "06712"
BENSLEY_CDP = "06728"
BERRYVILLE_TOWN = "06968"
BETHEL_MANOR_CDP = "07160"
BIG_ISLAND_CDP = "07400"
BIG_ROCK_CDP = "07448"
BIG_STONE_GAP_EAST_CDP = "07484"
BIG_STONE_GAP_TOWN = "07480"
BLACKSBURG_TOWN = "07784"
BLACKSTONE_TOWN = "07832"
BLAIRS_CDP = "07944"
BLAND_CDP = "07976"
BLOXOM_TOWN = "08120"
BLUE_RIDGE_CDP = "08200"
BLUE_RIDGE_SHORES_CDP = "08264"
BLUEFIELD_TOWN = "08152"
BOBTOWN_CDP = "08320"
BOISSEVAIN_CDP = "08376"
BON_AIR_CDP = "08472"
BOONES_MILL_TOWN = "08584"
BOSTON_CDP = "08675"
BOSWELLS_CORNER_CDP = "08708"
BOWLING_GREEN_TOWN = "08888"
BOYCE_TOWN = "08984"
BOYDTON_TOWN = "09016"
BOYKINS_TOWN = "09032"
BRACEY_CDP = "09064"
BRADDOCK_CDP = "09072"
BRAMBLETON_CDP = "09188"
BRANCHVILLE_TOWN = "09208"
BRANDERMILL_CDP = "09248"
BRANDY_STATION_CDP = "09352"
BREAKS_CDP = "09400"
BRIDGEWATER_TOWN = "09656"
BRIGHTWOOD_CDP = "09752"
BRISTOL_CITY = "09816"
BROADLANDS_CDP = "09952"
BROADWAY_TOWN = "10040"
BRODNAX_TOWN = "10072"
BROOKNEAL_TOWN = "10296"
BRUCETOWN_CDP = "10568"
BUCHANAN_TOWN = "10744"
BUCKHALL_CDP = "10776"
BUCKINGHAM_COURTHOUSE_CDP = "10856"
BUENA_VISTA_CITY = "11032"
BULL_RUN_CDP_FAIRFAX_COUNTY = "11224"
BULL_RUN_CDP_PRINCE_WILLIAM_COUNTY = "11230"
BULL_RUN_MOUNTAIN_ESTATES_CDP = "11245"
BURKE_CDP = "11464"
BURKE_CENTRE_CDP = "11470"
BURKEVILLE_TOWN = "11560"
CALLAGHAN_CDP = "12136"
CALVERTON_CDP = "12264"
CAMP_BARRETT_CDP = "12472"
CAMPTOWN_CDP = "12590"
CANA_CDP = "12600"
CAPE_CHARLES_TOWN = "12808"
CAPRON_TOWN = "12904"
CAPTAINS_COVE_CDP = "12915"
CARROLLTON_CDP = "13160"
CARRSVILLE_CDP = "13192"
CASCADES_CDP = "13403"
CASTLEWOOD_CDP = "13512"
CATLETT_CDP = "13624"
CATS_BRIDGE_CDP = "13635"
CAVE_SPRING_CDP = "13720"
CEDAR_BLUFF_TOWN = "13784"
CENTRAL_GARAGE_CDP = "14312"
CENTREVILLE_CDP = "14440"
CHAMBERLAYNE_CDP = "14544"
CHANTILLY_CDP = "14744"
CHARLES_CITY_CDP = "14904"
CHARLOTTE_COURT_HOUSE_TOWN = "14952"
CHARLOTTESVILLE_CITY = "14968"
CHASE_CITY_TOWN = "14984"
CHASE_CROSSING_CDP = "14995"
CHATHAM_TOWN = "15000"
CHATMOSS_CDP = "15048"
CHERITON_TOWN = "15112"
CHERRY_HILL_CDP = "15176"
CHESAPEAKE_CITY = "16000"
CHESTER_CDP = "16096"
CHESTER_GAP_CDP = "16240"
CHILHOWIE_TOWN = "16480"
CHINCOTEAGUE_TOWN = "16512"
CHRISTIANSBURG_TOWN = "16608"
CHURCHVILLE_CDP = "16736"
CLAREMONT_TOWN = "16880"
CLARKSVILLE_TOWN = "16992"
CLAYPOOL_HILL_CDP = "17120"
CLEVELAND_TOWN = "17296"
CLIFTON_FORGE_TOWN = "17440"
CLIFTON_TOWN = "17376"
CLIFTONDALE_PARK_CDP = "17424"
CLINCHCO_TOWN = "17504"
CLINCHPORT_TOWN = "17536"
CLINTWOOD_TOWN = "17552"
CLOVER_CDP = "17632"
CLOVERDALE_CDP = "17680"
CLUSTER_SPRINGS_CDP = "17776"
COEBURN_TOWN = "17952"
COLLINSVILLE_CDP = "18352"
COLONIAL_BEACH_TOWN = "18400"
COLONIAL_HEIGHTS_CITY = "18448"
COLUMBIA_CDP = "18624"
CONCORD_CDP = "18880"
COUNTRYSIDE_CDP = "19560"
COUNTY_CENTER_CDP = "19571"
COURTLAND_TOWN = "19600"
COVINGTON_CITY = "19728"
CRAIGSVILLE_TOWN = "19904"
CREWE_TOWN = "20160"
CRIMORA_CDP = "20240"
CROSSPOINTE_CDP = "20436"
CROZET_CDP = "20560"
CULPEPER_TOWN = "20752"
CUMBERLAND_CDP = "20768"
DAHLGREN_CDP = "21008"
DAHLGREN_CENTER_CDP = "21016"
DALE_CITY_CDP = "21088"
DALEVILLE_CDP = "21152"
DAMASCUS_TOWN = "21184"
DANTE_CDP = "21312"
DANVILLE_CITY = "21344"
DAYTON_TOWN = "21648"
DEEP_CREEK_CDP = "21776"
DEERFIELD_CDP = "21872"
DELTAVILLE_CDP = "22064"
DENDRON_TOWN = "22160"
DIFFICULT_RUN_CDP = "22472"
DILLWYN_TOWN = "22560"
DINWIDDIE_CDP = "22576"
DISPUTANTA_CDP = "22640"
DOOMS_CDP = "22976"
DORAN_CDP = "23008"
DRAKES_BRANCH_TOWN = "23376"
DRANESVILLE_CDP = "23392"
DRAPER_CDP = "23408"
DRYDEN_CDP = "23584"
DUBLIN_TOWN = "23648"
DUFFIELD_TOWN = "23680"
DULLES_TOWN_CENTER_CDP = "23732"
DUMBARTON_CDP = "23744"
DUMFRIES_TOWN = "23760"
DUNBAR_CDP = "23776"
DUNGANNON_TOWN = "23952"
DUNN_LORING_CDP = "23984"
EAGLE_ROCK_CDP = "24208"
EARLYSVILLE_CDP = "24272"
EAST_HIGHLAND_PARK_CDP = "24496"
EAST_LEXINGTON_CDP = "24544"
EAST_STONE_GAP_CDP = "24720"
EASTVILLE_TOWN = "24752"
EBONY_CDP = "24816"
EDINBURG_TOWN = "25008"
EGGLESTON_CDP = "25136"
ELKTON_TOWN = "25408"
ELLISTON_CDP = "25488"
EMORY_CDP = "25792"
EMPORIA_CITY = "25808"
ENON_CDP = "25877"
ESMONT_CDP = "25968"
ETTRICK_CDP = "26128"
EWING_CDP = "26384"
EXMORE_TOWN = "26416"
FAIR_LAKES_CDP = "26701"
FAIR_OAKS_CDP = "26875"
FAIRFAX_STATION_CDP = "26592"
FAIRFAX_CITY = "26496"
FAIRFIELD_CDP = "26656"
FAIRLAWN_CDP = "26736"
FAIRVIEW_BEACH_CDP = "27040"
FAIRVIEW_CDP = "26944"
FALLS_CHURCH_CITY = "27200"
FALLS_MILLS_CDP = "27232"
FALMOUTH_CDP = "27264"
FANCY_GAP_CDP = "27296"
FARMVILLE_TOWN = "27440"
FERRUM_CDP = "27712"
FIELDALE_CDP = "27744"
FINCASTLE_TOWN = "27824"
FISHERSVILLE_CDP = "27968"
FLINT_HILL_CDP = "28496"
FLORIS_CDP = "28528"
FLOYD_TOWN = "28544"
FOREST_CDP = "28688"
FORT_BELVOIR_CDP = "29008"
FORT_CHISWELL_CDP = "29040"
FORT_HUNT_CDP = "29136"
FORT_LEE_CDP = "29152"
FRANCONIA_CDP = "29552"
FRANKLIN_FARM_CDP = "29628"
FRANKLIN_CITY = "29600"
FRANKTOWN_CDP = "29712"
FREDERICKSBURG_CITY = "29744"
FREE_UNION_CDP = "29840"
FRIES_TOWN = "29920"
FRONT_ROYAL_TOWN = "29968"
GAINESVILLE_CDP = "30176"
GALAX_CITY = "30208"
GARGATHA_CDP = "30384"
GASBURG_CDP = "30480"
GATE_CITY_TOWN = "30496"
GEORGE_MASON_CDP = "30618"
GLADE_SPRING_TOWN = "31056"
GLASGOW_TOWN = "31136"
GLEN_ALLEN_CDP = "31200"
GLEN_LYN_TOWN = "31376"
GLEN_WILTON_CDP = "31504"
GLENVAR_CDP = "31488"
GLOUCESTER_COURTHOUSE_CDP = "31608"
GLOUCESTER_POINT_CDP = "31616"
GOOCHLAND_CDP = "31808"
GOOSE_CREEK_VILLAGE_CDP = "31912"
GORDONSVILLE_TOWN = "31936"
GORE_CDP = "31952"
GOSHEN_TOWN = "31968"
GRATTON_CDP = "32320"
GREAT_FALLS_CDP = "32496"
GREAT_FALLS_CROSSING_CDP = "32498"
GREENBACKVILLE_CDP = "32560"
GREENBRIAR_CDP = "32592"
GREENBUSH_CDP = "32624"
GREENVILLE_CDP = "32944"
GRETNA_TOWN = "33232"
GROTTOES_TOWN = "33488"
GROVETON_CDP = "33584"
GRUNDY_TOWN = "33648"
GWYNN_CDP = "33824"
HALIFAX_TOWN = "34064"
HALLWOOD_TOWN = "34176"
HAMILTON_TOWN = "34240"
HAMPDEN_SYDNEY_CDP = "34304"
HAMPTON_CITY = "35000"
HANOVER_CDP = "35160"
HARBORTON_CDP = "35240"
HARRISONBURG_CITY = "35624"
HARRISTON_CDP = "35640"
HAYFIELD_CDP = "35912"
HAYMARKET_TOWN = "35976"
HAYSI_TOWN = "36008"
HEATHSVILLE_CDP = "36216"
HENRY_FORK_CDP = "36445"
HERNDON_TOWN = "36648"
HIGHLAND_SPRINGS_CDP = "37032"
HILLSBORO_TOWN = "37288"
HILLSVILLE_TOWN = "37336"
HILLTOWN_CDP = "37380"
HILTONS_CDP = "37432"
HIWASSEE_CDP = "37544"
HOLLINS_CDP = "37880"
HOLLYMEAD_CDP = "38032"
HONAKER_TOWN = "38280"
HOPEWELL_CITY = "38424"
HORNTOWN_CDP = "38504"
HORSE_PASTURE_CDP = "38552"
HOT_SPRINGS_CDP = "38632"
HUNTINGTON_CDP = "39064"
HURT_TOWN = "39224"
HUTCHISON_CDP = "39259"
HYBLA_VALLEY_CDP = "39304"
IDYLWOOD_CDP = "39448"
INDEPENDENCE_TOWN = "39528"
INDEPENDENT_HILL_CDP = "39544"
INNOVATION_CDP = "39916"
INNSBROOK_CDP = "39920"
IRON_GATE_TOWN = "40024"
IRVINGTON_TOWN = "40088"
IVANHOE_CDP = "40216"
IVOR_TOWN = "40232"
IVY_CDP = "40248"
JARRATT_TOWN = "40536"
JEWELL_RIDGE_CDP = "41016"
JOLIVUE_CDP = "41144"
JONESVILLE_TOWN = "41272"
KEEZLETOWN_CDP = "41624"
KELLER_TOWN = "41656"
KENBRIDGE_TOWN = "41832"
KEOKEE_CDP = "42104"
KESWICK_CDP = "42216"
KEYSVILLE_TOWN = "42264"
KILMARNOCK_TOWN = "42424"
KINCORA_CDP = "42501"
KING_GEORGE_CDP = "42568"
KING_WILLIAM_CDP = "42792"
KING_AND_QUEEN_COURT_HOUSE_CDP = "42536"
KINGS_PARK_CDP = "42664"
KINGS_PARK_WEST_CDP = "42680"
KINGSTOWNE_CDP = "42746"
LA_CROSSE_TOWN = "43176"
LAFAYETTE_CDP = "43224"
LAKE_BARCROFT_CDP = "43352"
LAKE_CAROLINE_CDP = "43359"
LAKE_HOLIDAY_CDP = "43392"
LAKE_LANDOR_CDP = "43420"
LAKE_MONTICELLO_CDP = "43424"
LAKE_RIDGE_CDP = "43432"
LAKE_WILDERNESS_CDP = "43600"
LAKE_OF_THE_WOODS_CDP = "43430"
LAKESIDE_CDP = "43464"
LANCASTER_CDP = "43704"
LANSDOWNE_CDP = "44048"
LAUREL_CDP = "44280"
LAUREL_HILL_CDP = "44430"
LAUREL_PARK_CDP = "44476"
LAWRENCEVILLE_TOWN = "44520"
LAYMANTOWN_CDP = "44620"
LEBANON_TOWN = "44696"
LEE_MONT_CDP = "44952"
LEESBURG_TOWN = "44984"
LEESYLVANIA_CDP = "45008"
LEXINGTON_CITY = "45512"
LINCOLNIA_CDP = "45784"
LINTON_HALL_CDP = "45957"
LINVILLE_CDP = "45960"
LOCH_LOMOND_CDP = "46328"
LOCUST_MOUNT_CDP = "46456"
LONG_BRANCH_CDP = "46760"
LORTON_CDP = "47064"
LOUDOUN_VALLEY_ESTATES_CDP = "47136"
LOUISA_TOWN = "47144"
LOVETTSVILLE_TOWN = "47208"
LOVINGSTON_CDP = "47224"
LOW_MOOR_CDP = "47352"
LOWES_ISLAND_CDP = "47296"
LUNENBURG_CDP = "47496"
LURAY_TOWN = "47528"
LYNCHBURG_CITY = "47672"
LYNDHURST_CDP = "47720"
MADISON_HEIGHTS_CDP = "48520"
MADISON_TOWN = "48488"
MAKEMIE_PARK_CDP = "48776"
MALLOW_CDP = "48856"
MANASSAS_PARK_CITY = "48968"
MANASSAS_CITY = "48952"
MANCHESTER_CDP = "48996"
MANTUA_CDP = "49144"
MAPPSBURG_CDP = "49320"
MAPPSVILLE_CDP = "49336"
MARION_TOWN = "49464"
MARSHALL_CDP = "49656"
MARTINSVILLE_CITY = "49784"
MASON_NECK_CDP = "49998"
MASSANETTA_SPRINGS_CDP = "50020"
MASSANUTTEN_CDP = "50030"
MATHEWS_CDP = "50104"
MATOACA_CDP = "50136"
MAURERTOWN_CDP = "50200"
MAX_MEADOWS_CDP = "50312"
MCDOWELL_CDP = "48184"
MCGAHEYSVILLE_CDP = "48232"
MCKENNEY_TOWN = "48344"
MCLEAN_CDP = "48376"
MCMULLIN_CDP = "48445"
MCNAIR_CDP = "48450"
MEADOWBROOK_CDP = "50568"
MEADOWS_OF_DAN_CDP = "50696"
MEADOWVIEW_CDP = "50760"
MECHANICSBURG_CDP = "50840"
MECHANICSVILLE_CDP = "50856"
MELFA_TOWN = "50984"
MENDOTA_CDP = "51096"
MERRIFIELD_CDP = "51192"
MERRIMAC_CDP = "51208"
METOMPKIN_CDP = "51362"
MIDDLEBROOK_CDP = "51432"
MIDDLEBURG_TOWN = "51448"
MIDDLETOWN_TOWN = "51512"
MIDLAND_CDP = "51544"
MIDLOTHIAN_CDP = "51560"
MILLBORO_CDP = "51848"
MINERAL_TOWN = "52120"
MODEST_TOWN_CDP = "52408"
MONETA_CDP = "52536"
MONTCLAIR_CDP = "52658"
MONTEREY_TOWN = "52680"
MONTROSE_CDP = "52904"
MONTROSS_TOWN = "52952"
MONTVALE_CDP = "52968"
MOOREFIELD_CDP = "53030"
MOTLEY_CDP = "53480"
MOUNT_CLIFTON_CDP = "53832"
MOUNT_CRAWFORD_TOWN = "53864"
MOUNT_HERMON_CDP = "53944"
MOUNT_JACKSON_TOWN = "53992"
MOUNT_SIDNEY_CDP = "54120"
MOUNT_VERNON_CDP = "54144"
MOUNTAIN_ROAD_CDP = "53584"
NARROWS_TOWN = "54904"
NASSAWADOX_TOWN = "54984"
NATHALIE_CDP = "55000"
NAVY_CDP = "55208"
NELLYSFORD_CDP = "55400"
NELSONIA_CDP = "55448"
NEW_BALTIMORE_CDP = "55528"
NEW_CASTLE_TOWN = "55592"
NEW_CHURCH_CDP = "55608"
NEW_HOPE_CDP = "55720"
NEW_KENT_CDP = "55800"
NEW_MARKET_TOWN = "55848"
NEW_RIVER_CDP = "56048"
NEWINGTON_CDP = "55752"
NEWINGTON_FOREST_CDP = "55758"
NEWPORT_NEWS_CITY = "56000"
NEWSOMS_TOWN = "56096"
NICKELSVILLE_TOWN = "56304"
NOKESVILLE_CDP = "56464"
NORFOLK_CITY = "57000"
NORTH_GARDEN_CDP = "57368"
NORTH_SHORE_CDP = "57531"
NORTH_SPRINGFIELD_CDP = "57560"
NORTON_CITY = "57688"
NOTTOWAY_COURT_HOUSE_CDP = "57870"
OAK_GROVE_CDP = "58104"
OAK_HALL_CDP = "58184"
OAK_LEVEL_CDP = "58312"
OAKTON_CDP = "58472"
OCCOQUAN_TOWN = "58696"
ONANCOCK_TOWN = "59336"
ONE_LOUDOUN_CDP = "59364"
ONLEY_TOWN = "59384"
OPAL_CDP = "59416"
ORANGE_TOWN = "59496"
OSAKA_CDP = "59752"
PAINTER_TOWN = "60296"
PALMYRA_CDP = "60392"
PAMPLIN_CITY_TOWN = "60488"
PANTOPS_CDP = "60512"
PARIS_CDP = "60536"
PARKSLEY_TOWN = "60680"
PARROTT_CDP = "60840"
PASSAPATANZY_CDP = "60888"
PASTORIA_CDP = "60920"
PATRICK_SPRINGS_CDP = "60984"
PEARISBURG_TOWN = "61208"
PEMBROKE_TOWN = "61336"
PENHOOK_CDP = "61464"
PENNINGTON_GAP_TOWN = "61560"
PETERSBURG_CITY = "61832"
PHENIX_TOWN = "61896"
PIMMIT_HILLS_CDP = "62264"
PINEY_MOUNTAIN_CDP = "62738"
PLUM_CREEK_CDP = "63190"
POCAHONTAS_TOWN = "63288"
POQUOSON_CITY = "63768"
PORT_REPUBLIC_CDP = "63896"
PORT_ROYAL_TOWN = "63928"
PORTSMOUTH_CITY = "64000"
POTOMAC_MILLS_CDP = "64152"
POUND_TOWN = "64272"
POUNDING_MILL_CDP = "64288"
POWHATAN_CDP = "64384"
PRICES_FORK_CDP = "64512"
PRINCE_GEORGE_CDP = "64560"
PULASKI_TOWN = "64880"
PUNGOTEAGUE_CDP = "64976"
PURCELLVILLE_TOWN = "65008"
QUANTICO_BASE_CDP = "65128"
QUANTICO_TOWN = "65120"
QUINBY_CDP = "65280"
RADFORD_CITY = "65392"
RAVEN_CDP = "65744"
RAVENSWORTH_CDP = "65776"
RECTORTOWN_CDP = "66032"
REMINGTON_TOWN = "66512"
RESTON_CDP = "66672"
RICH_CREEK_TOWN = "66896"
RICHLANDS_TOWN = "66928"
RICHMOND_CITY = "67000"
RIDGEWAY_TOWN = "67208"
RINER_CDP = "67256"
RIO_CDP = "67288"
RIPPLEMEAD_CDP = "67304"
RIVANNA_CDP = "67331"
RIVERDALE_CDP = "67352"
RIVERVIEW_CDP = "67704"
ROANOKE_CITY = "68000"
ROCKWOOD_CDP = "68470"
ROCKY_GAP_CDP = "68480"
ROCKY_MOUNT_TOWN = "68496"
ROSE_HILL_CDP_FAIRFAX_COUNTY = "68880"
ROSE_HILL_CDP_LEE_COUNTY = "68885"
ROUND_HILL_TOWN = "69168"
RUCKERSVILLE_CDP = "69360"
RURAL_RETREAT_TOWN = "69456"
RUSHMERE_CDP = "69472"
RUSTBURG_CDP = "69536"
SALEM_CITY = "70000"
SALTVILLE_TOWN = "70096"
SALUDA_CDP = "70112"
SANDSTON_CDP = "70256"
SANDY_LEVEL_CDP = "70296"
SANFORD_CDP = "70352"
SAVAGE_TOWN_CDP = "70520"
SAVAGEVILLE_CDP = "70528"
SAXIS_TOWN = "70576"
SCHOONER_BAY_CDP = "70680"
SCHUYLER_CDP = "70704"
SCOTLAND_CDP = "70715"
SCOTTSBURG_TOWN = "70752"
SCOTTSVILLE_TOWN = "70800"
SEDLEY_CDP = "71040"
SELMA_CDP = "71072"
SEVEN_CORNERS_CDP = "71216"
SEVEN_MILE_FORD_CDP = "71264"
SHAWNEELAND_CDP = "71625"
SHAWSVILLE_CDP = "71632"
SHENANDOAH_FARMS_CDP = "71810"
SHENANDOAH_RETREAT_CDP = "71825"
SHENANDOAH_SHORES_CDP = "71826"
SHENANDOAH_TOWN = "71776"
SHERANDO_CDP = "71904"
SHIPMAN_CDP = "72080"
SHORT_PUMP_CDP = "72272"
SINGERS_GLEN_CDP = "72736"
SKYLAND_ESTATES_CDP = "72935"
SMITHFIELD_TOWN = "73200"
SNOWVILLE_CDP = "73376"
SOUTH_BOSTON_TOWN = "73712"
SOUTH_HILL_TOWN = "73904"
SOUTH_RIDING_CDP = "74100"
SOUTH_RUN_CDP = "74120"
SOUTHAMPTON_MEADOWS_CDP = "73624"
SOUTHERN_GATEWAY_CDP = "73760"
SOUTHSIDE_CHESCONESSEX_CDP = "74160"
SPERRYVILLE_CDP = "74384"
SPOTSYLVANIA_COURTHOUSE_CDP = "74470"
SPRINGFIELD_CDP = "74592"
SPRINGVILLE_CDP = "74848"
ST_CHARLES_TOWN = "69792"
ST_PAUL_TOWN = "69936"
STAFFORD_COURTHOUSE_CDP = "74916"
STANARDSVILLE_TOWN = "75008"
STANLEY_TOWN = "75024"
STANLEYTOWN_CDP = "75040"
STAUNTON_CITY = "75216"
STEPHENS_CITY_TOWN = "75344"
STERLING_CDP = "75376"
STEVENS_CREEK_CDP = "75440"
STEWARTSVILLE_CDP = "75504"
STICKLEYVILLE_CDP = "75536"
STONE_RIDGE_CDP = "75702"
STONEGA_CDP = "75680"
STONY_CREEK_TOWN = "75840"
STRASBURG_TOWN = "76000"
STUART_TOWN = "76256"
STUARTS_DRAFT_CDP = "76272"
SUDLEY_CDP = "76416"
SUFFOLK_CITY = "76432"
SUGAR_GROVE_CDP = "76448"
SUGARLAND_RUN_CDP = "76464"
SULLY_SQUARE_CDP = "76516"
SURRY_TOWN = "76880"
SUSSEX_CDP = "76912"
TACOMA_CDP = "77408"
TANGIER_TOWN = "77520"
TAPPAHANNOCK_TOWN = "77568"
TASLEY_CDP = "77648"
TAZEWELL_TOWN = "77792"
TEMPERANCEVILLE_CDP = "77856"
TEMPLETON_CDP = "77925"
THE_PLAINS_TOWN = "78192"
THE_UNIVERSITY_OF_VIRGINIAS_COLLEGE_AT_WISE_CDP = "78264"
THYNEDALE_CDP = "78532"
TIMBERLAKE_CDP = "78688"
TIMBERVILLE_TOWN = "78736"
TOMS_BROOK_TOWN = "79024"
TRIANGLE_CDP = "79360"
TROUTDALE_TOWN = "79456"
TROUTVILLE_TOWN = "79472"
TUCKAHOE_CDP = "79560"
TWIN_LAKES_CDP = "79768"
TYSONS_CDP = "79950"
UNION_HALL_CDP = "80000"
UNION_LEVEL_CDP = "80016"
UNION_MILL_CDP = "80029"
UNIVERSITY_CENTER_CDP = "80120"
UNIVERSITY_OF_VIRGINIA_CDP = "80165"
UPPERVILLE_CDP = "80224"
URBANNA_TOWN = "80272"
VANSANT_CDP = "80608"
VERONA_CDP = "80864"
VICTORIA_TOWN = "81024"
VIENNA_TOWN = "81072"
VILLA_HEIGHTS_CDP = "81152"
VINTON_TOWN = "81280"
VIRGILINA_TOWN = "81312"
VIRGINIA_BEACH_CITY = "82000"
WACHAPREAGUE_TOWN = "82320"
WAKEFIELD_CDP = "82371"
WAKEFIELD_TOWN = "82384"
WARFIELD_CDP = "83056"
WARM_SPRINGS_CDP = "83088"
WARRENTON_TOWN = "83136"
WARSAW_TOWN = "83168"
WASHINGTON_TOWN = "83248"
WATERFORD_CDP = "83440"
WATTSVILLE_CDP = "83568"
WAVERLY_TOWN = "83600"
WAYNESBORO_CITY = "83680"
WEBER_CITY_TOWN = "83808"
WEEMS_CDP = "83888"
WEST_FALLS_CHURCH_CDP = "84368"
WEST_POINT_TOWN = "84960"
WEST_SPRINGFIELD_CDP = "84976"
WESTLAKE_CORNER_CDP = "84632"
WEYERS_CAVE_CDP = "85184"
WHITE_STONE_TOWN = "85600"
WHITESVILLE_CDP = "85608"
WILLIAMSBURG_CITY = "86160"
WILLIS_WHARF_CDP = "86336"
WINCHESTER_CITY = "86720"
WINDSOR_TOWN = "86784"
WINTERGREEN_CDP = "87008"
WISE_TOWN = "87072"
WOLF_TRAP_CDP = "87240"
WOODBRIDGE_CDP = "87312"
WOODBURN_CDP = "87333"
WOODLAKE_CDP = "87380"
WOODLAWN_CDP_CARROLL_COUNTY = "87408"
WOODLAWN_CDP_FAIRFAX_COUNTY = "87410"
WOODSTOCK_TOWN = "87712"
WYNDHAM_CDP = "87960"
WYTHEVILLE_TOWN = "88000"
YOGAVILLE_CDP = "88145"
YORKSHIRE_CDP = "88176"
YORKTOWN_CDP = "88240"
