# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in South Carolina."""


ABBEVILLE = "001"
AIKEN = "003"
ALLENDALE = "005"
ANDERSON = "007"
BAMBERG = "009"
BARNWELL = "011"
BEAUFORT = "013"
BERKELEY = "015"
CALHOUN = "017"
CHARLESTON = "019"
CHEROKEE = "021"
CHESTER = "023"
CHESTERFIELD = "025"
CLARENDON = "027"
COLLETON = "029"
DARLINGTON = "031"
DILLON = "033"
DORCHESTER = "035"
EDGEFIELD = "037"
FAIRFIELD = "039"
FLORENCE = "041"
GEORGETOWN = "043"
GREENVILLE = "045"
GREENWOOD = "047"
HAMPTON = "049"
HORRY = "051"
JASPER = "053"
KERSHAW = "055"
LANCASTER = "057"
LAURENS = "059"
LEE = "061"
LEXINGTON = "063"
MARION = "067"
MARLBORO = "069"
MCCORMICK = "065"
NEWBERRY = "071"
OCONEE = "073"
ORANGEBURG = "075"
PICKENS = "077"
RICHLAND = "079"
SALUDA = "081"
SPARTANBURG = "083"
SUMTER = "085"
UNION = "087"
WILLIAMSBURG = "089"
YORK = "091"
