# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Wisconsin."""


ABBOTSFORD_CITY = "00100"
ABRAMS_CDP = "00150"
ADAMS_CITY = "00275"
ADELL_VILLAGE = "00450"
ALBANY_VILLAGE = "00750"
ALGOMA_CITY = "01000"
ALLENS_GROVE_CDP = "01075"
ALLENTON_CDP = "01100"
ALLOUEZ_VILLAGE = "01150"
ALMA_CENTER_VILLAGE = "01300"
ALMA_CITY = "01225"
ALMENA_VILLAGE = "01325"
ALMOND_VILLAGE = "01400"
ALTO_CDP = "01500"
ALTOONA_CITY = "01550"
AMBERG_CDP = "01650"
AMERY_CITY = "01725"
AMHERST_JUNCTION_VILLAGE = "01800"
AMHERST_VILLAGE = "01750"
ANGELICA_CDP = "01950"
ANIWA_VILLAGE = "02075"
ANTIGO_CITY = "02250"
APPLETON_CITY = "02375"
ARCADIA_CITY = "02500"
ARENA_VILLAGE = "02550"
ARGONNE_CDP = "02600"
ARGYLE_VILLAGE = "02650"
ARKANSAW_CDP = "02700"
ARKDALE_CDP = "02725"
ARLINGTON_VILLAGE = "02800"
ARPIN_VILLAGE = "03025"
ASHIPPUN_CDP = "03175"
ASHLAND_CITY = "03225"
ASHWAUBENON_VILLAGE = "03425"
ATHENS_VILLAGE = "03550"
AUBURNDALE_VILLAGE = "03775"
AUGUSTA_CITY = "03825"
AVOCA_VILLAGE = "04025"
BABCOCK_CDP = "04150"
BAGLEY_VILLAGE = "04250"
BAILEYS_HARBOR_CDP = "04300"
BALDWIN_VILLAGE = "04400"
BALSAM_LAKE_VILLAGE = "04475"
BANCROFT_CDP = "04525"
BANGOR_VILLAGE = "04550"
BARABOO_CITY = "04625"
BARNEVELD_VILLAGE = "04775"
BARRON_CITY = "04875"
BARRONETT_CDP = "04925"
BATAVIA_CDP = "05275"
BAY_CITY_VILLAGE = "05325"
BAYFIELD_CITY = "05350"
BAYFRONT_CDP = "05387"
BAYSIDE_VILLAGE = "05450"
BEAR_CREEK_VILLAGE = "05575"
BEAVER_DAM_CITY = "05900"
BELGIUM_VILLAGE = "06150"
BELL_CENTER_VILLAGE = "06225"
BELLEVILLE_VILLAGE = "06300"
BELLEVUE_VILLAGE = "06350"
BELMONT_VILLAGE = "06425"
BELOIT_CITY = "06500"
BENTON_VILLAGE = "06825"
BERLIN_CITY = "06925"
BIG_BEND_VILLAGE = "07200"
BIG_FALLS_VILLAGE = "07250"
BIG_FOOT_PRAIRIE_CDP = "07315"
BIRCH_HILL_CDP = "07532"
BIRCHWOOD_VILLAGE = "07550"
BIRNAMWOOD_VILLAGE = "07600"
BIRON_VILLAGE = "07650"
BLACK_CREEK_VILLAGE = "07725"
BLACK_EARTH_VILLAGE = "07800"
BLACK_RIVER_FALLS_CITY = "07900"
BLAIR_CITY = "08075"
BLANCHARDVILLE_VILLAGE = "08125"
BLOOMER_CITY = "08225"
BLOOMFIELD_VILLAGE = "08265"
BLOOMINGTON_VILLAGE = "08375"
BLUE_MOUNDS_VILLAGE = "08475"
BLUE_RIVER_VILLAGE = "08525"
BLUFFVIEW_CDP = "08560"
BOAZ_VILLAGE = "08600"
BOHNERS_LAKE_CDP = "08625"
BONDUEL_VILLAGE = "08725"
BOSCOBEL_CITY = "08850"
BOULDER_JUNCTION_CDP = "08925"
BOWLER_VILLAGE = "09025"
BOYCEVILLE_VILLAGE = "09050"
BOYD_VILLAGE = "09075"
BRANDON_VILLAGE = "09300"
BRICE_PRAIRIE_CDP = "09465"
BRIGGSVILLE_CDP = "09575"
BRILLION_CITY = "09725"
BRISTOL_VILLAGE = "09800"
BRODHEAD_CITY = "09925"
BROOKFIELD_CITY = "10025"
BROOKLYN_VILLAGE = "10075"
BROTHERTOWN_CDP = "10325"
BROWN_DEER_VILLAGE = "10375"
BROWNS_LAKE_CDP = "10425"
BROWNSVILLE_VILLAGE = "10450"
BROWNTOWN_VILLAGE = "10475"
BRUCE_VILLAGE = "10500"
BRULE_CDP = "10550"
BUFFALO_CITY_CITY = "11062"
BURLINGTON_CITY = "11200"
BURNETT_CDP = "11250"
BUTLER_VILLAGE = "11475"
BUTTE_DES_MORTS_CDP = "11500"
BUTTERNUT_VILLAGE = "11525"
CABLE_CDP = "11650"
CADOTT_VILLAGE = "11750"
CALEDONIA_VILLAGE = "11950"
CAMBRIA_VILLAGE = "12200"
CAMBRIDGE_VILLAGE = "12225"
CAMERON_VILLAGE = "12250"
CAMP_DOUGLAS_VILLAGE = "12350"
CAMPBELLSPORT_VILLAGE = "12325"
CAROLINE_CDP = "12675"
CASCADE_VILLAGE = "12825"
CASCO_VILLAGE = "12850"
CASHTON_VILLAGE = "12950"
CASSVILLE_VILLAGE = "13050"
CATARACT_CDP = "13150"
CATAWBA_VILLAGE = "13175"
CAZENOVIA_VILLAGE = "13300"
CECIL_VILLAGE = "13325"
CEDAR_GROVE_VILLAGE = "13475"
CEDARBURG_CITY = "13375"
CEEX_HACI_CDP = "13587"
CENTURIA_VILLAGE = "13850"
CHAIN_O_LAKES_CDP = "13880"
CHASEBURG_VILLAGE = "14150"
CHELSEA_CDP = "14175"
CHENEQUA_VILLAGE = "14225"
CHETEK_CITY = "14325"
CHIEF_LAKE_CDP = "14440"
CHILI_CDP = "14450"
CHILTON_CITY = "14475"
CHIPPEWA_FALLS_CITY = "14575"
CLAM_LAKE_CDP = "14850"
CLARKS_MILLS_CDP = "14925"
CLAYTON_VILLAGE = "15100"
CLEAR_LAKE_VILLAGE = "15250"
CLEVELAND_VILLAGE = "15400"
CLINTON_VILLAGE = "15625"
CLINTONVILLE_CITY = "15725"
CLYMAN_VILLAGE = "15900"
COBB_VILLAGE = "15975"
COCHRANE_VILLAGE = "16025"
COLBY_CITY = "16150"
COLEMAN_VILLAGE = "16250"
COLFAX_VILLAGE = "16275"
COLLINS_CDP = "16350"
COLOMA_VILLAGE = "16375"
COLUMBUS_CITY = "16450"
COMBINED_LOCKS_VILLAGE = "16500"
COMO_CDP = "16575"
CONRATH_VILLAGE = "16775"
COON_VALLEY_VILLAGE = "16900"
CORNELL_CITY = "17100"
CORNUCOPIA_CDP = "17150"
COTTAGE_GROVE_VILLAGE = "17175"
COUDERAY_VILLAGE = "17225"
CRANDON_CITY = "17425"
CRIVITZ_VILLAGE = "17725"
CROSS_PLAINS_VILLAGE = "17775"
CUBA_CITY_CITY = "17950"
CUDAHY_CITY = "17975"
CUMBERLAND_CITY = "18025"
CURTISS_VILLAGE = "18125"
DALE_CDP = "18500"
DALLAS_VILLAGE = "18575"
DALTON_CDP = "18625"
DANBURY_CDP = "18650"
DANE_VILLAGE = "18700"
DARIEN_VILLAGE = "18825"
DARLINGTON_CITY = "18875"
DE_PERE_CITY = "19775"
DE_SOTO_VILLAGE = "19850"
DEFOREST_VILLAGE = "19350"
DEER_PARK_VILLAGE = "19325"
DEERFIELD_VILLAGE = "19250"
DEKORRA_CDP = "19365"
DELAFIELD_CITY = "19400"
DELAVAN_LAKE_CDP = "19500"
DELAVAN_CITY = "19450"
DELLWOOD_CDP = "19600"
DENMARK_VILLAGE = "19700"
DIAMOND_BLUFF_CDP = "20125"
DIAPERVILLE_CDP = "20167"
DICKEYVILLE_VILLAGE = "20175"
DODGE_CDP = "20275"
DODGEVILLE_CITY = "20350"
DORCHESTER_VILLAGE = "20450"
DOUSMAN_VILLAGE = "20550"
DOWNING_VILLAGE = "20675"
DOWNSVILLE_CDP = "20725"
DOYLESTOWN_VILLAGE = "20775"
DRESSER_VILLAGE = "20850"
DRUMMOND_CDP = "20875"
DUNBAR_CDP = "20975"
DURAND_CITY = "21225"
DYCKESVILLE_CDP = "21375"
EAGLE_LAKE_CDP = "21525"
EAGLE_RIVER_CITY = "21625"
EAGLE_VILLAGE = "21425"
EAST_TROY_VILLAGE = "22100"
EASTMAN_VILLAGE = "21900"
EASTON_CDP = "21975"
EAU_CLAIRE_CITY = "22300"
EDEN_VILLAGE = "22475"
EDGAR_VILLAGE = "22550"
EDGERTON_CITY = "22575"
EDMUND_CDP = "22700"
EGG_HARBOR_VILLAGE = "22850"
ELAND_VILLAGE = "22975"
ELCHO_CDP = "23025"
ELDERON_VILLAGE = "23075"
ELEVA_VILLAGE = "23175"
ELK_MOUND_VILLAGE = "23325"
ELKHART_LAKE_VILLAGE = "23275"
ELKHORN_CITY = "23300"
ELLISON_BAY_CDP = "23475"
ELLSWORTH_VILLAGE = "23525"
ELM_GROVE_VILLAGE = "23575"
ELMWOOD_PARK_VILLAGE = "23725"
ELMWOOD_VILLAGE = "23700"
ELROY_CITY = "23800"
EMBARRASS_VILLAGE = "23850"
EMERALD_CDP = "23900"
ENDEAVOR_VILLAGE = "24075"
EPHRAIM_VILLAGE = "24150"
ETTRICK_VILLAGE = "24400"
EUREKA_CDP = "24475"
EVANSVILLE_CITY = "24550"
EXELAND_VILLAGE = "24700"
FAIRCHILD_VILLAGE = "24825"
FAIRWATER_VILLAGE = "25075"
FALL_CREEK_VILLAGE = "25125"
FALL_RIVER_VILLAGE = "25150"
FENNIMORE_CITY = "25600"
FENWOOD_VILLAGE = "25650"
FERRYVILLE_VILLAGE = "25725"
FITCHBURG_CITY = "25950"
FLORENCE_CDP = "26175"
FOND_DU_LAC_CITY = "26275"
FONTANA_ON_GENEVA_LAKE_VILLAGE = "26350"
FOOTVILLE_VILLAGE = "26400"
FOREST_JUNCTION_CDP = "26575"
FORESTVILLE_VILLAGE = "26625"
FORT_ATKINSON_CITY = "26675"
FOUNTAIN_CITY_CITY = "26850"
FOX_CROSSING_VILLAGE = "26982"
FOX_LAKE_CITY = "27000"
FOX_POINT_VILLAGE = "27075"
FRANCIS_CREEK_VILLAGE = "27125"
FRANKLIN_CITY = "27300"
FRANKS_FIELD_CDP = "27412"
FREDERIC_VILLAGE = "27500"
FREDONIA_VILLAGE = "27550"
FREMONT_VILLAGE = "27800"
FRENCH_ISLAND_CDP = "27875"
FRIENDSHIP_VILLAGE = "27950"
FRIESLAND_VILLAGE = "28000"
FULTON_CDP = "28050"
GALESVILLE_CITY = "28200"
GAYS_MILLS_VILLAGE = "28450"
GENOA_CITY_VILLAGE = "28675"
GENOA_VILLAGE = "28625"
GERMANTOWN_VILLAGE = "28875"
GIBBSVILLE_CDP = "28925"
GILLETT_CITY = "29050"
GILMAN_VILLAGE = "29175"
GILMANTON_CDP = "29200"
GLEN_FLORA_VILLAGE = "29475"
GLEN_HAVEN_CDP = "29500"
GLENBEULAH_VILLAGE = "29350"
GLENDALE_CITY = "29400"
GLENWOOD_CITY_CITY = "29625"
GLIDDEN_CDP = "29675"
GOODMAN_CDP = "29750"
GORDON_CDP = "29900"
GOTHAM_CDP = "29950"
GRAFTON_VILLAGE = "30000"
GRAND_MARSH_CDP = "30100"
GRAND_VIEW_CDP = "30150"
GRANTON_VILLAGE = "30425"
GRANTSBURG_VILLAGE = "30450"
GRATIOT_VILLAGE = "30575"
GREEN_BAY_CITY = "31000"
GREEN_LAKE_CITY = "31300"
GREEN_VALLEY_CDP = "31475"
GREENBUSH_CDP = "31075"
GREENDALE_VILLAGE = "31125"
GREENFIELD_CITY = "31175"
GREENLEAF_CDP = "31375"
GREENVILLE_VILLAGE = "31525"
GREENWOOD_CITY = "31575"
GRESHAM_VILLAGE = "31675"
HAGER_CITY_CDP = "31975"
HALES_CORNERS_VILLAGE = "32075"
HAMMOND_VILLAGE = "32325"
HANCOCK_VILLAGE = "32450"
HANOVER_CDP = "32550"
HARRISON_VILLAGE = "32790"
HARRISVILLE_CDP = "32950"
HARTFORD_CITY = "33000"
HARTLAND_VILLAGE = "33100"
HATFIELD_CDP = "33150"
HATLEY_VILLAGE = "33175"
HAUGEN_VILLAGE = "33225"
HAWKINS_VILLAGE = "33275"
HAYWARD_CITY = "33450"
HAZEL_GREEN_VILLAGE = "33500"
HEBRON_CDP = "33675"
HELENVILLE_CDP = "33825"
HERBSTER_CDP = "33975"
HEWITT_VILLAGE = "34250"
HIGHLAND_VILLAGE = "34450"
HILBERT_VILLAGE = "34575"
HILLSBORO_CITY = "34825"
HINGHAM_CDP = "35000"
HIXTON_VILLAGE = "35075"
HOBART_VILLAGE = "35150"
HOLCOMBE_CDP = "35225"
HOLLANDALE_VILLAGE = "35400"
HOLMEN_VILLAGE = "35450"
HORICON_CITY = "35750"
HORTONVILLE_VILLAGE = "35850"
HOULTON_CDP = "35900"
HOWARD_VILLAGE = "35950"
HOWARDS_GROVE_VILLAGE = "36025"
HUDSON_CITY = "36250"
HUMBIRD_CDP = "36400"
HURLEY_CITY = "36525"
HUSTISFORD_VILLAGE = "36625"
HUSTLER_VILLAGE = "36675"
INDEPENDENCE_CITY = "36800"
INGRAM_VILLAGE = "36925"
IOLA_VILLAGE = "37025"
IRON_BELT_CDP = "37125"
IRON_RIDGE_VILLAGE = "37150"
IRON_RIVER_CDP = "37175"
IRONTON_VILLAGE = "37225"
IXONIA_CDP = "37575"
JACKSON_VILLAGE = "37675"
JANESVILLE_CITY = "37825"
JEFFERSON_CITY = "37900"
JIM_FALLS_CDP = "38225"
JOHNSON_CREEK_VILLAGE = "38350"
JOLMAVILLE_CDP = "38487"
JUDA_CDP = "38600"
JUMP_RIVER_CDP = "38625"
JUNCTION_CITY_VILLAGE = "38650"
JUNEAU_CITY = "38675"
KAUKAUNA_CITY = "38800"
KEKOSKEE_VILLAGE = "38900"
KELLNERSVILLE_VILLAGE = "39000"
KENDALL_VILLAGE = "39150"
KENNAN_VILLAGE = "39175"
KENOSHA_CITY = "39225"
KESHENA_CDP = "39250"
KEWASKUM_VILLAGE = "39300"
KEWAUNEE_CITY = "39350"
KIEL_CITY = "39525"
KIELER_CDP = "39550"
KIMBERLY_VILLAGE = "39650"
KING_CDP = "39700"
KINGSTON_VILLAGE = "39750"
KNAPP_VILLAGE = "39975"
KNOWLTON_CDP = "40125"
KOHLER_VILLAGE = "40275"
KRAKOW_CDP = "40450"
KRONENWETTER_VILLAGE = "40550"
LA_CROSSE_CITY = "40775"
LA_FARGE_VILLAGE = "40875"
LA_VALLE_VILLAGE = "42825"
LAC_LA_BELLE_VILLAGE = "40750"
LAC_DU_FLAMBEAU_CDP = "40675"
LADYSMITH_CITY = "40850"
LAKE_ARROWHEAD_CDP = "41160"
LAKE_CAMELOT_CDP = "41210"
LAKE_DELTON_VILLAGE = "41300"
LAKE_GENEVA_CITY = "41450"
LAKE_HALLIE_VILLAGE = "41525"
LAKE_IVANHOE_CDP = "41560"
LAKE_KOSHKONONG_CDP = "41583"
LAKE_LORRAINE_CDP = "41645"
LAKE_MILLS_CITY = "41675"
LAKE_NEBAGAMON_VILLAGE = "41725"
LAKE_RIPLEY_CDP = "41765"
LAKE_SHERWOOD_CDP = "41772"
LAKE_TOMAHAWK_CDP = "41875"
LAKE_WAZEECHA_CDP = "41975"
LAKE_WISCONSIN_CDP = "42012"
LAKE_WISSOTA_CDP = "42025"
LAKEWOOD_CDP = "42050"
LANCASTER_CITY = "42250"
LANNON_VILLAGE = "42450"
LAONA_CDP = "42475"
LAUDERDALE_LAKES_CDP = "42805"
LEBANON_CDP = "43025"
LEGEND_LAKE_CDP = "43207"
LENA_VILLAGE = "43325"
LEOPOLIS_CDP = "43575"
LEWIS_CDP = "43725"
LILY_LAKE_CDP = "44033"
LIME_RIDGE_VILLAGE = "44225"
LINDEN_VILLAGE = "44625"
LITTLE_CHUTE_VILLAGE = "44950"
LITTLE_ROUND_LAKE_CDP = "45220"
LITTLE_STURGEON_CDP = "45225"
LIVINGSTON_VILLAGE = "45325"
LODI_CITY = "45350"
LOGANVILLE_VILLAGE = "45400"
LOHRVILLE_VILLAGE = "45425"
LOMIRA_VILLAGE = "45475"
LONE_ROCK_VILLAGE = "45575"
LONG_LAKE_CDP = "45600"
LOWELL_VILLAGE = "45950"
LOYAL_CITY = "46075"
LUBLIN_VILLAGE = "46150"
LUCK_VILLAGE = "46200"
LUXEMBURG_VILLAGE = "46400"
LYNDON_STATION_VILLAGE = "46600"
LYNXVILLE_VILLAGE = "46675"
LYONS_CDP = "46700"
MADISON_CITY = "48000"
MAIDEN_ROCK_VILLAGE = "48175"
MAINE_VILLAGE = "48225"
MANAWA_CITY = "48350"
MANITOWOC_CITY = "48500"
MAPLE_BLUFF_VILLAGE = "48750"
MARATHON_CITY_VILLAGE = "49100"
MARENGO_CDP = "49175"
MARIBEL_VILLAGE = "49250"
MARINETTE_CITY = "49300"
MARION_CITY = "49400"
MARKESAN_CITY = "49450"
MARQUETTE_VILLAGE = "49500"
MARSHALL_VILLAGE = "49575"
MARSHFIELD_CITY = "49675"
MASON_VILLAGE = "49900"
MATTOON_VILLAGE = "50000"
MAUSTON_CITY = "50025"
MAYVILLE_CITY = "50200"
MAZOMANIE_VILLAGE = "50225"
MCFARLAND_VILLAGE = "46850"
MEDFORD_CITY = "50425"
MELLEN_CITY = "50700"
MELROSE_VILLAGE = "50750"
MELVINA_VILLAGE = "50800"
MENASHA_CITY = "50825"
MENOMONEE_FALLS_VILLAGE = "51000"
MENOMONIE_CITY = "51025"
MEQUON_CITY = "51150"
MERCER_CDP = "51175"
MERRILL_CITY = "51250"
MERRILLAN_VILLAGE = "51300"
MERRIMAC_VILLAGE = "51325"
MERTON_VILLAGE = "51375"
MIDDLE_VILLAGE_CDP = "51617"
MIDDLETON_CITY = "51575"
MILLADORE_VILLAGE = "51875"
MILLSTON_CDP = "52025"
MILLTOWN_VILLAGE = "52075"
MILTON_CITY = "52200"
MILWAUKEE_CITY = "53000"
MINDORO_CDP = "53050"
MINERAL_POINT_CITY = "53100"
MINOCQUA_CDP = "53200"
MINONG_VILLAGE = "53250"
MISHICOT_VILLAGE = "53325"
MISSION_CDP = "53358"
MOLE_LAKE_CDP = "53500"
MONDOVI_CITY = "53600"
MONONA_CITY = "53675"
MONROE_CITY = "53750"
MONTELLO_CITY = "53875"
MONTFORT_VILLAGE = "53950"
MONTICELLO_VILLAGE = "54000"
MONTREAL_CITY = "54075"
MOSINEE_CITY = "54500"
MOUNT_CALVARY_VILLAGE = "54650"
MOUNT_HOPE_VILLAGE = "54675"
MOUNT_HOREB_VILLAGE = "54725"
MOUNT_PLEASANT_VILLAGE = "54875"
MOUNT_STERLING_VILLAGE = "54900"
MOUNTAIN_CDP = "54625"
MUKWONAGO_VILLAGE = "55050"
MUSCODA_VILLAGE = "55200"
MUSKEGO_CITY = "55275"
NASHOTAH_VILLAGE = "55550"
NAVARINO_CDP = "55650"
NECEDAH_VILLAGE = "55700"
NEENAH_CITY = "55750"
NEILLSVILLE_CITY = "55800"
NEKOOSA_CITY = "55875"
NELSON_VILLAGE = "55950"
NELSONVILLE_VILLAGE = "56000"
NEOPIT_CDP = "56050"
NEOSHO_VILLAGE = "56075"
NESHKORO_VILLAGE = "56125"
NEW_AUBURN_VILLAGE = "56350"
NEW_BERLIN_CITY = "56375"
NEW_GLARUS_VILLAGE = "56700"
NEW_HOLSTEIN_CITY = "56800"
NEW_LISBON_CITY = "56900"
NEW_LONDON_CITY = "56925"
NEW_MUNSTER_CDP = "57000"
NEW_ODANAH_CDP = "57008"
NEW_POST_CDP = "57050"
NEW_RICHMOND_CITY = "57100"
NEWALD_CDP = "56250"
NEWBURG_VILLAGE = "56450"
NIAGARA_CITY = "57325"
NICHOLS_VILLAGE = "57375"
NORTH_BAY_VILLAGE = "57700"
NORTH_FOND_DU_LAC_VILLAGE = "58000"
NORTH_FREEDOM_VILLAGE = "58025"
NORTH_HUDSON_VILLAGE = "58050"
NORTH_LAKE_CDP = "58100"
NORTH_PRAIRIE_VILLAGE = "58400"
NORTHPORT_CDP = "58375"
NORWALK_VILLAGE = "58575"
OAK_CREEK_CITY = "58800"
OAKDALE_VILLAGE = "58850"
OAKFIELD_VILLAGE = "58900"
OCONOMOWOC_LAKE_VILLAGE = "59300"
OCONOMOWOC_CITY = "59250"
OCONTO_FALLS_CITY = "59400"
OCONTO_CITY = "59350"
ODANAH_CDP = "59450"
OGDENSBURG_VILLAGE = "59475"
OGEMA_CDP = "59500"
OKAUCHEE_LAKE_CDP = "59650"
OLIVER_VILLAGE = "59800"
OMRO_CITY = "59875"
ONALASKA_CITY = "59925"
ONTARIO_VILLAGE = "60075"
OOSTBURG_VILLAGE = "60100"
OREGON_VILLAGE = "60200"
ORFORDVILLE_VILLAGE = "60250"
OSCEOLA_VILLAGE = "60450"
OSHKOSH_CITY = "60500"
OSSEO_CITY = "60575"
OWEN_CITY = "60825"
OXFORD_VILLAGE = "60875"
PAAC_CIINAK_CDP = "60912"
PACKWAUKEE_CDP = "60950"
PADDOCK_LAKE_VILLAGE = "60975"
PALMYRA_VILLAGE = "61025"
PARDEEVILLE_VILLAGE = "61100"
PARK_FALLS_CITY = "61200"
PARK_RIDGE_VILLAGE = "61325"
PATCH_GROVE_VILLAGE = "61425"
PELLA_CDP = "61675"
PEMBINE_CDP = "61750"
PENCE_CDP = "61800"
PEPIN_VILLAGE = "61925"
PESHTIGO_CITY = "62175"
PEWAUKEE_CITY = "62240"
PEWAUKEE_VILLAGE = "62250"
PHILLIPS_CITY = "62450"
PIGEON_FALLS_VILLAGE = "62675"
PINE_RIVER_CDP = "62975"
PITTSVILLE_CITY = "63100"
PLAIN_VILLAGE = "63125"
PLAINFIELD_VILLAGE = "63150"
PLATTEVILLE_CITY = "63250"
PLEASANT_PRAIRIE_VILLAGE = "63300"
PLOVER_VILLAGE = "63525"
PLUM_CITY_VILLAGE = "63600"
PLYMOUTH_CITY = "63700"
POLONIA_CDP = "63925"
POPLAR_VILLAGE = "63975"
PORT_EDWARDS_VILLAGE = "64175"
PORT_WASHINGTON_CITY = "64450"
PORT_WING_CDP = "64500"
PORTAGE_CITY = "64100"
POST_LAKE_CDP = "64550"
POTOSI_VILLAGE = "64625"
POTTER_LAKE_CDP = "64700"
POTTER_VILLAGE = "64675"
POUND_VILLAGE = "64750"
POWERS_LAKE_CDP = "64825"
POY_SIPPI_CDP = "64950"
POYNETTE_VILLAGE = "64900"
PRAIRIE_FARM_VILLAGE = "65150"
PRAIRIE_DU_CHIEN_CITY = "65050"
PRAIRIE_DU_SAC_VILLAGE = "65100"
PRENTICE_VILLAGE = "65325"
PRESCOTT_CITY = "65375"
PRINCETON_CITY = "65600"
PULASKI_VILLAGE = "65675"
PULCIFER_CDP = "65725"
RACINE_CITY = "66000"
RADISSON_VILLAGE = "66050"
RANDOLPH_VILLAGE = "66150"
RANDOM_LAKE_VILLAGE = "66200"
RAYMOND_VILLAGE = "66350"
READSTOWN_VILLAGE = "66450"
REDGRANITE_VILLAGE = "66625"
REEDSBURG_CITY = "66800"
REEDSVILLE_VILLAGE = "66875"
REESEVILLE_VILLAGE = "66900"
RESERVE_CDP = "67050"
REWEY_VILLAGE = "67100"
RHINELANDER_CITY = "67200"
RIB_LAKE_VILLAGE = "67275"
RIB_MOUNTAIN_CDP = "67320"
RICE_LAKE_CITY = "67350"
RICHFIELD_VILLAGE = "67475"
RICHLAND_CENTER_CITY = "67625"
RIDGELAND_VILLAGE = "67800"
RIDGEWAY_VILLAGE = "67875"
RIO_VILLAGE = "68100"
RIPON_CITY = "68175"
RIVER_FALLS_CITY = "68275"
RIVER_HILLS_VILLAGE = "68325"
ROBERTS_VILLAGE = "68475"
ROCHESTER_VILLAGE = "68550"
ROCK_FALLS_CDP = "68800"
ROCK_SPRINGS_VILLAGE = "68975"
ROCKDALE_VILLAGE = "68725"
ROCKLAND_VILLAGE = "68900"
ROME_CDP = "69300"
ROSENDALE_VILLAGE = "69525"
ROSHOLT_VILLAGE = "69575"
ROTHSCHILD_VILLAGE = "69725"
RUBICON_CDP = "69950"
RUDOLPH_VILLAGE = "70000"
SALEM_LAKES_VILLAGE = "71163"
SAND_PILLOW_CDP = "71512"
SANDY_HOOK_CDP = "71585"
SAUK_CITY_VILLAGE = "71650"
SAUKVILLE_VILLAGE = "71700"
SAXON_CDP = "71850"
SAYNER_CDP = "71950"
SCANDINAVIA_VILLAGE = "71975"
SCHOFIELD_CITY = "72150"
SENECA_CDP = "72475"
SEXTONVILLE_CDP = "72650"
SEYMOUR_CDP = "72670"
SEYMOUR_CITY = "72725"
SHARON_VILLAGE = "72875"
SHAWANO_CITY = "72925"
SHEBOYGAN_FALLS_CITY = "73025"
SHEBOYGAN_CITY = "72975"
SHELDON_VILLAGE = "73175"
SHELL_LAKE_CITY = "73200"
SHERWOOD_VILLAGE = "73525"
SHIOCTON_VILLAGE = "73625"
SHOPIERE_CDP = "73675"
SHOREWOOD_HILLS_VILLAGE = "73750"
SHOREWOOD_VILLAGE = "73725"
SHULLSBURG_CITY = "73825"
SIREN_VILLAGE = "74175"
SISTER_BAY_VILLAGE = "74225"
SLINGER_VILLAGE = "74400"
SOBIESKI_CDP = "74500"
SOLDIERS_GROVE_VILLAGE = "74550"
SOLON_SPRINGS_VILLAGE = "74575"
SOMERS_VILLAGE = "74625"
SOMERSET_VILLAGE = "74675"
SOUTH_MILWAUKEE_CITY = "75125"
SOUTH_WAYNE_VILLAGE = "75275"
SPARTA_CITY = "75325"
SPENCER_VILLAGE = "75400"
SPOONER_CITY = "75625"
SPRING_GREEN_VILLAGE = "76025"
SPRING_VALLEY_VILLAGE = "76300"
SPRINGBROOK_CDP = "75775"
SPRINGFIELD_CDP = "75975"
ST_CLOUD_VILLAGE = "70500"
ST_CROIX_FALLS_CITY = "70550"
ST_FRANCIS_CITY = "70650"
ST_JOSEPH_CDP = "70800"
ST_NAZIANZ_VILLAGE = "71025"
ST_PETER_CDP = "71050"
STANLEY_CITY = "76625"
STAR_PRAIRIE_VILLAGE = "76825"
STETSONVILLE_VILLAGE = "77100"
STEUBEN_VILLAGE = "77175"
STEVENS_POINT_CITY = "77200"
STOCKBRIDGE_VILLAGE = "77400"
STOCKHOLM_VILLAGE = "77475"
STODDARD_VILLAGE = "77550"
STONE_LAKE_CDP = "77625"
STOUGHTON_CITY = "77675"
STRATFORD_VILLAGE = "77750"
STRUM_VILLAGE = "77825"
STURGEON_BAY_CITY = "77875"
STURTEVANT_VILLAGE = "77925"
SUAMICO_VILLAGE = "77975"
SULLIVAN_VILLAGE = "78175"
SUMMIT_LAKE_CDP = "78425"
SUMMIT_VILLAGE = "78375"
SUN_PRAIRIE_CITY = "78600"
SUPERIOR_CITY = "78650"
SUPERIOR_VILLAGE = "78660"
SURING_VILLAGE = "78725"
SUSSEX_VILLAGE = "78750"
TAINTER_LAKE_CDP = "78980"
TAYCHEEDAH_CDP = "79100"
TAYLOR_VILLAGE = "79150"
TENNYSON_VILLAGE = "79250"
THERESA_VILLAGE = "79375"
THIENSVILLE_VILLAGE = "79475"
THORNTON_CDP = "79600"
THORP_CITY = "79625"
THREE_LAKES_CDP = "79675"
TICHIGAN_CDP = "79740"
TIGERTON_VILLAGE = "79825"
TILLEDA_CDP = "79900"
TOMAH_CITY = "80075"
TOMAHAWK_CITY = "80125"
TONY_VILLAGE = "80225"
TOWNSEND_CDP = "80300"
TREGO_CDP = "80425"
TREMPEALEAU_VILLAGE = "80475"
TUNNEL_CITY_CDP = "81025"
TURTLE_LAKE_CDP = "81090"
TURTLE_LAKE_VILLAGE = "81075"
TUSTIN_CDP = "81150"
TWIN_LAKES_VILLAGE = "81250"
TWO_RIVERS_CITY = "81325"
UNION_CENTER_VILLAGE = "81725"
UNION_GROVE_VILLAGE = "81775"
UNITY_VILLAGE = "81850"
VALDERS_VILLAGE = "82200"
VAN_DYNE_CDP = "82450"
VERNON_VILLAGE = "82575"
VERONA_CITY = "82600"
VESPER_VILLAGE = "82650"
VIOLA_VILLAGE = "82900"
VIROQUA_CITY = "82925"
WABENO_CDP = "83000"
WALDO_VILLAGE = "83100"
WALES_VILLAGE = "83175"
WALWORTH_VILLAGE = "83250"
WARRENS_VILLAGE = "83450"
WASHBURN_CITY = "83525"
WATERFORD_VILLAGE = "83825"
WATERLOO_CITY = "83925"
WATERTOWN_CITY = "83975"
WAUBEKA_CDP = "84150"
WAUKAU_CDP = "84200"
WAUKESHA_CITY = "84250"
WAUKESHA_VILLAGE = "84275"
WAUMANDEE_CDP = "84300"
WAUNAKEE_VILLAGE = "84350"
WAUPACA_CITY = "84375"
WAUPUN_CITY = "84425"
WAUSAU_CITY = "84475"
WAUSAUKEE_VILLAGE = "84525"
WAUTOMA_CITY = "84625"
WAUWATOSA_CITY = "84675"
WAUZEKA_VILLAGE = "84725"
WEBSTER_VILLAGE = "85025"
WEST_ALLIS_CITY = "85300"
WEST_BARABOO_VILLAGE = "85325"
WEST_BEND_CITY = "85350"
WEST_MILWAUKEE_VILLAGE = "85875"
WEST_SALEM_VILLAGE = "86275"
WESTBORO_CDP = "85425"
WESTBY_CITY = "85475"
WESTFIELD_VILLAGE = "85575"
WESTON_VILLAGE = "86025"
WEYAUWEGA_CITY = "86400"
WEYERHAEUSER_VILLAGE = "86450"
WHEELER_VILLAGE = "86575"
WHITE_LAKE_VILLAGE = "86750"
WHITEFISH_BAY_VILLAGE = "86700"
WHITEHALL_CITY = "86725"
WHITELAW_VILLAGE = "86775"
WHITEWATER_CITY = "86925"
WHITING_VILLAGE = "86975"
WHITTLESEY_CDP = "87000"
WILD_ROSE_VILLAGE = "87075"
WILLIAMS_BAY_VILLAGE = "87200"
WILSON_VILLAGE = "87475"
WILTON_VILLAGE = "87525"
WINCHESTER_CDP = "87625"
WIND_LAKE_CDP = "87675"
WIND_POINT_VILLAGE = "87700"
WINDSOR_VILLAGE = "87725"
WINNECONNE_VILLAGE = "87900"
WINTER_VILLAGE = "87975"
WIOTA_CDP = "88025"
WISCONSIN_DELLS_CITY = "88150"
WISCONSIN_RAPIDS_CITY = "88200"
WITHEE_VILLAGE = "88275"
WITTENBERG_VILLAGE = "88325"
WONEWOC_VILLAGE = "88500"
WOODFORD_CDP = "88675"
WOODMAN_VILLAGE = "88825"
WOODRUFF_CDP = "88925"
WOODVILLE_VILLAGE = "89025"
WRIGHTSTOWN_VILLAGE = "89150"
WYEVILLE_VILLAGE = "89275"
WYOCENA_VILLAGE = "89300"
YORKVILLE_VILLAGE = "89550"
YUBA_VILLAGE = "89625"
ZOAR_CDP = "89760"
