# Copyright (c) 2023 Darren Erik Vengroff
"""Places in New Hampshire."""


ALTON_CDP = "00980"
AMHERST_CDP = "01220"
ANTRIM_CDP = "01620"
ASHLAND_CDP = "01940"
BARTLETT_CDP = "03620"
BELMONT_CDP = "04660"
BENNINGTON_CDP = "04820"
BERLIN_CITY = "05140"
BETHLEHEM_CDP = "05380"
BLODGETT_LANDING_CDP = "06020"
BRADFORD_CDP = "06900"
BRISTOL_CDP = "07620"
CANAAN_CDP = "08900"
CENTER_OSSIPEE_CDP = "10820"
CENTER_SANDWICH_CDP = "10900"
CHARLESTOWN_CDP = "11300"
CLAREMONT_CITY = "12900"
COLEBROOK_CDP = "13700"
CONCORD_CITY = "14200"
CONTOOCOOK_CDP = "14340"
CONWAY_CDP = "14580"
DERRY_CDP = "17860"
DOVER_CITY = "18820"
DURHAM_CDP = "19620"
EAST_MERRIMACK_CDP = "21780"
ENFIELD_CDP = "24260"
EPPING_CDP = "24580"
EXETER_CDP = "25300"
FARMINGTON_CDP = "25940"
FRANCESTOWN_CDP = "27060"
FRANKLIN_CITY = "27380"
GOFFSTOWN_CDP = "29780"
GORHAM_CDP = "30180"
GREENVILLE_CDP = "31860"
GROVETON_CDP = "32260"
HAMPTON_BEACH_CDP = "33140"
HAMPTON_CDP = "32980"
HANCOCK_CDP = "33620"
HANOVER_CDP = "33780"
HENNIKER_CDP = "35460"
HILLSBOROUGH_CDP = "36020"
HINSDALE_CDP = "36580"
HOOKSETT_CDP = "37220"
HUDSON_CDP = "37860"
JAFFREY_CDP = "38420"
KEENE_CITY = "39300"
KLONDIKE_CORNER_CDP = "40120"
LACONIA_CITY = "40180"
LANCASTER_CDP = "40340"
LEBANON_CITY = "41300"
LINCOLN_CDP = "41780"
LISBON_CDP = "41940"
LITTLETON_CDP = "42500"
LONDONDERRY_CDP = "43140"
LOUDON_CDP = "43300"
MANCHESTER_CITY = "45140"
MARLBOROUGH_CDP = "45380"
MELVIN_VILLAGE_CDP = "46980"
MEREDITH_CDP = "47060"
MILFORD_CDP = "47940"
MILTON_CDP = "48580"
MILTON_MILLS_CDP = "48740"
MOUNTAIN_LAKES_CDP = "49600"
NASHUA_CITY = "50260"
NEW_BOSTON_CDP = "50660"
NEW_HAMPTON_CDP = "51460"
NEW_LONDON_CDP = "52020"
NEWFIELDS_CDP = "51300"
NEWMARKET_CDP = "52260"
NEWPORT_CDP = "52500"
NORTH_CONWAY_CDP = "53860"
NORTH_HAVERHILL_CDP = "54740"
NORTH_WALPOLE_CDP = "56420"
NORTH_WOODSTOCK_CDP = "57220"
PETERBOROUGH_CDP = "60500"
PINARDVILLE_CDP = "61220"
PITTSFIELD_CDP = "61860"
PLAINFIELD_CDP = "62260"
PLYMOUTH_CDP = "62580"
PORTSMOUTH_CITY = "62900"
RAYMOND_CDP = "63940"
ROCHESTER_CITY = "65140"
SANBORNVILLE_CDP = "67460"
SEABROOK_BEACH_CDP = "68340"
SOMERSWORTH_CITY = "69940"
SOUTH_HOOKSETT_CDP = "71220"
SUISSEVALE_CDP = "74780"
SUNCOOK_CDP = "75140"
TILTON_NORTHFIELD_CDP = "77100"
TROY_CDP = "77300"
UNION_CDP = "77780"
WALPOLE_CDP = "78340"
WARNER_CDP = "78500"
WEST_STEWARTSTOWN_CDP = "83620"
WEST_SWANZEY_CDP = "83700"
WHITEFIELD_CDP = "84340"
WILTON_CDP = "85140"
WINCHESTER_CDP = "85460"
WOLFEBORO_CDP = "86340"
WOODSVILLE_CDP = "87140"
