# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Puerto Rico."""


ACEITUNAS_COMUNIDAD = "00186"
ADJUNTAS_ZONA_URBANA = "00358"
AGUADA_ZONA_URBANA = "00616"
AGUADILLA_ZONA_URBANA = "00745"
AGUAS_BUENAS_ZONA_URBANA = "00874"
AGUAS_CLARAS_COMUNIDAD = "01003"
AGUILITA_COMUNIDAD = "01089"
AIBONITO_ZONA_URBANA = "01218"
ALIANZA_COMUNIDAD = "01863"
ANIMAS_COMUNIDAD = "03024"
ANON_RAICES_COMUNIDAD = "03174"
ANTON_RUIZ_COMUNIDAD = "03196"
ARECIBO_ZONA_URBANA = "03368"
ARROYO_ZONA_URBANA = "03927"
ANASCO_ZONA_URBANA = "02680"
BAIROA_LA_VEINTICINCO_COMUNIDAD = "04620"
BAJADERO_COMUNIDAD = "04658"
BAJANDAS_COMUNIDAD = "04701"
BARAHONA_COMUNIDAD = "05217"
BARCELONETA_ZONA_URBANA = "05346"
BARRANQUITAS_ZONA_URBANA = "05690"
BARTOLO_COMUNIDAD = "06421"
BAYAMON_COMUNIDAD = "06679"
BAYAMON_ZONA_URBANA = "06593"
BENITEZ_COMUNIDAD = "07496"
BETANCES_COMUNIDAD = "07668"
BOQUERON_COMUNIDAD_CABO_ROJO_MUNICIPIO = "07969"
BOQUERON_COMUNIDAD_LAS_PIEDRAS_MUNICIPIO = "08099"
BRENAS_COMUNIDAD = "08700"
BRISAS_DEL_CAMPANERO_COMUNIDAD = "08722"
BUENA_VISTA_COMUNIDAD_ARROYO_MUNICIPIO = "09087"
BUENA_VISTA_COMUNIDAD_HUMACAO_MUNICIPIO = "09250"
BÚFALO_COMUNIDAD = "09603"
CABO_ROJO_ZONA_URBANA = "09861"
CABAN_COMUNIDAD = "09689"
CACAO_COMUNIDAD = "10048"
CAGUAS_ZONA_URBANA = "10334"
CALZADA_COMUNIDAD = "11151"
CAMBALACHE_COMUNIDAD = "11345"
CAMPANILLA_COMUNIDAD = "11581"
CAMPANILLAS_COMUNIDAD = "11597"
CAMPO_RICO_COMUNIDAD = "11710"
CAMUY_ZONA_URBANA = "11925"
CANDELARIA_ARENAS_COMUNIDAD = "12560"
CANDELARIA_COMUNIDAD = "12441"
CANDELERO_ABAJO_COMUNIDAD = "12568"
CANDELERO_ARRIBA_COMUNIDAD = "12613"
CANOVANILLAS_COMUNIDAD = "13065"
CANOVANAS_ZONA_URBANA = "12828"
CAPITANEJO_COMUNIDAD = "13925"
CAROLINA_ZONA_URBANA = "14290"
CARRIZALES_COMUNIDAD = "14634"
CATANO_ZONA_URBANA = "15193"
CAYEY_ZONA_URBANA = "15494"
CAYUCO_COMUNIDAD = "15623"
CANO_MARTIN_PENA_COMUNIDAD = "12806"
CEIBA_COMUNIDAD = "16139"
CEIBA_ZONA_URBANA = "15924"
CELADA_COMUNIDAD = "16440"
CENTRAL_AGUIRRE_COMUNIDAD = "16526"
CERRILLOS_HOYOS_COMUNIDAD = "17050"
CIALES_ZONA_URBANA = "17773"
CIDRA_ZONA_URBANA = "18074"
COAMO_ZONA_URBANA = "18719"
COCO_COMUNIDAD = "18891"
COMERIO_ZONA_URBANA = "19665"
COMUNAS_COMUNIDAD = "19837"
COQUI_COMUNIDAD = "20310"
CORAZON_COMUNIDAD = "20353"
CORCOVADO_COMUNIDAD = "20482"
COROZAL_ZONA_URBANA = "20783"
CORRAL_VIEJO_COMUNIDAD = "20998"
COTO_LAUREL_COMUNIDAD = "21213"
COTO_NORTE_COMUNIDAD = "21385"
CULEBRA_ZONA_URBANA = "22589"
DAGUAO_COMUNIDAD = "23062"
DEL_CARMEN_COMUNIDAD = "23341"
DORADO_ZONA_URBANA = "24008"
DUQUE_COMUNIDAD = "24395"
EL_COMBATE_COMUNIDAD = "24954"
EL_MANGO_COMUNIDAD = "25556"
EL_NEGRO_COMUNIDAD = "25685"
EL_OJO_COMUNIDAD = "25771"
EL_PARAISO_COMUNIDAD = "25835"
EL_TUMBAO_COMUNIDAD = "26287"
EL_VEINTISÉIS_COMUNIDAD = "26362"
EMAJAGUA_COMUNIDAD = "26502"
ESPERANZA_COMUNIDAD = "27190"
ESPINO_COMUNIDAD = "27263"
FAJARDO_ZONA_URBANA = "27964"
FERRER_COMUNIDAD = "28367"
FLORIDA_ZONA_URBANA = "28824"
FRONTON_COMUNIDAD = "29682"
FRANQUEZ_COMUNIDAD = "29555"
FUIG_COMUNIDAD = "29727"
G_L_GARCIA_COMUNIDAD = "30544"
GALATEO_COMUNIDAD = "29813"
GARROCHALES_COMUNIDAD = "30372"
GUAYABAL_COMUNIDAD = "31877"
GUAYAMA_ZONA_URBANA = "32221"
GUAYANILLA_ZONA_URBANA = "32307"
GUAYNABO_ZONA_URBANA = "32522"
GURABO_ZONA_URBANA = "32823"
GUANICA_ZONA_URBANA = "31189"
H_RIVERA_COLON_COMUNIDAD = "35403"
HACIENDA_SAN_JOSÉ_COMUNIDAD = "33184"
HATILLO_ZONA_URBANA = "33296"
HATO_ARRIBA_COMUNIDAD = "33597"
HATO_CANDAL_COMUNIDAD = "33683"
HATO_VIEJO_COMUNIDAD = "34242"
HONDURAS_COMUNIDAD = "34914"
HORMIGUEROS_ZONA_URBANA = "35059"
HUMACAO_ZONA_URBANA = "35532"
IMBÉRY_COMUNIDAD = "35962"
INDIOS_COMUNIDAD = "36177"
INGENIO_COMUNIDAD = "36263"
ISABELA_ZONA_URBANA = "36478"
ISLETA_COMUNIDAD = "36779"
JAGUAL_COMUNIDAD = "37166"
JAGUAS_COMUNIDAD = "37336"
JAUCA_COMUNIDAD = "38241"
JAYUYA_ZONA_URBANA = "38370"
JOBOS_COMUNIDAD = "38671"
JUANA_DIAZ_ZONA_URBANA = "38972"
JUNCAL_COMUNIDAD = "39470"
JUNCOS_ZONA_URBANA = "39574"
LA_ALIANZA_COMUNIDAD = "39875"
LA_DOLORES_COMUNIDAD = "40348"
LA_FERMINA_COMUNIDAD = "40563"
LA_LIGA_COMUNIDAD = "41274"
LA_LUISA_COMUNIDAD = "41294"
LA_PARGUERA_COMUNIDAD = "41767"
LA_PICA_COMUNIDAD = "41810"
LA_PLAYA_COMUNIDAD = "42068"
LA_PLENA_COMUNIDAD = "42197"
LA_YUCA_COMUNIDAD = "45170"
LAJAS_ZONA_URBANA = "40950"
LAMBOGLIA_COMUNIDAD = "41466"
LARES_ZONA_URBANA = "42498"
LAS_CAROLINAS_COMUNIDAD = "42842"
LAS_CROABAS_COMUNIDAD = "43057"
LAS_GAVIOTAS_COMUNIDAD = "43294"
LAS_MARIAS_COMUNIDAD = "43702"
LAS_MARIAS_ZONA_URBANA = "43788"
LAS_OCHENTA_COMUNIDAD = "44003"
LAS_OLLAS_COMUNIDAD = "44089"
LAS_PIEDRAS_ZONA_URBANA = "44390"
LASSALLE_COMUNIDAD = "44507"
LIBORIO_NEGRON_TORRES_COMUNIDAD = "45379"
LLUVERAS_COMUNIDAD = "46282"
LOMAS_VERDES_COMUNIDAD = "46800"
LOMAS_COMUNIDAD = "46626"
LOS_HÉROES_COMUNIDAD = "46960"
LOS_LLANOS_COMUNIDAD = "47013"
LOS_PANES_COMUNIDAD = "47336"
LOS_PRADOS_COMUNIDAD = "47422"
LOIZA_ZONA_URBANA = "46368"
LUIS_LLORÉNS_TORRES_COMUNIDAD = "47615"
LUIS_M_CINTRON_COMUNIDAD = "47701"
LUQUILLO_ZONA_URBANA = "47787"
LUYANDO_COMUNIDAD = "47873"
MAGAS_ARRIBA_COMUNIDAD = "48604"
MAGUAYO_COMUNIDAD = "48862"
MANATI_ZONA_URBANA = "50152"
MANSION_DEL_MAR_COMUNIDAD = "50260"
MANSION_DEL_SOL_COMUNIDAD = "50270"
MARIANO_COLON_COMUNIDAD = "51055"
MARICAO_ZONA_URBANA = "51270"
MARTORELL_COMUNIDAD = "51657"
MARUENO_COMUNIDAD = "51700"
MARIA_ANTONIA_COMUNIDAD = "50754"
MAUNABO_ZONA_URBANA = "52345"
MAYAGUEZ_ZONA_URBANA = "52431"
MIRANDA_COMUNIDAD = "53678"
MOCA_ZONA_URBANA = "53807"
MONSERRATE_COMUNIDAD = "53979"
MONTE_GRANDE_COMUNIDAD = "54366"
MONTE_VERDE_COMUNIDAD = "54688"
MORA_COMUNIDAD = "54882"
MOROVIS_ZONA_URBANA = "55097"
MUCARABONES_COMUNIDAD = "55355"
NAGUABO_ZONA_URBANA = "55828"
NARANJITO_ZONA_URBANA = "56129"
OLIMPO_COMUNIDAD = "57075"
OROCOVIS_ZONA_URBANA = "57290"
PABELLONES_COMUNIDAD = "57612"
PAJONAL_COMUNIDAD = "57862"
PALMA_SOLA_COMUNIDAD = "58613"
PALMAREJO_COMUNIDAD_COAMO_MUNICIPIO = "57978"
PALMAREJO_COMUNIDAD_COROZAL_MUNICIPIO = "58064"
PALMAREJO_COMUNIDAD_LAJAS_MUNICIPIO = "58150"
PALMAS_COMUNIDAD = "58365"
PALMAS_DEL_MAR_COMUNIDAD = "58602"
PALMER_COMUNIDAD = "58666"
PALO_SECO_COMUNIDAD = "59139"
PALOMAS_COMUNIDAD_COMERIO_MUNICIPIO = "58967"
PALOMAS_COMUNIDAD_YAUCO_MUNICIPIO = "59053"
PARCELAS_LA_MILAGROSA_COMUNIDAD = "59420"
PARCELAS_MANDRY_COMUNIDAD = "59422"
PARCELAS_NUEVAS_COMUNIDAD = "59425"
PARCELAS_PENUELAS_COMUNIDAD = "59440"
PARCELAS_VIEJAS_BORINQUEN_COMUNIDAD = "59450"
PARCELAS_DE_NAVARRO_COMUNIDAD = "59386"
PASTOS_COMUNIDAD = "60257"
PATILLAS_ZONA_URBANA = "60472"
PENA_POBRE_COMUNIDAD = "60945"
PENUELAS_ZONA_URBANA = "61074"
PIEDRA_AGUZA_COMUNIDAD = "61545"
PIEDRA_GORDA_COMUNIDAD = "61590"
PINAS_COMUNIDAD = "61977"
PLAYA_FORTUNA_COMUNIDAD = "63310"
PLAYITA_CORTADA_COMUNIDAD = "63568"
PLAYITA_COMUNIDAD_SALINAS_MUNICIPIO = "63503"
PLAYITA_COMUNIDAD_YABUCOA_MUNICIPIO = "63525"
POLE_OJEA_COMUNIDAD = "63697"
PONCE_ZONA_URBANA = "63820"
POTALA_PASTILLO_COMUNIDAD = "64127"
PUEBLITO_DEL_CARMEN_COMUNIDAD = "64400"
PUEBLITO_DEL_RIO_COMUNIDAD = "64500"
PUERTO_REAL_COMUNIDAD = "65589"
PUNTA_SANTIAGO_COMUNIDAD = "66492"
PAJAROS_COMUNIDAD = "57806"
QUEBRADA_PRIETA_COMUNIDAD = "67675"
QUEBRADA_COMUNIDAD = "66660"
QUEBRADA_DEL_AGUA_COMUNIDAD = "67200"
QUEBRADILLAS_ZONA_URBANA = "68040"
RAFAEL_CAPO_COMUNIDAD = "68513"
RAFAEL_GONZALEZ_COMUNIDAD = "68556"
RAFAEL_HERNANDEZ_COMUNIDAD = "68599"
RAMOS_COMUNIDAD = "68771"
RINCON_COMUNIDAD = "69488"
RINCON_ZONA_URBANA = "69588"
RODRIGUEZ_HEVIA_COMUNIDAD = "71996"
ROSA_SANCHEZ_COMUNIDAD = "72555"
RIO_BLANCO_COMUNIDAD = "70448"
RIO_CANAS_ABAJO_COMUNIDAD = "70706"
RIO_GRANDE_ZONA_URBANA = "71136"
RIO_LAJAS_COMUNIDAD = "71437"
SABANA_ENEAS_COMUNIDAD = "73372"
SABANA_GRANDE_ZONA_URBANA = "73544"
SABANA_HOYOS_COMUNIDAD = "73716"
SABANA_SECA_COMUNIDAD = "74189"
SABANA_COMUNIDAD = "73200"
SALINAS_ZONA_URBANA = "74877"
SAN_ANTONIO_COMUNIDAD_AGUADILLA_MUNICIPIO = "75608"
SAN_ANTONIO_COMUNIDAD_DORADO_MUNICIPIO = "75694"
SAN_ANTONIO_COMUNIDAD_QUEBRADILLAS_MUNICIPIO = "75780"
SAN_GERMAN_ZONA_URBANA = "76167"
SAN_ISIDRO_COMUNIDAD = "76339"
SAN_JOSÉ_COMUNIDAD = "76683"
SAN_JUAN_ZONA_URBANA = "76770"
SAN_LORENZO_ZONA_URBANA = "77027"
SAN_SEBASTIAN_ZONA_URBANA = "77500"
SANTA_BARBARA_COMUNIDAD = "77672"
SANTA_CLARA_COMUNIDAD = "77826"
SANTA_ISABEL_ZONA_URBANA = "78145"
SANTA_MARIA_COMUNIDAD = "78317"
SANTO_DOMINGO_COMUNIDAD = "79564"
STELLA_COMUNIDAD = "80596"
SUAREZ_COMUNIDAD = "80639"
TALLABOA_ALTA_COMUNIDAD = "81456"
TALLABOA_COMUNIDAD = "81413"
TIBES_COMUNIDAD = "82055"
TIBURONES_COMUNIDAD = "82125"
TIERRAS_NUEVAS_PONIENTE_COMUNIDAD = "82187"
TOA_ALTA_ZONA_URBANA = "82488"
TOA_BAJA_ZONA_URBANA = "82617"
TOAVILLE_COMUNIDAD = "82692"
TOMAS_DE_CASTRO_COMUNIDAD = "82875"
TRUJILLO_ALTO_ZONA_URBANA = "83606"
UTUADO_ZONA_URBANA = "84509"
VALLE_HILL_COMUNIDAD = "84917"
VAYAS_COMUNIDAD = "85025"
VEGA_ALTA_ZONA_URBANA = "85197"
VEGA_BAJA_ZONA_URBANA = "85326"
VIEQUES_COMUNIDAD = "85971"
VIEQUES_ZONA_URBANA = "86014"
VILLA_CALMA_COMUNIDAD = "86250"
VILLA_ESPERANZA_COMUNIDAD = "86584"
VILLA_HUGO_I_COMUNIDAD = "86788"
VILLA_HUGO_II_COMUNIDAD = "86796"
VILLA_QUINTERO_COMUNIDAD = "87240"
VILLA_SIN_MIEDO_COMUNIDAD = "87282"
VILLA_DE_SABANA_COMUNIDAD = "86509"
VILLALBA_ZONA_URBANA = "86831"
VILLAS_DEL_SOL_COMUNIDAD = "87272"
VOLADORAS_COMUNIDAD = "87638"
VAZQUEZ_COMUNIDAD = "85111"
YABUCOA_ZONA_URBANA = "87863"
YAUCO_ZONA_URBANA = "88035"
YAUREL_COMUNIDAD = "88121"
YEGUADA_COMUNIDAD = "88293"
