# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Virginia."""


ACCOMACK = "001"
ALBEMARLE = "003"
ALEXANDRIA_CITY = "510"
ALLEGHANY = "005"
AMELIA = "007"
AMHERST = "009"
APPOMATTOX = "011"
ARLINGTON = "013"
AUGUSTA = "015"
BATH = "017"
BEDFORD = "019"
BLAND = "021"
BOTETOURT = "023"
BRISTOL_CITY = "520"
BRUNSWICK = "025"
BUCHANAN = "027"
BUCKINGHAM = "029"
BUENA_VISTA_CITY = "530"
CAMPBELL = "031"
CAROLINE = "033"
CARROLL = "035"
CHARLES_CITY = "036"
CHARLOTTE = "037"
CHARLOTTESVILLE_CITY = "540"
CHESAPEAKE_CITY = "550"
CHESTERFIELD = "041"
CLARKE = "043"
COLONIAL_HEIGHTS_CITY = "570"
COVINGTON_CITY = "580"
CRAIG = "045"
CULPEPER = "047"
CUMBERLAND = "049"
DANVILLE_CITY = "590"
DICKENSON = "051"
DINWIDDIE = "053"
EMPORIA_CITY = "595"
ESSEX = "057"
FAIRFAX = "059"
FAIRFAX_CITY = "600"
FALLS_CHURCH_CITY = "610"
FAUQUIER = "061"
FLOYD = "063"
FLUVANNA = "065"
FRANKLIN = "067"
FRANKLIN_CITY = "620"
FREDERICK = "069"
FREDERICKSBURG_CITY = "630"
GALAX_CITY = "640"
GILES = "071"
GLOUCESTER = "073"
GOOCHLAND = "075"
GRAYSON = "077"
GREENE = "079"
GREENSVILLE = "081"
HALIFAX = "083"
HAMPTON_CITY = "650"
HANOVER = "085"
HARRISONBURG_CITY = "660"
HENRICO = "087"
HENRY = "089"
HIGHLAND = "091"
HOPEWELL_CITY = "670"
ISLE_OF_WIGHT = "093"
JAMES_CITY = "095"
KING_GEORGE = "099"
KING_WILLIAM = "101"
KING_AND_QUEEN = "097"
LANCASTER = "103"
LEE = "105"
LEXINGTON_CITY = "678"
LOUDOUN = "107"
LOUISA = "109"
LUNENBURG = "111"
LYNCHBURG_CITY = "680"
MADISON = "113"
MANASSAS_PARK_CITY = "685"
MANASSAS_CITY = "683"
MARTINSVILLE_CITY = "690"
MATHEWS = "115"
MECKLENBURG = "117"
MIDDLESEX = "119"
MONTGOMERY = "121"
NELSON = "125"
NEW_KENT = "127"
NEWPORT_NEWS_CITY = "700"
NORFOLK_CITY = "710"
NORTHAMPTON = "131"
NORTHUMBERLAND = "133"
NORTON_CITY = "720"
NOTTOWAY = "135"
ORANGE = "137"
PAGE = "139"
PATRICK = "141"
PETERSBURG_CITY = "730"
PITTSYLVANIA = "143"
POQUOSON_CITY = "735"
PORTSMOUTH_CITY = "740"
POWHATAN = "145"
PRINCE_EDWARD = "147"
PRINCE_GEORGE = "149"
PRINCE_WILLIAM = "153"
PULASKI = "155"
RADFORD_CITY = "750"
RAPPAHANNOCK = "157"
RICHMOND = "159"
RICHMOND_CITY = "760"
ROANOKE = "161"
ROANOKE_CITY = "770"
ROCKBRIDGE = "163"
ROCKINGHAM = "165"
RUSSELL = "167"
SALEM_CITY = "775"
SCOTT = "169"
SHENANDOAH = "171"
SMYTH = "173"
SOUTHAMPTON = "175"
SPOTSYLVANIA = "177"
STAFFORD = "179"
STAUNTON_CITY = "790"
SUFFOLK_CITY = "800"
SURRY = "181"
SUSSEX = "183"
TAZEWELL = "185"
VIRGINIA_BEACH_CITY = "810"
WARREN = "187"
WASHINGTON = "191"
WAYNESBORO_CITY = "820"
WESTMORELAND = "193"
WILLIAMSBURG_CITY = "830"
WINCHESTER_CITY = "840"
WISE = "195"
WYTHE = "197"
YORK = "199"
