# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Kentucky."""


ADAIRVILLE_CITY = "00298"
AGES_CDP = "00514"
ALBANY_CITY = "00694"
ALEXANDRIA_CITY = "00802"
ALLEN_CITY = "00946"
ALLENSVILLE_CDP = "01000"
ANCHORAGE_CITY = "01504"
ANNVILLE_CDP = "01648"
ANTHOSTON_CDP = "01720"
ARJAY_CDP = "01972"
ARLINGTON_CITY = "02044"
ARTEMUS_CDP = "02188"
ASHLAND_CITY = "02368"
AUBURN_CITY = "02638"
AUDUBON_PARK_CITY = "02656"
AUGUSTA_CITY = "02674"
AUXIER_CDP = "02764"
BANCROFT_CITY = "03376"
BANDANA_CDP = "03412"
BARBOURMEADE_CITY = "03556"
BARBOURVILLE_CITY = "03574"
BARDSTOWN_CITY = "03628"
BARDWELL_CITY = "03664"
BARLOW_CITY = "03718"
BEATTYVILLE_CITY = "04546"
BEAVER_DAM_CITY = "04654"
BEDFORD_CITY = "04816"
BEECH_GROVE_CDP = "04978"
BEECHMONT_CDP = "05014"
BEECHWOOD_VILLAGE_CITY = "05068"
BELFRY_CDP = "05266"
BELLEFONTE_CITY = "05374"
BELLEMEADE_CITY = "05392"
BELLEVIEW_CDP = "05428"
BELLEVUE_CITY = "05446"
BELLEWOOD_CITY = "05464"
BENHAM_CITY = "05662"
BENTON_CITY = "05824"
BEREA_CITY = "05842"
BERRY_CITY = "05968"
BETSY_LAYNE_CDP = "06220"
BIG_CLIFTY_CDP = "06508"
BLACKEY_CITY = "07012"
BLAINE_CITY = "07264"
BLANDVILLE_CITY = "07390"
BLOOMFIELD_CITY = "07516"
BLUE_RIDGE_MANOR_CITY = "07858"
BONNIEVILLE_CITY = "08488"
BOONEVILLE_CITY = "08614"
BOSTON_CDP = "08722"
BOWLING_GREEN_CITY = "08902"
BRADFORDSVILLE_CITY = "09100"
BRANDENBURG_CITY = "09226"
BRECKINRIDGE_CENTER_CDP = "09379"
BREMEN_CITY = "09406"
BRIARWOOD_CITY = "09532"
BRODHEAD_CITY = "09838"
BROECK_POINTE_CITY = "09847"
BROMLEY_CITY = "09856"
BROOKS_CDP = "09964"
BROOKSVILLE_CITY = "10000"
BROWNSBORO_FARM_CITY = "10162"
BROWNSBORO_VILLAGE_CITY = "10198"
BROWNSVILLE_CITY = "10324"
BUCKHORN_CITY = "10612"
BUCKNER_CDP = "10648"
BUFFALO_CDP = "10774"
BURGIN_CITY = "11044"
BURKESVILLE_CITY = "11098"
BURLINGTON_CDP = "11170"
BURNA_CDP = "11188"
BURNSIDE_CITY = "11278"
BUTLER_CITY = "11530"
CADIZ_CITY = "11692"
CALHOUN_CITY = "11854"
CALIFORNIA_CITY = "11872"
CALVERT_CITY_CITY = "12016"
CAMARGO_CITY = "12052"
CAMBRIDGE_CITY = "12066"
CAMPBELLSBURG_CITY = "12142"
CAMPBELLSVILLE_CITY = "12160"
CAMPTON_CITY = "12358"
CANEYVILLE_CITY = "12538"
CANNONSBURG_CDP = "12610"
CARLISLE_CITY = "12898"
CARROLLTON_CITY = "13024"
CARRSVILLE_CITY = "13060"
CATLETTSBURG_CITY = "13420"
CAVE_CITY_CITY = "13492"
CAWOOD_CDP = "13582"
CAYCE_CDP = "13600"
CECILIA_CDP = "13636"
CENTERTOWN_CITY = "13870"
CENTRAL_CITY_CITY = "13978"
CERULEAN_CDP = "14068"
CHAPLIN_CDP = "14266"
CLARKSON_CITY = "15148"
CLARYVILLE_CDP = "15166"
CLAY_CITY_CITY = "15238"
CLAY_CITY = "15202"
CLEATON_CDP = "15490"
CLINTON_CITY = "15742"
CLOVERPORT_CITY = "15904"
COAL_RUN_VILLAGE_CITY = "16110"
COLD_SPRING_CITY = "16372"
COLDIRON_CDP = "16354"
COLDSTREAM_CITY = "16395"
COLUMBIA_CITY = "16750"
COLUMBUS_CITY = "16768"
COMBS_CDP = "16822"
CONCORD_CITY = "16894"
CORBIN_CITY = "17362"
CORINTH_CITY = "17434"
CORYDON_CITY = "17686"
COVINGTON_CITY = "17848"
COXTON_CDP = "17938"
CRAB_ORCHARD_CITY = "17956"
CRAYNE_CDP = "18190"
CREEKSIDE_CITY = "18270"
CRESCENT_SPRINGS_CITY = "18352"
CRESTVIEW_HILLS_CITY = "18442"
CRESTVIEW_CITY = "18424"
CRESTWOOD_CITY = "18496"
CRITTENDEN_CITY = "18568"
CROFTON_CITY = "18658"
CROSSGATE_CITY = "18766"
CUMBERLAND_CITY = "19108"
CUNNINGHAM_CDP = "19234"
CURDSVILLE_CDP = "19288"
CYNTHIANA_CITY = "19432"
DANVILLE_CITY = "19882"
DAWSON_SPRINGS_CITY = "20224"
DAYTON_CITY = "20350"
DEXTER_CDP = "21322"
DIABLOCK_CDP = "21358"
DIXON_CITY = "21682"
DOE_VALLEY_CDP = "21844"
DOUGLASS_HILLS_CITY = "22204"
DOVER_CITY = "22222"
DRAKESBORO_CITY = "22348"
DRUID_HILLS_CITY = "22474"
DRY_RIDGE_CITY = "22582"
DUNMOR_CDP = "23014"
DWALE_CDP = "23104"
EARLINGTON_CITY = "23230"
EAST_BERNSTADT_CDP = "23284"
EDDYVILLE_CITY = "23824"
EDGEWOOD_CITY = "23932"
EDMONTON_CITY = "23968"
EKRON_CITY = "24094"
ELIZABETHTOWN_CITY = "24274"
ELIZAVILLE_CDP = "24292"
ELK_CREEK_CDP = "24328"
ELKHORN_CITY_CITY = "24382"
ELKTON_CITY = "24400"
ELSMERE_CITY = "24778"
EMINENCE_CITY = "24904"
EMLYN_CDP = "24922"
ERLANGER_CITY = "25300"
EUBANK_CITY = "25552"
EVARTS_CITY = "25606"
EWING_CITY = "25786"
EZEL_CDP = "25876"
FAIRFIELD_CITY = "26020"
FAIRVIEW_CDP = "26182"
FAIRVIEW_CITY = "26236"
FALMOUTH_CITY = "26434"
FANCY_FARM_CDP = "26452"
FARLEY_CDP = "26528"
FARMERS_CDP = "26560"
FARMINGTON_CDP = "26614"
FERGUSON_CITY = "27010"
FINCASTLE_CITY = "27262"
FLAT_LICK_CDP = "27730"
FLATWOODS_CITY = "27802"
FLEMING_NEON_CITY = "27846"
FLEMINGSBURG_CITY = "27856"
FLORENCE_CITY = "27982"
FORDSVILLE_CITY = "28270"
FOREST_HILLS_CITY = "28342"
FORT_CAMPBELL_NORTH_CDP = "28486"
FORT_KNOX_CDP = "28540"
FORT_MITCHELL_CITY = "28558"
FORT_THOMAS_CITY = "28594"
FORT_WRIGHT_CITY = "28612"
FOUNTAIN_RUN_CITY = "28666"
FOX_CHASE_CITY = "28785"
FRANCISVILLE_CDP = "28882"
FRANKFORT_CITY = "28900"
FRANKLIN_CITY = "28918"
FREDONIA_CITY = "29080"
FREEBURN_CDP = "29134"
FRENCHBURG_CITY = "29260"
FULTON_CITY = "29566"
GAMALIEL_CITY = "29872"
GARRISON_CDP = "30232"
GEORGETOWN_CITY = "30700"
GERMANTOWN_CITY = "30718"
GHENT_CITY = "30808"
GILBERTSVILLE_CDP = "30880"
GLASGOW_CITY = "31114"
GLENCOE_CITY = "31204"
GLENVIEW_HILLS_CITY = "31402"
GLENVIEW_MANOR_CITY = "31420"
GLENVIEW_CITY = "31348"
GOOSE_CREEK_CITY = "31870"
GOSHEN_CITY = "31960"
GRACEY_CDP = "32032"
GRAND_RIVERS_CITY = "32212"
GRATZ_CITY = "32428"
GRAYMOOR_DEVONDALE_CITY = "32523"
GRAYSON_CITY = "32572"
GREEN_SPRING_CITY = "32986"
GREENSBURG_CITY = "32968"
GREENUP_CITY = "33004"
GREENVILLE_CITY = "33022"
GUTHRIE_CITY = "33562"
HANSON_CITY = "34390"
HARDIN_CITY = "34534"
HARDINSBURG_CITY = "34552"
HARDYVILLE_CDP = "34660"
HARLAN_CITY = "34732"
HARRODSBURG_CITY = "34966"
HARTFORD_CITY = "35020"
HAWESVILLE_CITY = "35200"
HAZARD_CITY = "35362"
HAZEL_GREEN_CDP = "35398"
HAZEL_CITY = "35380"
HEBRON_CDP = "35542"
HEBRON_ESTATES_CITY = "35545"
HENDERSON_CITY = "35866"
HENDRON_CDP = "35902"
HERITAGE_CREEK_CITY = "36102"
HICKMAN_CITY = "36298"
HICKORY_CDP = "36316"
HICKORY_HILL_CITY = "36374"
HIGH_BRIDGE_CDP = "36460"
HIGHLAND_HEIGHTS_CITY = "36604"
HILLS_AND_DALES_CITY = "36865"
HILLVIEW_CITY = "36982"
HINDMAN_CITY = "37108"
HISEVILLE_CDP = "37234"
HODGENVILLE_CITY = "37396"
HOLLOW_CREEK_CITY = "37576"
HOLLYVILLA_CITY = "37630"
HOPKINSVILLE_CITY = "37918"
HORSE_CAVE_CITY = "38008"
HOUSTON_ACRES_CITY = "38170"
HUNTERS_HOLLOW_CITY = "38670"
HURSTBOURNE_ACRES_CITY = "38818"
HURSTBOURNE_CITY = "38814"
HUSTONVILLE_CITY = "38836"
HYDEN_CITY = "38908"
INDEPENDENCE_CITY = "39142"
INDIAN_HILLS_CITY = "39304"
INEZ_CITY = "39430"
IRONVILLE_CDP = "39592"
IRVINE_CITY = "39646"
IRVINGTON_CITY = "39664"
ISLAND_CITY = "39700"
JACKSON_CITY = "39952"
JAMESTOWN_CITY = "40114"
JEFF_CDP = "40204"
JEFFERSONTOWN_CITY = "40222"
JEFFERSONVILLE_CITY = "40240"
JENKINS_CITY = "40312"
JUNCTION_CITY_CITY = "41338"
KEENE_CITY = "41716"
KENTON_VALE_CITY = "42094"
KENVIR_CDP = "42112"
KEVIL_CITY = "42292"
KINGSLEY_CITY = "42598"
KNOTTSVILLE_CDP = "43030"
KUTTAWA_CITY = "43264"
LA_CENTER_CITY = "43336"
LA_GRANGE_CITY = "43480"
LAFAYETTE_CITY = "43444"
LAKESIDE_PARK_CITY = "43606"
LAKEVIEW_HEIGHTS_CITY = "43668"
LANCASTER_CITY = "43840"
LANGDON_PLACE_CITY = "43900"
LAWRENCEBURG_CITY = "44146"
LEBANON_JUNCTION_CITY = "44362"
LEBANON_CITY = "44344"
LEDBETTER_CDP = "44434"
LEITCHFIELD_CITY = "44686"
LEWISBURG_CITY = "45064"
LEWISPORT_CITY = "45136"
LEXINGTON_FAYETTE_URBAN_COUNTY = "46027"
LIBERTY_CITY = "46072"
LINCOLNSHIRE_CITY = "46540"
LIVERMORE_CITY = "47062"
LIVINGSTON_CITY = "47098"
LONDON_CITY = "47476"
LORETTO_CITY = "47710"
LOUISA_CITY = "47854"
LOUISVILLE_JEFFERSON_COUNTY_METRO_GOVERNMENT_BALANCE = "48006"
LOVELACEVILLE_CDP = "48072"
LOWES_CDP = "48234"
LOYALL_CITY = "48288"
LUDLOW_CITY = "48378"
LYNCH_CITY = "48540"
LYNDON_CITY = "48558"
LYNNVIEW_CITY = "48648"
MACEO_CDP = "49026"
MACKVILLE_CITY = "49206"
MADISONVILLE_CITY = "49368"
MAGNOLIA_CDP = "49476"
MANCHESTER_CITY = "49656"
MANITOU_CDP = "49746"
MANOR_CREEK_CITY = "49800"
MARION_CITY = "50034"
MARROWBONE_CDP = "50124"
MARTIN_CITY = "50286"
MARYHILL_ESTATES_CITY = "50412"
MASONVILLE_CDP = "50520"
MASSAC_CDP = "50556"
MAYFIELD_CITY = "50898"
MAYKING_CDP = "50952"
MAYS_LICK_CDP = "51006"
MAYSVILLE_CITY = "51024"
MAYTOWN_CDP = "51042"
MCCARR_CDP = "48810"
MCDOWELL_CDP = "48954"
MCHENRY_CITY = "49098"
MCKEE_CITY = "49116"
MCKINNEY_CDP = "49134"
MCROBERTS_CDP = "49278"
MEADOW_VALE_CITY = "51258"
MEADOWBROOK_FARM_CITY = "51193"
MEADOWVIEW_ESTATES_CITY = "51294"
MELBOURNE_CITY = "51438"
MENTOR_CITY = "51564"
MIDDLESBOROUGH_CITY = "51924"
MIDDLETOWN_CITY = "51978"
MIDWAY_CITY = "52140"
MILLERSBURG_CITY = "52302"
MILLSTONE_CDP = "52464"
MILTON_CITY = "52590"
MOCKINGBIRD_VALLEY_CITY = "52842"
MONTEREY_CITY = "53076"
MONTICELLO_CITY = "53130"
MOORLAND_CITY = "53328"
MOREHEAD_CITY = "53418"
MORGANFIELD_CITY = "53472"
MORGANTOWN_CITY = "53490"
MORTONS_GAP_CITY = "53616"
MOSELEYVILLE_CDP = "53670"
MOUNT_OLIVET_CITY = "53976"
MOUNT_STERLING_CITY = "54084"
MOUNT_VERNON_CITY = "54174"
MOUNT_WASHINGTON_CITY = "54228"
MULDRAUGH_CITY = "54480"
MUNFORDVILLE_CITY = "54570"
MURRAY_HILL_CITY = "54660"
MURRAY_CITY = "54642"
NEBO_CITY = "55092"
NEW_CASTLE_CITY = "55596"
NEW_HAVEN_CITY = "55758"
NEW_HOPE_CDP = "55794"
NEWPORT_CITY = "55884"
NICHOLASVILLE_CITY = "56136"
NORBOURNE_ESTATES_CITY = "56550"
NORTH_CORBIN_CDP = "56694"
NORTH_MIDDLETOWN_CITY = "56820"
NORTHFIELD_CITY = "56730"
NORTONVILLE_CITY = "56910"
NORWOOD_CITY = "56928"
OAK_GROVE_CITY = "57090"
OAKBROOK_CDP = "57030"
OAKLAND_CITY = "57144"
OLD_BROWNSBORO_PLACE_CITY = "57658"
OLIVE_HILL_CITY = "57918"
ONEIDA_CDP = "58062"
ONTON_CDP = "58116"
ORCHARD_GRASS_HILLS_CITY = "58200"
OWENSBORO_CITY = "58620"
OWENTON_CITY = "58692"
OWINGSVILLE_CITY = "58710"
PADUCAH_CITY = "58836"
PAINTSVILLE_CITY = "58962"
PANTHER_CDP = "59124"
PARIS_CITY = "59196"
PARK_CITY_CITY = "59232"
PARK_HILLS_CITY = "59255"
PARKWAY_VILLAGE_CITY = "59322"
PATHFORK_CDP = "59466"
PAYNE_GAP_CDP = "59592"
PEMBROKE_CITY = "59934"
PERRYVILLE_CITY = "60258"
PETERSBURG_CDP = "60312"
PEWEE_VALLEY_CITY = "60492"
PHELPS_CDP = "60600"
PHILPOT_CDP = "60654"
PIKEVILLE_CITY = "60852"
PINE_KNOT_CDP = "61122"
PINEVILLE_CITY = "61248"
PIONEER_VILLAGE_CITY = "61356"
PIPPA_PASSES_CITY = "61374"
PLANO_CDP = "61536"
PLANTATION_CITY = "61554"
PLEASANT_RIDGE_CDP = "61680"
PLEASANT_VIEW_CDP = "61734"
PLEASUREVILLE_CITY = "61788"
PLUM_SPRINGS_CITY = "61860"
POOLE_CDP = "62202"
POPLAR_HILLS_CITY = "62370"
POWDERLY_CITY = "62652"
PRESTONSBURG_CITY = "62940"
PRESTONVILLE_CITY = "62958"
PRINCETON_CITY = "63138"
PROSPECT_CITY = "63264"
PROVIDENCE_CITY = "63372"
PRYORSBURG_CDP = "63426"
RABBIT_HASH_CDP = "63804"
RACELAND_CITY = "63858"
RADCLIFF_CITY = "63912"
RAVENNA_CITY = "64092"
RAYWICK_CITY = "64146"
REIDLAND_CDP = "64632"
RICHLAWN_CITY = "65208"
RICHMOND_CITY = "65226"
RINEYVILLE_CDP = "65388"
RIVER_BLUFF_CITY = "65559"
RIVERWOOD_CITY = "65766"
ROBARDS_CITY = "65874"
ROCHESTER_CITY = "65982"
ROCKHOLDS_CDP = "66162"
ROCKPORT_CITY = "66216"
ROLLING_FIELDS_CITY = "66486"
ROLLING_HILLS_CITY = "66504"
ROSINE_CDP = "66846"
RUSSELL_SPRINGS_CITY = "67494"
RUSSELL_CITY = "67458"
RUSSELLVILLE_CITY = "67512"
RYLAND_HEIGHTS_CITY = "67602"
SACRAMENTO_CITY = "67638"
SADIEVILLE_CITY = "67656"
SALEM_CITY = "68052"
SALT_LICK_CITY = "68160"
SALVISA_CDP = "68214"
SALYERSVILLE_CITY = "68232"
SANDERS_CITY = "68358"
SANDY_HOOK_CITY = "68556"
SARDIS_CITY = "68646"
SCIENCE_HILL_CITY = "68952"
SCOTTSVILLE_CITY = "69114"
SEBREE_CITY = "69222"
SEDALIA_CDP = "69258"
SENECA_GARDENS_CITY = "69384"
SHARPSBURG_CITY = "69852"
SHELBYVILLE_CITY = "70050"
SHEPHERDSVILLE_CITY = "70086"
SHIVELY_CITY = "70284"
SILVER_GROVE_CITY = "70644"
SIMPSONVILLE_CITY = "70752"
SLAUGHTERS_CITY = "71130"
SMITHFIELD_CITY = "71364"
SMITHLAND_CITY = "71382"
SMITHS_GROVE_CITY = "71454"
SOMERSET_CITY = "71688"
SONORA_CITY = "71724"
SORGHO_CDP = "71760"
SOUTH_CARROLLTON_CITY = "71814"
SOUTH_PARK_VIEW_CITY = "72138"
SOUTH_SHORE_CITY = "72210"
SOUTH_WALLINS_CDP = "72255"
SOUTH_WILLIAMSON_CDP = "72264"
SOUTHGATE_CITY = "71976"
SPARTA_CITY = "72372"
SPOTTSVILLE_CDP = "72570"
SPRING_MILL_CITY = "72770"
SPRING_VALLEY_CITY = "72790"
SPRINGFIELD_CITY = "72660"
ST_CHARLES_CITY = "67710"
ST_JOSEPH_CDP = "67854"
ST_MARY_CITY = "67890"
ST_MATTHEWS_CITY = "67944"
ST_REGIS_PARK_CITY = "67998"
STAMPING_GROUND_CITY = "73038"
STANFORD_CITY = "73110"
STANLEY_CDP = "73146"
STANTON_CITY = "73164"
STEARNS_CDP = "73362"
STRATHMOOR_MANOR_CITY = "74064"
STRATHMOOR_VILLAGE_CITY = "74082"
STURGIS_CITY = "74316"
SUMMER_SHADE_CDP = "74586"
SUMMERSVILLE_CDP = "74604"
SYCAMORE_CITY = "75190"
SYMSONIA_CDP = "75270"
TAYLOR_MILL_CITY = "75738"
TAYLORSVILLE_CITY = "75810"
TEN_BROECK_CITY = "75963"
THORNHILL_CITY = "76380"
THRUSTON_CDP = "76620"
TOLU_CDP = "77124"
TOMPKINSVILLE_CITY = "77160"
TRENTON_CITY = "77592"
UNION_CITY = "78384"
UNIONTOWN_CITY = "78492"
UPTON_CITY = "78672"
UTICA_CDP = "78708"
VAN_LEAR_CDP = "79194"
VANCEBURG_CITY = "79068"
VERONA_CDP = "79464"
VERSAILLES_CITY = "79482"
VICCO_CITY = "79590"
VILLA_HILLS_CITY = "79698"
VINE_GROVE_CITY = "79734"
VIRGIE_CDP = "79860"
WALLINS_CREEK_CDP = "80310"
WALTON_CITY = "80490"
WARFIELD_CITY = "80616"
WARSAW_CITY = "80706"
WATER_VALLEY_CDP = "80832"
WATTERSON_PARK_CITY = "80913"
WAVERLY_CITY = "80958"
WAYLAND_CITY = "81012"
WELLINGTON_CITY = "81372"
WEST_BUECHEL_CITY = "81624"
WEST_LIBERTY_CITY = "81858"
WEST_LOUISVILLE_CDP = "81876"
WEST_POINT_CITY = "81930"
WEST_VAN_LEAR_CDP = "82056"
WESTPORT_CDP = "81948"
WESTWOOD_CDP = "82146"
WESTWOOD_CITY = "82164"
WHEATCROFT_CITY = "82200"
WHEELWRIGHT_CITY = "82272"
WHITE_PLAINS_CITY = "82722"
WHITESBURG_CITY = "82776"
WHITESVILLE_CITY = "82830"
WHITLEY_CITY_CDP = "82938"
WICKLIFFE_CITY = "83064"
WILDER_CITY = "83172"
WILDWOOD_CITY = "83208"
WILLIAMSBURG_CITY = "83334"
WILLIAMSTOWN_CITY = "83406"
WILLISBURG_CITY = "83424"
WILMORE_CITY = "83550"
WINCHESTER_CITY = "83676"
WINDY_HILLS_CITY = "83784"
WINGO_CITY = "83856"
WOODBURN_CITY = "84414"
WOODBURY_CITY = "84432"
WOODLAND_HILLS_CITY = "84486"
WOODLAWN_PARK_CITY = "84576"
WOODLAWN_CITY = "84522"
WORTHINGTON_HILLS_CITY = "84891"
WORTHINGTON_CITY = "84864"
WORTHVILLE_CITY = "84900"
WURTLAND_CITY = "85008"
YELVINGTON_CDP = "85224"
