# Copyright (c) 2023 Darren Erik Vengroff
"""Places in North Dakota."""


ABERCROMBIE_CITY = "00100"
ADAMS_CITY = "00340"
ALAMO_CITY = "00940"
ALEXANDER_CITY = "01180"
ALICE_CITY = "01420"
ALMONT_CITY = "01700"
ALSEN_CITY = "01740"
AMBROSE_CITY = "01860"
AMENIA_CITY = "01940"
AMIDON_CITY = "02060"
ANAMOOSE_CITY = "02220"
ANETA_CITY = "02380"
ANTLER_CITY = "02660"
APPLE_VALLEY_CDP = "02820"
ARDOCH_CITY = "02860"
ARGUSVILLE_CITY = "03020"
ARNEGARD_CITY = "03220"
ARTHUR_CITY = "03300"
ASHLEY_CITY = "03540"
AUBURN_CDP = "03740"
AYR_CITY = "04020"
BALFOUR_CITY = "04460"
BALTA_CITY = "04580"
BANTRY_CDP = "04740"
BARNEY_CITY = "04940"
BARTON_CDP = "05220"
BATHGATE_CITY = "05260"
BEACH_CITY = "05420"
BELCOURT_CDP = "05740"
BELFIELD_CITY = "05820"
BENEDICT_CITY = "05980"
BERGEN_CITY = "06180"
BERLIN_CITY = "06300"
BERTHOLD_CITY = "06460"
BEULAH_CITY = "06660"
BINFORD_CITY = "07020"
BISBEE_CITY = "07180"
BISMARCK_CITY = "07200"
BLACKTAIL_CDP = "07456"
BLANCHARD_CDP = "07620"
BOTTINEAU_CITY = "08460"
BOWBELLS_CITY = "08500"
BOWDON_CITY = "08580"
BOWMAN_CITY = "08700"
BRADDOCK_CITY = "08900"
BRIARWOOD_CITY = "09320"
BRINSMADE_CITY = "09460"
BROCKET_CITY = "09700"
BROOKTREE_PARK_CDP = "09830"
BUCHANAN_CITY = "10060"
BUCYRUS_CITY = "10300"
BUFFALO_CITY = "10420"
BURLINGTON_CITY = "10940"
BUTTE_CITY = "11180"
BUXTON_CITY = "11340"
CALEDONIA_CDP = "11500"
CALIO_CITY = "11580"
CALVIN_CITY = "11700"
CANDO_CITY = "11860"
CANNON_BALL_CDP = "12020"
CANTON_CITY_HENSEL_CITY = "12060"
CARPIO_CITY = "12260"
CARRINGTON_CITY = "12340"
CARSON_CITY = "12460"
CASSELTON_CITY = "12700"
CATHAY_CITY = "12820"
CAVALIER_CITY = "12940"
CAYUGA_CITY = "13020"
CENTER_CITY = "13180"
CHRISTINE_CITY = "14100"
CHURCHS_FERRY_CITY = "14140"
CLEVELAND_CITY = "14660"
CLIFFORD_CITY = "14740"
COGSWELL_CITY = "15100"
COLEHARBOR_CITY = "15140"
COLFAX_CITY = "15180"
COLUMBUS_CITY = "15460"
CONWAY_CITY = "15820"
COOPERSTOWN_CITY = "15900"
COURTENAY_CITY = "16380"
CRARY_CITY = "16580"
CROSBY_CITY = "16940"
CRYSTAL_CITY = "17060"
DAHLEN_CDP = "17620"
DAVENPORT_CITY = "18180"
DAWSON_CITY = "18260"
DAZEY_CITY = "18340"
DE_LAMERE_CDP = "18820"
DEERING_CITY = "18620"
DENHOFF_CDP = "19060"
DES_LACS_CITY = "19300"
DEVILS_LAKE_CITY = "19420"
DICKEY_CITY = "19580"
DICKINSON_CITY = "19620"
DODGE_CITY = "19820"
DONNYBROOK_CITY = "19900"
DOUGLAS_CITY = "20020"
DRAKE_CITY = "20300"
DRAYTON_CITY = "20340"
DRISCOLL_CDP = "20500"
DUNN_CENTER_CITY = "20940"
DUNSEITH_CITY = "21020"
DWIGHT_CITY = "21220"
EAST_DUNSEITH_CDP = "21520"
EAST_FAIRVIEW_CDP = "21580"
EDGELEY_CITY = "22140"
EDINBURG_CITY = "22260"
EDMORE_CITY = "22340"
EGELAND_CITY = "22540"
ELGIN_CITY = "23020"
ELLENDALE_CITY = "23220"
ELLIOTT_CITY = "23340"
EMBDEN_CDP = "24020"
EMERADO_CITY = "24060"
ENDERLIN_CITY = "24260"
ENGLEVALE_CDP = "24380"
EPPING_CITY = "24540"
ERIE_CDP = "24620"
ESMOND_CITY = "24780"
FAIRDALE_CITY = "25180"
FAIRMOUNT_CITY = "25300"
FARGO_CITY = "25700"
FESSENDEN_CITY = "26180"
FINGAL_CITY = "26380"
FINLEY_CITY = "26420"
FLASHER_CITY = "26660"
FLAXTON_CITY = "26700"
FORBES_CITY = "26980"
FORDVILLE_CITY = "27060"
FOREST_RIVER_CITY = "27100"
FORMAN_CITY = "27260"
FORT_RANSOM_CITY = "27580"
FORT_TOTTEN_CDP = "27700"
FORT_YATES_CITY = "27860"
FORTUNA_CITY = "27820"
FOUR_BEARS_VILLAGE_CDP = "27950"
FOXHOLM_CDP = "27980"
FREDONIA_CITY = "28380"
FRONTIER_CITY = "28720"
FULLERTON_CITY = "28780"
GACKLE_CITY = "28860"
GALESBURG_CITY = "28980"
GARDENA_CITY = "29180"
GARDNER_CITY = "29220"
GARRISON_CITY = "29460"
GASCOYNE_CITY = "29540"
GILBY_CITY = "30180"
GLADSTONE_CITY = "30460"
GLEN_ULLIN_CITY = "30860"
GLENBURN_CITY = "30580"
GLENFIELD_CITY = "30660"
GOLDEN_VALLEY_CITY = "31180"
GOLVA_CITY = "31420"
GOODRICH_CITY = "31500"
GRACE_CITY_CITY = "31740"
GRAFTON_CITY = "31820"
GRAND_FORKS_AFB_CDP = "32140"
GRAND_FORKS_CITY = "32060"
GRANDIN_CITY = "32300"
GRANO_CITY = "32580"
GRANVILLE_CITY = "32660"
GREAT_BEND_CITY = "32900"
GREEN_ACRES_CDP = "33050"
GRENORA_CITY = "33500"
GWINNER_CITY = "34020"
HAGUE_CITY = "34180"
HALLIDAY_CITY = "34340"
HAMBERG_CITY = "34460"
HAMILTON_CITY = "34620"
HAMPDEN_CITY = "34860"
HANKINSON_CITY = "34900"
HANNAFORD_CITY = "35020"
HANNAH_CITY = "35060"
HANSBORO_CITY = "35140"
HARMON_CDP = "35500"
HARVEY_CITY = "35900"
HARWOOD_CITY = "35940"
HATTON_CITY = "36100"
HAVANA_CITY = "36140"
HAYNES_CITY = "36540"
HAZELTON_CITY = "36700"
HAZEN_CITY = "36780"
HEBRON_CITY = "36860"
HEIL_CDP = "36980"
HEIMDAL_CDP = "37020"
HETTINGER_CITY = "37700"
HILLSBORO_CITY = "38100"
HOOPLE_CITY = "38780"
HOPE_CITY = "38860"
HORACE_CITY = "38900"
HUNTER_CITY = "39460"
HURDSFIELD_CITY = "39580"
INKSTER_CITY = "39980"
JAMESTOWN_CITY = "40580"
JESSIE_CDP = "40740"
JUD_CITY = "41180"
KARLSRUHE_CITY = "41380"
KATHRYN_CITY = "41500"
KENMARE_CITY = "42020"
KENSAL_CITY = "42180"
KIEF_CITY = "42660"
KILLDEER_CITY = "42700"
KINDRED_CITY = "42780"
KNOX_CITY = "43260"
KRAMER_CITY = "43500"
KULM_CITY = "43580"
LAMOURE_CITY = "44540"
LAKOTA_CITY = "44300"
LANDA_CITY = "44700"
LANGDON_CITY = "44780"
LANKIN_CITY = "44860"
LANSFORD_CITY = "44900"
LARIMORE_CITY = "45020"
LARSON_CDP = "45220"
LAWTON_CITY = "45300"
LEAL_CITY = "45460"
LEEDS_CITY = "45580"
LEHR_CITY = "45740"
LEITH_CITY = "45860"
LEONARD_CITY = "45980"
LIDGERWOOD_CITY = "46460"
LIGNITE_CITY = "46540"
LINCOLN_CITY = "46640"
LINTON_CITY = "46980"
LISBON_CITY = "47100"
LITCHVILLE_CITY = "47140"
LOGAN_CDP = "47540"
LOMA_CITY = "47660"
LONG_CREEK_CDP = "47796"
LORAINE_CITY = "48020"
LUDDEN_CITY = "48460"
LUVERNE_CITY = "48580"
MADDOCK_CITY = "49620"
MAKOTI_CITY = "49820"
MANDAN_CITY = "49900"
MANDAREE_CDP = "49980"
MANNING_CDP = "50220"
MANTADOR_CITY = "50380"
MANVEL_CITY = "50420"
MAPLETON_CITY = "50580"
MARION_CITY = "50780"
MARMARTH_CITY = "50860"
MARTIN_CITY = "51060"
MAX_CITY = "51380"
MAXBASS_CITY = "51420"
MAYVILLE_CITY = "51500"
MCCLUSKY_CITY = "49020"
MCGREGOR_CDP = "49220"
MCHENRY_CITY = "49260"
MCLEOD_CDP = "49540"
MCVILLE_CITY = "49580"
MEDINA_CITY = "51860"
MEDORA_CITY = "51900"
MENOKEN_CDP = "52180"
MERCER_CITY = "52340"
MICHIGAN_CITY_CITY = "52740"
MILNOR_CITY = "52940"
MILTON_CITY = "53020"
MINNEWAUKAN_CITY = "53220"
MINOT_AFB_CDP = "53420"
MINOT_CITY = "53380"
MINTO_CITY = "53540"
MOHALL_CITY = "53780"
MONANGO_CITY = "53820"
MONTPELIER_CITY = "53980"
MOORETON_CITY = "54220"
MOTT_CITY = "54620"
MOUNTAIN_CITY = "54740"
MUNICH_CITY = "55020"
MYLO_CITY = "55220"
NAPOLEON_CITY = "55420"
NASH_CDP = "55500"
NECHE_CITY = "55620"
NEKOMA_CITY = "55740"
NEW_ENGLAND_CITY = "56180"
NEW_LEIPZIG_CITY = "56420"
NEW_ROCKFORD_CITY = "56620"
NEW_SALEM_CITY = "56700"
NEW_TOWN_CITY = "56740"
NEWBURG_CITY = "56020"
NIAGARA_CITY = "56780"
NOME_CITY = "57180"
NOONAN_CITY = "57220"
NORTH_RIVER_CITY = "58120"
NORTHWOOD_CITY = "58300"
OAKES_CITY = "58740"
OBERON_CITY = "59020"
ORISKA_CITY = "59660"
ORRIN_CDP = "59820"
OSNABROCK_CITY = "60100"
OVERLY_CITY = "60380"
OXBOW_CITY = "60480"
PAGE_CITY = "60500"
PALERMO_CITY = "60620"
PARK_RIVER_CITY = "60900"
PARSHALL_CITY = "60940"
PEKIN_CITY = "61460"
PEMBINA_CITY = "61580"
PERTH_CITY = "61780"
PETERSBURG_CITY = "61860"
PETTIBONE_CITY = "62060"
PICK_CITY_CITY = "62260"
PILLSBURY_CITY = "62540"
PINGREE_CITY = "62620"
PISEK_CITY = "62780"
PLAZA_CITY = "62980"
PORCUPINE_CDP = "63700"
PORTAL_CITY = "63740"
PORTLAND_CITY = "63900"
POWERS_LAKE_CITY = "64140"
PRAIRIE_ROSE_CITY = "64320"
RALEIGH_CDP = "65100"
RAY_CITY = "65580"
REEDER_CITY = "65900"
REGAN_CITY = "65980"
REGENT_CITY = "66020"
REILES_ACRES_CITY = "66040"
REYNOLDS_CITY = "66260"
RHAME_CITY = "66300"
RICHARDTON_CITY = "66500"
RIVERDALE_CITY = "66980"
ROBINSON_CITY = "67180"
ROCKLAKE_CITY = "67500"
ROGERS_CITY = "67620"
ROLETTE_CITY = "67780"
ROLLA_CITY = "67820"
ROSS_CITY = "68540"
RUGBY_CITY = "68860"
RUSO_CITY = "69140"
RUTHVILLE_CDP = "69300"
RUTLAND_CITY = "69340"
RYDER_CITY = "69460"
SANBORN_CITY = "70380"
SARLES_CITY = "70780"
SAWYER_CITY = "70980"
SCRANTON_CITY = "71500"
SELFRIDGE_CITY = "71660"
SELZ_CDP = "71700"
SENTINEL_BUTTE_CITY = "71780"
SHARON_CITY = "71940"
SHELDON_CITY = "72180"
SHELL_VALLEY_CDP = "72250"
SHERWOOD_CITY = "72540"
SHEYENNE_CITY = "72580"
SIBLEY_CITY = "72820"
SOLEN_CITY = "73820"
SOURIS_CITY = "74020"
SOUTH_HEART_CITY = "74185"
SPIRITWOOD_CDP = "74660"
SPIRITWOOD_LAKE_CITY = "74740"
SPRINGBROOK_CITY = "74780"
ST_JOHN_CITY = "69980"
ST_THOMAS_CITY = "70260"
STANLEY_CITY = "75380"
STANTON_CITY = "75420"
STARKWEATHER_CITY = "75580"
STEELE_CITY = "75780"
STRASBURG_CITY = "76500"
STREETER_CITY = "76620"
SURREY_CITY = "77180"
SUTTON_CDP = "77260"
SYKESTON_CITY = "77660"
TAPPEN_CITY = "77980"
TAYLOR_CITY = "78180"
THOMPSON_CITY = "78660"
TIOGA_CITY = "78940"
TOLLEY_CITY = "79140"
TOLNA_CITY = "79180"
TOWER_CITY_CITY = "79340"
TOWNER_CITY = "79420"
TRENTON_CDP = "79460"
TURTLE_LAKE_CITY = "79940"
TUTTLE_CITY = "80140"
UNDERWOOD_CITY = "80660"
UPHAM_CITY = "80860"
VALLEY_CITY_CITY = "81180"
VELVA_CITY = "81620"
VENTURIA_CITY = "81700"
VERONA_CITY = "81900"
VOLTAIRE_CITY = "82380"
WAHPETON_CITY = "82660"
WALCOTT_CITY = "82780"
WALES_CITY = "82940"
WALHALLA_CITY = "82980"
WARWICK_CITY = "83580"
WASHBURN_CITY = "83700"
WATFORD_CITY_CITY = "83860"
WEST_FARGO_CITY = "84780"
WESTHOPE_CITY = "85020"
WHEATLAND_CDP = "85180"
WHITE_EARTH_CITY = "85540"
WHITE_SHIELD_CDP = "85660"
WILDROSE_CITY = "86020"
WILLISTON_CITY = "86220"
WILLOW_CITY_CITY = "86380"
WILTON_CITY = "86580"
WIMBLEDON_CITY = "86620"
WING_CITY = "86780"
WISHEK_CITY = "87020"
WOLFORD_CITY = "87180"
WOODWORTH_CITY = "87580"
WYNDMERE_CITY = "87740"
YORK_CITY = "87860"
YPSILANTI_CDP = "88020"
ZAP_CITY = "88140"
ZEELAND_CITY = "88180"
