# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Louisiana."""


ABBEVILLE_CITY = "00100"
ABITA_SPRINGS_TOWN = "00240"
ADDIS_TOWN = "00415"
ALBANY_TOWN = "00835"
ALEXANDRIA_CITY = "00975"
AMA_CDP = "01780"
AMELIA_CDP = "01815"
AMITE_CITY_TOWN = "01885"
ANACOCO_VILLAGE = "01920"
ANGIE_VILLAGE = "02165"
ARABI_CDP = "02550"
ARCADIA_TOWN = "02655"
ARNAUDVILLE_TOWN = "03110"
ASHLAND_VILLAGE = "03145"
ATHENS_VILLAGE = "03320"
ATLANTA_VILLAGE = "03390"
AVONDALE_CDP = "03810"
BAKER_CITY = "03985"
BALDWIN_TOWN = "04020"
BALL_TOWN = "04055"
BANKS_SPRINGS_CDP = "04230"
BARATARIA_CDP = "04300"
BASILE_TOWN = "04580"
BASKIN_VILLAGE = "04615"
BASTROP_CITY = "04685"
BATON_ROUGE_CITY = "05000"
BAWCOMVILLE_CDP = "05105"
BAYOU_BLUE_CDP = "05175"
BAYOU_CANE_CDP = "05210"
BAYOU_CORNE_CDP = "05255"
BAYOU_COUNTRY_CLUB_CDP = "05260"
BAYOU_GAUCHE_CDP = "05315"
BAYOU_GOULA_CDP = "05350"
BAYOU_LOURSE_CDP = "05378"
BAYOU_VISTA_CDP = "05525"
BELCHER_VILLAGE = "05945"
BELLE_CHASSE_CDP = "06120"
BELLE_ROSE_CDP = "06260"
BELMONT_CDP = "06750"
BENTON_TOWN = "06925"
BERNICE_TOWN = "07030"
BERWICK_TOWN = "07100"
BIENVILLE_VILLAGE = "07205"
BLANCHARD_TOWN = "07730"
BOGALUSA_CITY = "08150"
BONITA_VILLAGE = "08535"
BOOTHVILLE_CDP = "08710"
BORDELONVILLE_CDP = "08745"
BOSSIER_CITY_CITY = "08920"
BOURG_CDP = "09095"
BOUTTE_CDP = "09130"
BOYCE_TOWN = "09165"
BRANCH_CDP = "09235"
BREAUX_BRIDGE_CITY = "09340"
BRIDGE_CITY_CDP = "09480"
BROUSSARD_CITY = "10075"
BROWNFIELDS_CDP = "10145"
BROWNSVILLE_CDP = "10225"
BRUSLY_TOWN = "10600"
BRYCELAND_VILLAGE = "10705"
BUNKIE_CITY = "10950"
BURAS_CDP = "10985"
CADE_CDP = "11580"
CALHOUN_CDP = "11825"
CALVIN_VILLAGE = "11930"
CAMERON_CDP = "12000"
CAMPTI_TOWN = "12280"
CANKTON_VILLAGE = "12420"
CARENCRO_CITY = "12665"
CARLYSS_CDP = "12840"
CASTOR_VILLAGE = "13260"
CATAHOULA_CDP = "13330"
CECILIA_CDP = "13575"
CENTER_POINT_CDP = "13855"
CENTERVILLE_CDP = "13925"
CENTRAL_CITY = "13960"
CHACKBAY_CDP = "14100"
CHALMETTE_CDP = "14135"
CHARENTON_CDP = "14310"
CHATAIGNIER_VILLAGE = "14450"
CHATHAM_TOWN = "14485"
CHAUVIN_CDP = "14520"
CHENEYVILLE_TOWN = "14660"
CHOCTAW_CDP = "15150"
CHOUDRANT_VILLAGE = "15290"
CHURCH_POINT_TOWN = "15465"
CLAIBORNE_CDP = "15605"
CLARENCE_VILLAGE = "15745"
CLARKS_VILLAGE = "15780"
CLAYTON_TOWN = "15850"
CLINTON_TOWN = "15990"
COLFAX_TOWN = "16375"
COLLINSTON_VILLAGE = "16655"
COLUMBIA_TOWN = "16830"
CONVENT_CDP = "17180"
CONVERSE_VILLAGE = "17215"
COTTON_VALLEY_TOWN = "17915"
COTTONPORT_TOWN = "17880"
COUSHATTA_TOWN = "18055"
COVINGTON_CITY = "18125"
CREOLA_VILLAGE = "18295"
CRESCENT_CDP = "18335"
CROWLEY_CITY = "18650"
CULLEN_TOWN = "18790"
CUT_OFF_CDP = "18930"
DARROW_CDP = "19490"
DEQUINCY_CITY = "20575"
DERIDDER_CITY = "20610"
DELACROIX_CDP = "20050"
DELCAMBRE_TOWN = "20155"
DELHI_TOWN = "20190"
DELTA_VILLAGE = "20330"
DENHAM_SPRINGS_CITY = "20435"
DES_ALLEMANDS_CDP = "20680"
DESTREHAN_CDP = "20820"
DEVILLE_CDP = "20890"
DIXIE_INN_VILLAGE = "21135"
DODSON_VILLAGE = "21170"
DONALDSONVILLE_CITY = "21240"
DORSEYVILLE_CDP = "21388"
DOWNSVILLE_VILLAGE = "21450"
DOYLINE_VILLAGE = "21590"
DRY_PRONG_VILLAGE = "21765"
DUBACH_TOWN = "21800"
DUBBERLY_VILLAGE = "21835"
DULAC_CDP = "21940"
DUSON_TOWN = "22255"
EAST_HODGE_VILLAGE = "22465"
EASTWOOD_CDP = "22610"
ECHO_CDP = "22640"
EDEN_ISLE_CDP = "22722"
EDGARD_CDP = "22815"
EDGEFIELD_VILLAGE = "22850"
EGAN_CDP = "23025"
ELIZABETH_VILLAGE = "23235"
ELMWOOD_CDP = "23567"
ELTON_TOWN = "23620"
EMPIRE_CDP = "23725"
EPPS_VILLAGE = "24145"
ERATH_TOWN = "24180"
EROS_TOWN = "24215"
ERWINVILLE_CDP = "24250"
ESTELLE_CDP = "24390"
ESTHERWOOD_VILLAGE = "24460"
EUNICE_CITY = "24565"
EVERGREEN_TOWN = "24775"
FARMERVILLE_TOWN = "25160"
FENTON_VILLAGE = "25335"
FERRIDAY_TOWN = "25440"
FIFTH_WARD_CDP = "25545"
FISHER_VILLAGE = "25615"
FLORIEN_VILLAGE = "25860"
FOLSOM_VILLAGE = "26140"
FORDOCHE_TOWN = "26280"
FOREST_HILL_VILLAGE = "26420"
FOREST_VILLAGE = "26350"
FORT_JESUP_CDP = "26665"
FORT_POLK_NORTH_CDP = "26746"
FORT_POLK_SOUTH_CDP = "26757"
FRANKLIN_CITY = "27155"
FRANKLINTON_TOWN = "27190"
FRENCH_SETTLEMENT_VILLAGE = "27435"
FRIERSON_CDP = "27540"
GALLIANO_CDP = "28065"
GARDERE_CDP = "28275"
GARYVILLE_CDP = "28345"
GEORGETOWN_VILLAGE = "28660"
GIBSLAND_TOWN = "28835"
GILBERT_VILLAGE = "28940"
GILLIAM_VILLAGE = "29010"
GILLIS_CDP = "29045"
GLENCOE_CDP = "29150"
GLENMORA_TOWN = "29220"
GLOSTER_CDP = "29395"
GOLDEN_MEADOW_TOWN = "29640"
GOLDONNA_VILLAGE = "29745"
GONZALES_CITY = "29850"
GOOD_PINE_CDP = "29990"
GRAMBLING_CITY = "30515"
GRAMERCY_TOWN = "30550"
GRAND_CANE_VILLAGE = "30690"
GRAND_COTEAU_TOWN = "30760"
GRAND_ISLE_TOWN = "30830"
GRAND_POINT_CDP = "30900"
GRAY_CDP = "31180"
GRAYSON_VILLAGE = "31250"
GREENSBURG_TOWN = "31565"
GREENWOOD_TOWN = "31705"
GRETNA_CITY = "31915"
GROSSE_TETE_VILLAGE = "32020"
GUEYDAN_TOWN = "32055"
HACKBERRY_CDP = "32405"
HAHNVILLE_CDP = "32510"
HALL_SUMMIT_VILLAGE = "32650"
HAMMOND_CITY = "32755"
HARAHAN_CITY = "32930"
HARRISONBURG_VILLAGE = "33210"
HARVEY_CDP = "33245"
HAUGHTON_TOWN = "33420"
HAYES_CDP = "33490"
HAYNESVILLE_TOWN = "33525"
HEFLIN_VILLAGE = "33735"
HENDERSON_TOWN = "33875"
HESSMER_VILLAGE = "34015"
HESTER_CDP = "34085"
HODGE_VILLAGE = "35100"
HOMER_TOWN = "35870"
HORNBECK_TOWN = "36045"
HOSSTON_VILLAGE = "36150"
HOUMA_CITY = "36255"
IDA_VILLAGE = "36885"
INDEPENDENCE_TOWN = "37025"
INNISWOLD_CDP = "37270"
IOTA_TOWN = "37410"
IOWA_TOWN = "37445"
JACKSON_TOWN = "37830"
JAMESTOWN_VILLAGE = "37935"
JEAN_LAFITTE_TOWN = "38092"
JEANERETTE_CITY = "38075"
JEFFERSON_CDP = "38145"
JENA_TOWN = "38285"
JENNINGS_CITY = "38355"
JONESBORO_TOWN = "38670"
JONESVILLE_TOWN = "38775"
JORDAN_HILL_CDP = "38845"
JOYCE_CDP = "38880"
JUNCTION_CITY_VILLAGE = "38985"
KAPLAN_CITY = "39055"
KEACHI_TOWN = "39085"
KENNER_CITY = "39475"
KENTWOOD_TOWN = "39545"
KILBOURNE_VILLAGE = "39650"
KILLIAN_TOWN = "39685"
KILLONA_CDP = "39720"
KINDER_TOWN = "39755"
KRAEMER_CDP = "40210"
KROTZ_SPRINGS_TOWN = "40280"
LABADIEVILLE_CDP = "40420"
LACASSINE_CDP = "40595"
LACOMBE_CDP = "40665"
LAFAYETTE_CITY = "40735"
LAFITTE_CDP = "40840"
LAFOURCHE_CROSSING_CDP = "40878"
LAKE_ARTHUR_TOWN = "41050"
LAKE_CHARLES_CITY = "41155"
LAKE_PROVIDENCE_TOWN = "41400"
LAKESHORE_CDP = "41470"
LAKEVIEW_CDP = "41645"
LAPLACE_CDP = "42030"
LAROSE_CDP = "42135"
LAWTELL_CDP = "42520"
LECOMPTE_TOWN = "42800"
LEESVILLE_CITY = "43010"
LEMANNVILLE_CDP = "43255"
LEONVILLE_TOWN = "43395"
LEWISBURG_CDP = "43640"
LILLIE_VILLAGE = "43920"
LISBON_VILLAGE = "44235"
LIVINGSTON_TOWN = "44655"
LIVONIA_TOWN = "44690"
LOCKPORT_HEIGHTS_CDP = "44970"
LOCKPORT_TOWN = "44900"
LOGANSPORT_TOWN = "45040"
LONGSTREET_VILLAGE = "45460"
LONGVILLE_CDP = "45530"
LOREAUVILLE_VILLAGE = "45670"
LUCKY_VILLAGE = "46370"
LULING_CDP = "46615"
LUTCHER_TOWN = "46720"
LYDIA_CDP = "46755"
MADISONVILLE_TOWN = "47560"
MAMOU_TOWN = "48085"
MANDEVILLE_CITY = "48225"
MANGHAM_TOWN = "48260"
MANSFIELD_CITY = "48365"
MANSURA_TOWN = "48400"
MANY_TOWN = "48470"
MARINGOUIN_TOWN = "48610"
MARION_TOWN = "48645"
MARKSVILLE_CITY = "48750"
MARRERO_CDP = "48785"
MARTHAVILLE_CDP = "48890"
MARTIN_VILLAGE = "48925"
MATHEWS_CDP = "49170"
MAURICE_VILLAGE = "49240"
MCNARY_VILLAGE = "47315"
MELVILLE_TOWN = "49730"
MER_ROUGE_VILLAGE = "49905"
MERAUX_CDP = "49800"
MERMENTAU_VILLAGE = "49870"
MERRYDALE_CDP = "49940"
MERRYVILLE_TOWN = "50010"
METAIRIE_CDP = "50115"
MIDLAND_CDP = "50325"
MIDWAY_CDP = "50395"
MILTON_CDP = "50815"
MINDEN_CITY = "50885"
MINORCA_CDP = "50990"
MONROE_CITY = "51410"
MONTEGUT_CDP = "51550"
MONTEREY_CDP = "51585"
MONTGOMERY_TOWN = "51620"
MONTICELLO_CDP = "51645"
MONTPELIER_VILLAGE = "51690"
MONTZ_CDP = "51795"
MOONSHINE_CDP = "51800"
MOORINGSPORT_TOWN = "51830"
MOREAUVILLE_VILLAGE = "51970"
MORGAN_CITY_CITY = "52040"
MORGANZA_VILLAGE = "52075"
MORROW_CDP = "52250"
MORSE_VILLAGE = "52320"
MOSS_BLUFF_CDP = "52425"
MOUND_VILLAGE = "52565"
MOUNT_LEBANON_TOWN = "52740"
NAPOLEONVILLE_VILLAGE = "53370"
NATALBANY_CDP = "53475"
NATCHEZ_VILLAGE = "53510"
NATCHITOCHES_CITY = "53545"
NEW_IBERIA_CITY = "54035"
NEW_LLANO_TOWN = "54175"
NEW_ORLEANS_STATION_CDP = "55074"
NEW_ORLEANS_CITY = "55000"
NEW_ROADS_CITY = "55105"
NEW_SARPY_CDP = "55140"
NEWELLTON_TOWN = "53930"
NOBLE_VILLAGE = "55420"
NORCO_CDP = "55525"
NORTH_HODGE_VILLAGE = "55910"
NORTH_VACHERIE_CDP = "56170"
NORWOOD_VILLAGE = "56295"
OAK_GROVE_TOWN = "56820"
OAK_HILLS_PLACE_CDP = "56855"
OAK_RIDGE_VILLAGE = "57205"
OAKDALE_CITY = "56540"
OBERLIN_TOWN = "57450"
OIL_CITY_TOWN = "57590"
OLD_JEFFERSON_CDP = "57705"
OLLA_TOWN = "57905"
OPELOUSAS_CITY = "58045"
ORETTA_CDP = "58150"
OSSUN_CDP = "58360"
PAINCOURTVILLE_CDP = "58745"
PALMETTO_VILLAGE = "58780"
PARADIS_CDP = "58920"
PARKS_VILLAGE = "59165"
PATTERSON_CITY = "59340"
PAULINA_CDP = "59375"
PEARL_RIVER_TOWN = "59445"
PERRY_CDP = "59795"
PIERRE_PART_CDP = "60075"
PINE_PRAIRIE_VILLAGE = "60495"
PINEVILLE_CITY = "60530"
PIONEER_VILLAGE = "60565"
PITKIN_CDP = "60600"
PLAIN_DEALING_TOWN = "60670"
PLAQUEMINE_CITY = "60880"
PLAUCHEVILLE_VILLAGE = "60985"
PLEASANT_HILL_VILLAGE = "61055"
PLEASURE_BEND_CDP = "61160"
POINT_PLACE_CDP = "61473"
POINTE_A_LA_HACHE_CDP = "61440"
POLLOCK_TOWN = "61580"
PONCHATOULA_CITY = "61615"
PORT_ALLEN_CITY = "61790"
PORT_BARRE_TOWN = "61825"
PORT_SULPHUR_CDP = "62070"
PORT_VINCENT_VILLAGE = "62105"
POWHATAN_VILLAGE = "62245"
POYDRAS_CDP = "62280"
PRAIRIEVILLE_CDP = "62385"
PRESQUILLE_CDP = "62510"
PRIEN_CDP = "62647"
PROSPECT_CDP = "62733"
PROVENCAL_VILLAGE = "62770"
QUITMAN_VILLAGE = "63120"
RACELAND_CDP = "63155"
RAYNE_CITY = "63645"
RAYVILLE_TOWN = "63680"
RED_CHUTE_CDP = "63855"
REDDELL_CDP = "63890"
REEVES_VILLAGE = "64100"
RESERVE_CDP = "64310"
RICHMOND_VILLAGE = "64590"
RICHWOOD_TOWN = "64660"
RIDGECREST_TOWN = "64765"
RINGGOLD_TOWN = "64905"
RIO_CDP = "64975"
RIVER_RIDGE_CDP = "65150"
ROANOKE_CDP = "65290"
ROBELINE_VILLAGE = "65325"
ROCK_HILL_CDP = "65535"
RODESSA_VILLAGE = "65710"
ROMEVILLE_CDP = "65850"
ROSEDALE_VILLAGE = "66060"
ROSELAND_TOWN = "66165"
ROSEPINE_TOWN = "66200"
RUSTON_CITY = "66655"
SALINE_VILLAGE = "67880"
SAREPTA_TOWN = "68125"
SCHRIEVER_CDP = "68300"
SCOTT_CITY = "68475"
SHENANDOAH_CDP = "69225"
SHONGALOO_VILLAGE = "69455"
SHREVEPORT_CITY = "70000"
SIBLEY_TOWN = "70175"
SICILY_ISLAND_VILLAGE = "70245"
SIKES_VILLAGE = "70385"
SIMMESPORT_TOWN = "70525"
SIMPSON_VILLAGE = "70595"
SIMSBORO_VILLAGE = "70630"
SINGER_CDP = "70665"
SIRACUSAVILLE_CDP = "70675"
SLAUGHTER_TOWN = "70770"
SLIDELL_CITY = "70805"
SORREL_CDP = "71190"
SORRENTO_TOWN = "71225"
SOUTH_MANSFIELD_VILLAGE = "71820"
SOUTH_VACHERIE_CDP = "72092"
SPEARSVILLE_VILLAGE = "72170"
SPOKANE_CDP = "72310"
SPRINGFIELD_TOWN = "72415"
SPRINGHILL_CITY = "72485"
ST_FRANCISVILLE_TOWN = "67215"
ST_GABRIEL_CITY = "67250"
ST_JAMES_CDP = "67355"
ST_JOSEPH_TOWN = "67495"
ST_MARTINVILLE_CITY = "67600"
ST_MAURICE_CDP = "67635"
ST_ROSE_CDP = "67740"
STANLEY_VILLAGE = "72800"
STARKS_CDP = "72975"
START_CDP = "73010"
STERLINGTON_TOWN = "73255"
STONEWALL_TOWN = "73395"
SUGARTOWN_CDP = "73570"
SULPHUR_CITY = "73640"
SUN_VILLAGE = "73955"
SUNSET_TOWN = "74060"
SUPREME_CDP = "74235"
SWARTZ_CDP = "74340"
TAFT_CDP = "74550"
TALLULAH_CITY = "74690"
TANGIPAHOA_VILLAGE = "74760"
TERRYTOWN_CDP = "75180"
THIBODAUX_CITY = "75425"
TICKFAW_VILLAGE = "75670"
TIMBERLANE_CDP = "75740"
TRIUMPH_CDP = "76440"
TROUT_CDP = "76475"
TULLOS_TOWN = "76615"
TURKEY_CREEK_VILLAGE = "76685"
UNION_CDP = "77035"
URANIA_TOWN = "77490"
VARNADO_VILLAGE = "77910"
VENICE_CDP = "78015"
VENTRESS_CDP = "78050"
VIDALIA_TOWN = "78470"
VIENNA_BEND_CDP = "78545"
VIENNA_TOWN = "78540"
VILLAGE_ST_GEORGE_CDP = "78680"
VILLE_PLATTE_CITY = "78715"
VINTON_TOWN = "78820"
VIOLET_CDP = "78855"
VIVIAN_TOWN = "78890"
WAGGAMAN_CDP = "79100"
WALKER_TOWN = "79240"
WALLACE_CDP = "79275"
WALLACE_RIDGE_CDP = "79310"
WASHINGTON_TOWN = "79870"
WATERPROOF_TOWN = "79940"
WATSON_CDP = "80010"
WELCOME_CDP = "80360"
WELSH_TOWN = "80430"
WEST_MONROE_CITY = "80955"
WESTLAKE_CITY = "80815"
WESTMINSTER_CDP = "80920"
WESTWEGO_CITY = "81165"
WHITE_CASTLE_TOWN = "81375"
WILSON_VILLAGE = "82215"
WINNFIELD_CITY = "82460"
WINNSBORO_CITY = "82495"
WISNER_TOWN = "82565"
WOODMERE_CDP = "83002"
WOODWORTH_TOWN = "83125"
YOUNGSVILLE_CITY = "83335"
ZACHARY_CITY = "83405"
ZWOLLE_TOWN = "83685"
