# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Louisiana."""


ACADIA = "001"
ALLEN = "003"
ASCENSION = "005"
ASSUMPTION = "007"
AVOYELLES = "009"
BEAUREGARD = "011"
BIENVILLE = "013"
BOSSIER = "015"
CADDO = "017"
CALCASIEU = "019"
CALDWELL = "021"
CAMERON = "023"
CATAHOULA = "025"
CLAIBORNE = "027"
CONCORDIA = "029"
DE_SOTO = "031"
EAST_BATON_ROUGE = "033"
EAST_CARROLL = "035"
EAST_FELICIANA = "037"
EVANGELINE = "039"
FRANKLIN = "041"
GRANT = "043"
IBERIA = "045"
IBERVILLE = "047"
JACKSON = "049"
JEFFERSON_DAVIS = "053"
JEFFERSON = "051"
LASALLE = "059"
LAFAYETTE = "055"
LAFOURCHE = "057"
LINCOLN = "061"
LIVINGSTON = "063"
MADISON = "065"
MOREHOUSE = "067"
NATCHITOCHES = "069"
ORLEANS = "071"
OUACHITA = "073"
PLAQUEMINES = "075"
POINTE_COUPEE = "077"
RAPIDES = "079"
RED_RIVER = "081"
RICHLAND = "083"
SABINE = "085"
ST_BERNARD = "087"
ST_CHARLES = "089"
ST_HELENA = "091"
ST_JAMES = "093"
ST_JOHN_THE_BAPTIST = "095"
ST_LANDRY = "097"
ST_MARTIN = "099"
ST_MARY = "101"
ST_TAMMANY = "103"
TANGIPAHOA = "105"
TENSAS = "107"
TERREBONNE = "109"
UNION = "111"
VERMILION = "113"
VERNON = "115"
WASHINGTON = "117"
WEBSTER = "119"
WEST_BATON_ROUGE = "121"
WEST_CARROLL = "123"
WEST_FELICIANA = "125"
WINN = "127"
