# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Alabama."""


ABANDA_CDP = "00100"
ABBEVILLE_CITY = "00124"
ADAMSVILLE_CITY = "00460"
ADDISON_TOWN = "00484"
AKRON_TOWN = "00676"
ALABASTER_CITY = "00820"
ALBERTVILLE_CITY = "00988"
ALEXANDER_CITY_CITY = "01132"
ALEXANDRIA_CDP = "01180"
ALICEVILLE_CITY = "01228"
ALLGOOD_TOWN = "01396"
ALTOONA_TOWN = "01660"
ANDALUSIA_CITY = "01708"
ANDERSON_TOWN = "01756"
ANNISTON_CITY = "01852"
ARAB_CITY = "02116"
ARDMORE_TOWN = "02260"
ARGO_TOWN = "02320"
ARITON_TOWN = "02428"
ARLEY_TOWN = "02500"
ASHFORD_TOWN = "02836"
ASHLAND_TOWN = "02860"
ASHVILLE_CITY = "02908"
ATHENS_CITY = "02956"
ATMORE_CITY = "03004"
ATTALLA_CITY = "03028"
AUBURN_CITY = "03076"
AUTAUGAVILLE_TOWN = "03220"
AVON_TOWN = "03364"
AXIS_CDP = "03508"
BABBIE_TOWN = "03556"
BAILEYTON_TOWN = "03676"
BAKERHILL_TOWN = "03724"
BALLPLAY_CDP = "03820"
BANKS_TOWN = "03940"
BAY_MINETTE_CITY = "04660"
BAYOU_LA_BATRE_CITY = "04684"
BEAR_CREEK_TOWN = "04852"
BEATRICE_TOWN = "04900"
BEAVERTON_TOWN = "04948"
BELGREEN_CDP = "05140"
BELK_TOWN = "05164"
BELLAMY_CDP = "05188"
BELLE_FONTAINE_CDP = "05212"
BENTON_TOWN = "05692"
BERLIN_TOWN = "05812"
BERRY_TOWN = "05932"
BESSEMER_CITY = "05980"
BILLINGSLEY_TOWN = "06460"
BIRMINGHAM_CITY = "07000"
BLACK_TOWN = "07120"
BLOUNTSVILLE_TOWN = "07456"
BLUE_RIDGE_CDP = "07588"
BLUE_SPRINGS_TOWN = "07672"
BOAZ_CITY = "07912"
BOLIGEE_TOWN = "08104"
BON_AIR_TOWN = "08248"
BON_SECOUR_CDP = "08272"
BOYKIN_CDP = "08680"
BRANTLEY_TOWN = "09016"
BRANTLEYVILLE_CDP = "09064"
BRENT_CITY = "09136"
BREWTON_CITY = "09208"
BRIDGEPORT_CITY = "09328"
BRIGHTON_CITY = "09400"
BRILLIANT_TOWN = "09424"
BRISTOW_COVE_CDP = "09457"
BROOK_HIGHLAND_CDP = "09500"
BROOKSIDE_TOWN = "09736"
BROOKWOOD_TOWN = "09808"
BROOMTOWN_CDP = "09880"
BRUNDIDGE_CITY = "10240"
BUCKS_CDP = "10456"
BUTLER_TOWN = "11032"
CALERA_CITY = "11416"
CALVERT_CDP = "11488"
CAMDEN_CITY = "11512"
CAMP_HILL_TOWN = "11680"
CARBON_HILL_CITY = "12016"
CARDIFF_TOWN = "12040"
CARLISLE_ROCKLEDGE_CDP = "12070"
CARLTON_CDP = "12112"
CAROLINA_TOWN = "12160"
CARROLLTON_TOWN = "12304"
CASTLEBERRY_TOWN = "12496"
CATHERINE_CDP = "12544"
CEDAR_BLUFF_TOWN = "12760"
CENTER_POINT_CITY = "13264"
CENTRE_CITY = "13648"
CENTREVILLE_CITY = "13672"
CHATOM_TOWN = "14008"
CHELSEA_CITY = "14104"
CHEROKEE_TOWN = "14152"
CHICKASAW_CITY = "14392"
CHILDERSBURG_CITY = "14464"
CHOCCOLOCCO_CDP = "14728"
CHUNCHULA_CDP = "14968"
CITRONELLE_CITY = "15064"
CLANTON_CITY = "15136"
CLAY_CITY = "15256"
CLAYHATCHEE_TOWN = "15304"
CLAYTON_TOWN = "15376"
CLEVELAND_TOWN = "15472"
CLIO_CITY = "15640"
COALING_TOWN = "16000"
COATS_BEND_CDP = "16080"
COFFEE_SPRINGS_TOWN = "16240"
COFFEEVILLE_TOWN = "16264"
COKER_TOWN = "16312"
COLLINSVILLE_TOWN = "16600"
COLONY_TOWN = "16684"
COLUMBIA_TOWN = "16744"
COLUMBIANA_CITY = "16768"
CONCORD_CDP = "16936"
COOSADA_TOWN = "17176"
CORDOVA_CITY = "17368"
COTTONDALE_CDP = "17704"
COTTONWOOD_TOWN = "17824"
COUNTY_LINE_TOWN = "17968"
COURTLAND_TOWN = "18040"
COWARTS_TOWN = "18088"
CREOLA_CITY = "18304"
CROSSVILLE_TOWN = "18856"
CUBA_TOWN = "18952"
CULLMAN_CITY = "18976"
CULLOMBURG_CDP = "19024"
CUSSETA_TOWN = "19216"
DADEVILLE_CITY = "19336"
DALEVILLE_CITY = "19360"
DAPHNE_CITY = "19648"
DAUPHIN_ISLAND_TOWN = "19744"
DAVISTON_TOWN = "19816"
DAYTON_TOWN = "19912"
DEATSVILLE_TOWN = "20008"
DECATUR_CITY = "20104"
DEER_PARK_CDP = "20152"
DELTA_CDP = "20272"
DEMOPOLIS_CITY = "20296"
DETROIT_TOWN = "20392"
DODGE_CITY_TOWN = "20955"
DORA_CITY = "21136"
DOTHAN_CITY = "21184"
DOUBLE_SPRINGS_TOWN = "21280"
DOUGLAS_TOWN = "21328"
DOZIER_TOWN = "21448"
DUNNAVANT_CDP = "21890"
DUTTON_TOWN = "21952"
EAGLE_POINT_CDP = "22088"
EAST_BREWTON_CITY = "22216"
EAST_POINT_CDP = "22504"
ECLECTIC_TOWN = "22816"
EDGEWATER_CDP = "23032"
EDWARDSVILLE_TOWN = "23176"
EGYPT_CDP = "23224"
ELBA_CITY = "23296"
ELBERTA_TOWN = "23320"
ELDRIDGE_TOWN = "23344"
ELKMONT_TOWN = "23488"
ELMORE_TOWN = "23656"
EMELLE_TOWN = "23872"
EMERALD_MOUNTAIN_CDP = "23880"
ENTERPRISE_CITY = "24184"
EPES_TOWN = "24256"
EQUALITY_CDP = "24280"
ETHELSVILLE_TOWN = "24472"
EUFAULA_CITY = "24568"
EUNOLA_CDP = "24616"
EUTAW_TOWN = "24664"
EVA_TOWN = "24688"
EVERGREEN_CITY = "24808"
EXCEL_TOWN = "24880"
FAIRFIELD_CITY = "25120"
FAIRFORD_CDP = "25216"
FAIRHOPE_CITY = "25240"
FAIRVIEW_TOWN = "25384"
FALKVILLE_TOWN = "25648"
FAUNSDALE_TOWN = "25816"
FAYETTE_CITY = "25840"
FAYETTEVILLE_CDP = "25864"
FITZPATRICK_CDP = "26152"
FIVE_POINTS_TOWN = "26200"
FLOMATON_TOWN = "26824"
FLORALA_TOWN = "26848"
FLORENCE_CITY = "26896"
FOLEY_CITY = "26992"
FORESTDALE_CDP = "27088"
FORKLAND_TOWN = "27376"
FORT_DEPOSIT_TOWN = "27520"
FORT_PAYNE_CITY = "27616"
FORT_RUCKER_CDP = "27640"
FRANKLIN_TOWN = "28024"
FREDONIA_CDP = "28120"
FRISCO_CITY_TOWN = "28312"
FRUITDALE_CDP = "28408"
FRUITHURST_TOWN = "28432"
FULTON_TOWN = "28504"
FULTONDALE_CITY = "28552"
FYFFE_TOWN = "28672"
GADSDEN_CITY = "28696"
GAINESVILLE_TOWN = "28768"
GALLANT_CDP = "28816"
GANTT_TOWN = "28936"
GARDEN_CITY_TOWN = "29032"
GARDENDALE_CITY = "29056"
GAYLESVILLE_TOWN = "29296"
GEIGER_TOWN = "29392"
GENEVA_CITY = "29464"
GEORGIANA_TOWN = "29560"
GERALDINE_TOWN = "29608"
GILBERTOWN_TOWN = "29704"
GLEN_ALLEN_TOWN = "29944"
GLENCOE_CITY = "29992"
GLENWOOD_TOWN = "30160"
GOLDVILLE_TOWN = "30448"
GOOD_HOPE_CITY = "30496"
GOODWATER_TOWN = "30640"
GORDO_TOWN = "30736"
GORDON_TOWN = "30760"
GORDONVILLE_TOWN = "30808"
GOSHEN_TOWN = "30880"
GRAHAM_CDP = "31000"
GRAND_BAY_CDP = "31024"
GRANT_TOWN = "31096"
GRAYSON_VALLEY_CDP = "31348"
GRAYSVILLE_CITY = "31384"
GREENSBORO_CITY = "31720"
GREENVILLE_CITY = "31912"
GRIMES_TOWN = "32056"
GROVE_HILL_TOWN = "32080"
GU_WIN_TOWN = "32536"
GUIN_CITY = "32224"
GULF_SHORES_CITY = "32272"
GULFCREST_CDP = "32248"
GUNTERSVILLE_CITY = "32416"
GURLEY_TOWN = "32440"
HACKLEBURG_TOWN = "32560"
HACKNEYVILLE_CDP = "32584"
HALEBURG_TOWN = "32656"
HALEYVILLE_CITY = "32704"
HAMILTON_CITY = "32848"
HAMMONDVILLE_TOWN = "32896"
HANCEVILLE_CITY = "32968"
HANOVER_CDP = "33064"
HARPERSVILLE_TOWN = "33256"
HARTFORD_CITY = "33424"
HARTSELLE_CITY = "33448"
HARVEST_CDP = "33472"
HATTON_CDP = "33544"
HAYDEN_TOWN = "33640"
HAYNEVILLE_TOWN = "33712"
HAZEL_GREEN_CDP = "33808"
HEADLAND_CITY = "33856"
HEATH_TOWN = "33904"
HEFLIN_CITY = "33976"
HELENA_CITY = "34024"
HENAGAR_CITY = "34096"
HIGHLAND_LAKE_TOWN = "34480"
HIGHLAND_LAKES_CDP = "34490"
HILLSBORO_TOWN = "34816"
HISSOP_CDP = "34984"
HOBSON_CDP = "35130"
HOBSON_CITY_TOWN = "35152"
HODGES_TOWN = "35200"
HOKES_BLUFF_CITY = "35392"
HOLLINS_CDP = "35512"
HOLLIS_CROSSROADS_CDP = "35536"
HOLLY_POND_TOWN = "35560"
HOLLYWOOD_TOWN = "35632"
HOLT_CDP = "35704"
HOLTVILLE_CDP = "35752"
HOMEWOOD_CITY = "35800"
HOOVER_CITY = "35896"
HORN_HILL_TOWN = "36088"
HUEYTOWN_CITY = "36448"
HUGULEY_CDP = "36592"
HUNTSVILLE_CITY = "37000"
HURTSBORO_TOWN = "37096"
HYTOP_TOWN = "37264"
IDER_TOWN = "37312"
INDIAN_SPRINGS_VILLAGE_CITY = "37465"
IRONDALE_CITY = "37864"
IVALEE_CDP = "38032"
JACKSON_CITY = "38152"
JACKSONS_GAP_TOWN = "38248"
JACKSONVILLE_CITY = "38272"
JASPER_CITY = "38416"
JEMISON_CITY = "38608"
JOPPA_CDP = "39064"
KANSAS_TOWN = "39280"
KELLYTON_TOWN = "39472"
KENNEDY_TOWN = "39520"
KILLEN_TOWN = "39784"
KIMBERLY_CITY = "39856"
KINSEY_TOWN = "40072"
KINSTON_TOWN = "40096"
LA_FAYETTE_CITY = "40672"
LADONIA_CDP = "40648"
LAKE_VIEW_TOWN = "40928"
LAKEVIEW_TOWN = "40888"
LANETT_CITY = "41296"
LANGSTON_TOWN = "41368"
LEEDS_CITY = "41968"
LEESBURG_TOWN = "42016"
LEIGHTON_TOWN = "42160"
LEROY_CDP = "42304"
LESTER_TOWN = "42352"
LEVEL_PLAINS_TOWN = "42472"
LEXINGTON_TOWN = "42640"
LIBERTYVILLE_TOWN = "42808"
LILLIAN_CDP = "42928"
LINCOLN_CITY = "43120"
LINDEN_CITY = "43240"
LINEVILLE_CITY = "43264"
LIPSCOMB_CITY = "43336"
LISMAN_TOWN = "43384"
LITTLEVILLE_TOWN = "43648"
LIVINGSTON_CITY = "43720"
LOACHAPOKA_TOWN = "43744"
LOCKHART_TOWN = "43816"
LOCUST_FORK_TOWN = "43888"
LOOKOUT_MOUNTAIN_CDP = "44160"
LOUISVILLE_TOWN = "44344"
LOWNDESBORO_TOWN = "44536"
LOXLEY_TOWN = "44608"
LUVERNE_CITY = "44728"
LYNN_TOWN = "44800"
MACEDONIA_CDP = "45316"
MADISON_CITY = "45784"
MADRID_TOWN = "45904"
MAGNOLIA_SPRINGS_TOWN = "46072"
MALCOLM_CDP = "46192"
MALVERN_TOWN = "46264"
MAPLESVILLE_TOWN = "46504"
MARBURY_CDP = "46600"
MARGARET_TOWN = "46696"
MARION_CITY = "46768"
MAYTOWN_TOWN = "47728"
MCCALLA_CDP = "45040"
MCDONALD_CHAPEL_CDP = "45208"
MCINTOSH_TOWN = "45472"
MCKENZIE_TOWN = "45496"
MCMULLEN_TOWN = "45640"
MEADOWBROOK_CDP = "47740"
MEGARGEL_CDP = "47848"
MEMPHIS_TOWN = "48052"
MENTONE_TOWN = "48064"
MERIDIANVILLE_CDP = "48112"
MIDFIELD_CITY = "48376"
MIDLAND_CITY_TOWN = "48400"
MIDWAY_TOWN = "48424"
MIGNON_CDP = "48616"
MILLBROOK_CITY = "48712"
MILLERVILLE_CDP = "48784"
MILLPORT_TOWN = "48808"
MILLRY_TOWN = "48832"
MINOR_CDP = "49072"
MOBILE_CITY = "50000"
MONROEVILLE_CITY = "50192"
MONTEVALLO_CITY = "50312"
MONTGOMERY_CITY = "51000"
MOODY_CITY = "51096"
MOORES_MILL_CDP = "51216"
MOORESVILLE_TOWN = "51264"
MORRIS_TOWN = "51456"
MORRISON_CROSSROADS_CDP = "51469"
MOSSES_TOWN = "51520"
MOULTON_CITY = "51600"
MOUNDVILLE_TOWN = "51648"
MOUNT_OLIVE_CDP_COOSA_COUNTY = "52320"
MOUNT_OLIVE_CDP_JEFFERSON_COUNTY = "52344"
MOUNT_VERNON_TOWN = "52608"
MOUNTAIN_BROOK_CITY = "51696"
MOVICO_CDP = "52680"
MULGA_TOWN = "52776"
MUNFORD_TOWN = "52848"
MUSCLE_SHOALS_CITY = "53016"
MYRTLEWOOD_TOWN = "53112"
NANAFALIA_CDP = "53208"
NANCES_CREEK_CDP = "53232"
NAPIER_FIELD_TOWN = "53256"
NATURAL_BRIDGE_TOWN = "53376"
NAUVOO_TOWN = "53400"
NECTAR_TOWN = "53448"
NEEDHAM_TOWN = "53472"
NEW_BROCKTON_TOWN = "53856"
NEW_HOPE_CITY = "54168"
NEW_MARKET_CDP = "54312"
NEW_SITE_TOWN = "54432"
NEW_UNION_CDP = "54582"
NEWBERN_TOWN = "53784"
NEWTON_TOWN = "54480"
NEWVILLE_TOWN = "54600"
NIXBURG_CDP = "54696"
NORTH_COURTLAND_TOWN = "55044"
NORTH_JOHNS_TOWN = "55152"
NORTHPORT_CITY = "55200"
NOTASULGA_TOWN = "55440"
OAK_GROVE_TOWN = "55752"
OAK_HILL_TOWN = "55848"
OAKMAN_TOWN = "55992"
ODENVILLE_CITY = "56400"
OHATCHEE_TOWN = "56472"
ONEONTA_CITY = "57000"
ONYCHA_TOWN = "57024"
OPELIKA_CITY = "57048"
OPP_CITY = "57120"
ORANGE_BEACH_CITY = "57144"
ORRVILLE_TOWN = "57240"
OUR_TOWN_CDP = "57384"
OWENS_CROSS_ROADS_TOWN = "57504"
OXFORD_CITY = "57576"
OZARK_CITY = "57648"
PAINT_ROCK_TOWN = "57696"
PANOLA_CDP = "57912"
PARRISH_TOWN = "58272"
PEA_RIDGE_CDP = "58680"
PELHAM_CITY = "58848"
PELL_CITY_CITY = "58896"
PENNINGTON_TOWN = "58968"
PENTON_CDP = "59016"
PERDIDO_BEACH_TOWN = "59088"
PERDIDO_CDP = "59064"
PETERMAN_CDP = "59232"
PETREY_TOWN = "59328"
PHENIX_CITY_CITY = "59472"
PHIL_CAMPBELL_TOWN = "59496"
PICKENSVILLE_TOWN = "59592"
PIEDMONT_CITY = "59640"
PIKE_ROAD_TOWN = "59760"
PINCKARD_TOWN = "59832"
PINE_APPLE_TOWN = "59880"
PINE_HILL_TOWN = "60240"
PINE_LEVEL_CDP = "60264"
PINE_RIDGE_TOWN = "60372"
PINSON_CITY = "60648"
PISGAH_TOWN = "60720"
PLEASANT_GROVE_CITY = "61008"
PLEASANT_GROVES_TOWN = "61038"
POINT_CLEAR_CDP = "61488"
POLLARD_TOWN = "61536"
POWELL_TOWN = "62075"
PRATTVILLE_CITY = "62328"
PRICEVILLE_TOWN = "62472"
PRICHARD_CITY = "62496"
PROVIDENCE_TOWN = "62688"
PUTNAM_CDP = "62952"
RAGLAND_TOWN = "63216"
RAINBOW_CITY_CITY = "63288"
RAINSVILLE_CITY = "63336"
RANBURNE_TOWN = "63408"
RAY_CDP = "63495"
RED_BAY_CITY = "63576"
RED_LEVEL_TOWN = "63768"
REDLAND_CDP = "63730"
REDSTONE_ARSENAL_CDP = "63912"
REECE_CITY_TOWN = "63984"
REELTOWN_CDP = "64040"
REFORM_TOWN = "64104"
REHOBETH_TOWN = "64152"
REMLAP_CDP = "64248"
REPTON_TOWN = "64368"
RIDGEVILLE_TOWN = "64656"
RIVER_FALLS_TOWN = "64776"
RIVERSIDE_CITY = "64920"
RIVERVIEW_TOWN = "65016"
ROANOKE_CITY = "65040"
ROBERTSDALE_CITY = "65208"
ROCK_CREEK_CDP = "65412"
ROCK_MILLS_CDP = "65592"
ROCKFORD_TOWN = "65472"
ROCKVILLE_CDP = "65784"
ROGERSVILLE_TOWN = "66216"
ROSA_TOWN = "66408"
RUSSELLVILLE_CITY = "67056"
RUTLEDGE_TOWN = "67176"
SAKS_CDP = "67608"
SAMSON_CITY = "67800"
SAND_ROCK_TOWN = "67920"
SANFORD_TOWN = "68016"
SARALAND_CITY = "68160"
SARDIS_CITY_TOWN = "68280"
SATSUMA_CITY = "68352"
SCOTTSBORO_CITY = "68736"
SECTION_TOWN = "69000"
SELMA_CITY = "69120"
SELMONT_WEST_SELMONT_CDP = "69180"
SEMMES_CITY = "69240"
SHEFFIELD_CITY = "69648"
SHELBY_CDP = "69672"
SHILOH_TOWN = "69840"
SHOAL_CREEK_CDP = "69978"
SHORTER_TOWN = "70128"
SILAS_TOWN = "70416"
SILVERHILL_TOWN = "70536"
SIMS_CHAPEL_CDP = "70632"
SIPSEY_TOWN = "70704"
SKYLINE_TOWN = "70896"
SLOCOMB_CITY = "71040"
SMITHS_STATION_CITY = "71190"
SMOKE_RISE_CDP = "71201"
SNEAD_TOWN = "71280"
SOMERVILLE_TOWN = "71496"
SOUTH_VINEMONT_TOWN = "71900"
SOUTHSIDE_CITY = "71832"
SPANISH_FORT_CITY = "71976"
SPRING_GARDEN_CDP = "72408"
SPRINGVILLE_CITY = "72600"
SPRUCE_PINE_CDP = "72672"
ST_FLORIAN_TOWN = "67536"
ST_STEPHENS_CDP = "67584"
STANDING_ROCK_CDP = "72720"
STAPLETON_CDP = "72816"
STEELE_TOWN = "72888"
STERRETT_CDP = "73056"
STEVENSON_CITY = "73080"
STEWARTVILLE_CDP = "73152"
STOCKTON_CDP = "73272"
SULLIGENT_CITY = "73728"
SUMITON_CITY = "73848"
SUMMERDALE_TOWN = "73872"
SUSAN_MOORE_TOWN = "74160"
SWEET_WATER_TOWN = "74304"
SYLACAUGA_CITY = "74352"
SYLVAN_SPRINGS_TOWN = "74424"
SYLVANIA_TOWN = "74400"
TALLADEGA_SPRINGS_TOWN = "74616"
TALLADEGA_CITY = "74592"
TALLASSEE_CITY = "74688"
TARRANT_CITY = "74976"
TAYLOR_TOWN = "75096"
THEODORE_CDP = "75768"
THOMASTON_TOWN = "75936"
THOMASVILLE_CITY = "75960"
THORSBY_TOWN = "76080"
TIBBIE_CDP = "76200"
TIDMORE_BEND_CDP = "76208"
TILLMANS_CORNER_CDP = "76320"
TOWN_CREEK_TOWN = "76584"
TOXEY_TOWN = "76632"
TRAFFORD_TOWN = "76680"
TRIANA_TOWN = "76824"
TRINITY_TOWN = "76872"
TROY_CITY = "76920"
TRUSSVILLE_CITY = "76944"
TUSCALOOSA_CITY = "77256"
TUSCUMBIA_CITY = "77280"
TUSKEGEE_CITY = "77304"
TWIN_TOWN = "77352"
UNDERWOOD_PETERSVILLE_CDP = "77580"
UNION_GROVE_TOWN = "77784"
UNION_SPRINGS_CITY = "77880"
UNION_TOWN = "77616"
UNIONTOWN_TOWN = "77904"
URIAH_CDP = "78120"
VALLEY_GRANDE_CITY = "78232"
VALLEY_HEAD_TOWN = "78240"
VALLEY_CITY = "78204"
VANCE_TOWN = "78264"
VANDIVER_CDP = "78312"
VERNON_CITY = "78480"
VESTAVIA_HILLS_CITY = "78552"
VINA_TOWN = "78984"
VINCENT_TOWN = "79008"
VINEGAR_BEND_CDP = "79032"
VREDENBURGH_TOWN = "79272"
WADLEY_TOWN = "79344"
WALDO_TOWN = "79488"
WALNUT_GROVE_TOWN = "79728"
WARRIOR_CITY = "79944"
WATERLOO_TOWN = "80064"
WAVERLY_TOWN = "80256"
WEAVER_CITY = "80352"
WEBB_TOWN = "80376"
WEDOWEE_TOWN = "80496"
WEOGUFKA_CDP = "80736"
WEST_BLOCTON_TOWN = "80928"
WEST_END_COBB_TOWN_CDP = "81084"
WEST_JEFFERSON_TOWN = "81336"
WEST_POINT_TOWN = "81528"
WESTOVER_TOWN = "81504"
WETUMPKA_CITY = "81720"
WHATLEY_CDP = "81744"
WHITE_HALL_TOWN = "81912"
WHITE_PLAINS_CDP = "82104"
WHITESBORO_CDP = "82176"
WILSONVILLE_TOWN = "82848"
WILTON_TOWN = "82872"
WINFIELD_CITY = "82992"
WOODLAND_TOWN = "83400"
WOODSTOCK_TOWN = "83640"
WOODVILLE_TOWN = "83664"
YELLOW_BLUFF_TOWN = "83976"
YORK_CITY = "84096"
