# Copyright (c) 2023 Darren Erik Vengroff
"""Places in New Mexico."""


ABEYTAS_CDP = "00240"
ABIQUIU_CDP = "00310"
ACOMITA_LAKE_CDP = "00765"
ADELINO_CDP = "00940"
AGUA_FRIA_CDP = "01220"
ALAMILLO_CDP = "01640"
ALAMO_CDP = "01710"
ALAMOGORDO_CITY = "01780"
ALBUQUERQUE_CITY = "02000"
ALCALDE_CDP = "02070"
ALGODONES_CDP = "02210"
ALMA_CDP = "02560"
ANGEL_FIRE_VILLAGE = "03400"
ANGUSTURA_CDP = "03680"
ANIMAS_CDP = "03750"
ANTHONY_CITY = "03820"
ANTON_CHICO_CDP = "03890"
ANZAC_VILLAGE_CDP = "03970"
APACHE_CREEK_CDP = "04030"
ARAGON_CDP = "04450"
ARENAS_VALLEY_CDP = "04660"
ARREY_CDP = "04870"
ARROYO_HONDO_CDP_SANTA_FE_COUNTY = "05002"
ARROYO_HONDO_CDP_TAOS_COUNTY = "05010"
ARROYO_SECO_CDP = "05150"
ARTESIA_CITY = "05220"
ATOKA_CDP = "05430"
AZTEC_CITY = "05780"
BARTON_CDP = "06220"
BAYARD_CITY = "06270"
BECENTI_CDP = "06340"
BECLABITO_CDP = "06425"
BELEN_CITY = "06480"
BENT_CDP = "06760"
BERINO_CDP = "06830"
BERNALILLO_TOWN = "06970"
BIBO_CDP = "07145"
BLACK_HAT_CDP = "07492"
BLACK_ROCK_CDP = "07670"
BLANCO_CDP = "07810"
BLOOMFIELD_CITY = "07880"
BLUEWATER_CDP = "08180"
BLUEWATER_VILLAGE_CDP = "08190"
BOLES_ACRES_CDP = "08440"
BORREGO_PASS_CDP = "08493"
BOSQUE_FARMS_VILLAGE = "08580"
BRAZOS_CDP = "08860"
BRIMHALL_NIZHONI_CDP = "09035"
BROADVIEW_CDP = "09202"
BUCKHORN_CDP = "09630"
BUTTERFIELD_PARK_CDP = "09980"
CABALLO_CDP = "10050"
CANDY_KITCHEN_CDP = "10592"
CANJILON_CDP = "10610"
CANNON_AFB_CDP = "10750"
CANOVA_CDP = "11520"
CAPITAN_VILLAGE = "11800"
CAPULIN_CDP = "12010"
CARLSBAD_CITY = "12150"
CARNUEL_CDP = "12430"
CARRIZOZO_TOWN = "12500"
CASA_COLORADA_CDP = "12786"
CASAS_ADOBES_CDP = "12833"
CATALPA_CANYON_CDP = "12844"
CAUSEY_VILLAGE = "12850"
CANADA_DE_LOS_ALAMOS_CDP = "10470"
CANON_CDP = "10770"
CANONCITO_CDP = "11256"
CANONES_CDP = "11310"
CEDAR_CREST_CDP = "13200"
CEDAR_GROVE_CDP = "13270"
CEDAR_HILL_CDP = "13340"
CEDRO_CDP = "13450"
CENTER_POINT_CDP = "13540"
CHAMA_VILLAGE = "13970"
CHAMBERINO_CDP = "14040"
CHAMISAL_CDP = "14110"
CHAMITA_CDP = "14180"
CHAMIZAL_CDP = "14200"
CHAPARRAL_CDP = "14250"
CHICAL_CDP = "14670"
CHILI_CDP = "14810"
CHILILI_CDP = "14880"
CHIMAYO_CDP = "14950"
CHUPADERO_CDP = "15300"
CHURCH_ROCK_CDP = "15370"
CIMARRON_VILLAGE = "15440"
CITY_OF_THE_SUN_CDP = "15560"
CLAYTON_TOWN = "15720"
CLIFF_CDP = "15860"
CLOUDCROFT_VILLAGE = "16280"
CLOVIS_CITY = "16420"
COBRE_CDP = "16490"
COCHITI_CDP = "16560"
COCHITI_LAKE_CDP = "16585"
COLUMBUS_VILLAGE = "17050"
CONCHAS_DAM_CDP = "17260"
CONEJO_CDP = "17295"
CONTINENTAL_DIVIDE_CDP = "17330"
CORDOVA_CDP = "17610"
CORONA_VILLAGE = "17680"
CORRALES_VILLAGE = "17960"
COSTILLA_CDP = "18240"
COTTON_CITY_CDP = "18310"
COYOTE_CDP = "18660"
CRESTVIEW_CDP = "18770"
CROUCH_MESA_CDP = "18905"
CROWNPOINT_CDP = "18940"
CRUZVILLE_CDP = "19010"
CRYSTAL_CDP = "19080"
CUARTELEZ_CDP = "19110"
CUBA_VILLAGE = "19150"
CUBERO_CDP = "19220"
CUNDIYO_CDP = "19500"
CUYAMUNGUE_CDP = "19640"
CUYAMUNGUE_GRANT_CDP = "19645"
DATIL_CDP = "19920"
DEER_CANYON_CDP = "20015"
DEMING_CITY = "20270"
DES_MOINES_VILLAGE = "20480"
DEXTER_TOWN = "20620"
DIXON_CDP = "20830"
DORA_VILLAGE = "21180"
DONA_ANA_CDP = "21110"
DULCE_CDP = "21390"
DURAN_CDP = "21810"
EAGLE_NEST_VILLAGE = "22020"
EAST_PECOS_CDP = "22230"
EDGEWOOD_TOWN = "22380"
EDITH_ENCLAVE_CDP = "22389"
EL_CERRO_CDP = "22580"
EL_CERRO_MISSION_CDP = "22582"
EL_DUENDE_CDP = "22650"
EL_MORRO_VALLEY_CDP = "23497"
EL_RANCHO_CDP = "23840"
EL_RITO_CDP = "24120"
EL_VALLE_DE_ARROYO_SECO_CDP = "24347"
ELDORADO_AT_SANTA_FE_CDP = "22625"
ELEPHANT_BUTTE_CITY = "22720"
ELIDA_TOWN = "23000"
ENCANTADO_CDP = "24453"
ENCINAL_CDP = "24540"
ENCINO_VILLAGE = "24610"
ENSENADA_CDP = "24960"
ESCONDIDA_CDP = "25100"
ESCUDILLA_BONITA_CDP = "25135"
ESPANOLA_CITY = "25170"
ESTANCIA_TOWN = "25380"
EUNICE_CITY = "25450"
FAIRACRES_CDP = "25590"
FARMINGTON_CITY = "25800"
FAYWOOD_CDP = "25870"
FENCE_LAKE_CDP = "26010"
FLORA_VISTA_CDP = "26360"
FLOYD_VILLAGE = "26570"
FOLSOM_VILLAGE = "26780"
FORT_SUMNER_VILLAGE = "27340"
FORT_WINGATE_CDP = "27410"
FRUITLAND_CDP = "27760"
GALISTEO_CDP = "27970"
GALLINA_CDP = "28180"
GALLUP_CITY = "28460"
GAMERCO_CDP = "28530"
GARFIELD_CDP = "28670"
GILA_CDP = "29160"
GILA_HOT_SPRINGS_CDP = "29230"
GLEN_ACRES_CDP = "29540"
GLENWOOD_CDP = "29790"
GLORIETA_CDP = "29860"
GOLDEN_ACRES_CDP = "30035"
GOLDEN_CDP = "30000"
GRADY_VILLAGE = "30210"
GRANTS_CITY = "30490"
GRENVILLE_VILLAGE = "30770"
HACHITA_CDP = "31190"
HAGERMAN_TOWN = "31330"
HANOVER_CDP = "31540"
HAPPY_VALLEY_CDP = "31680"
HATCH_VILLAGE = "31820"
HAYSTACK_CDP = "31925"
HERNANDEZ_CDP = "32100"
HIGH_ROLLS_CDP = "32160"
HIGHLAND_MEADOWS_CDP = "32148"
HILLSBORO_CDP = "32380"
HOBBS_CITY = "32520"
HOLLOMAN_AFB_CDP = "32940"
HOMER_C_JONES_CDP = "33122"
HOMESTEAD_CDP = "33130"
HOPE_VILLAGE = "33290"
HOT_SPRINGS_LANDING_CDP = "33640"
HOUSE_VILLAGE = "33710"
HURLEY_TOWN = "33850"
HYDE_PARK_CDP = "33920"
INDIAN_HILLS_CDP = "34430"
ISLETA_CDP = "34620"
IYANBITO_CDP = "34830"
JACONA_CDP = "34900"
JACONITA_CDP = "34925"
JAL_CITY = "35040"
JAMESTOWN_CDP = "35070"
JARALES_CDP = "35110"
JEMEZ_PUEBLO_CDP = "35250"
JEMEZ_SPRINGS_VILLAGE = "35320"
KEELER_FARM_CDP = "35595"
KINGSTON_CDP = "36090"
KIRTLAND_AFB_CDP = "36300"
KIRTLAND_TOWN = "36230"
LA_BAJADA_CDP = "36555"
LA_BOCA_CDP = "36567"
LA_CIENEGA_CDP = "36720"
LA_CUEVA_CDP_SANDOVAL_COUNTY = "36880"
LA_CUEVA_CDP_SANTA_FE_COUNTY = "36930"
LA_HACIENDA_CDP = "37407"
LA_HUERTA_CDP = "37420"
LA_JARA_CDP = "37490"
LA_JOYA_CDP = "37700"
LA_LUZ_CDP = "38330"
LA_MADERA_CDP_RIO_ARRIBA_COUNTY = "38470"
LA_MADERA_CDP_SANDOVAL_COUNTY = "38540"
LA_MESA_CDP = "38680"
LA_MESILLA_CDP = "38820"
LA_PLATA_CDP = "39030"
LA_PUEBLA_CDP = "39170"
LA_TIERRA_CDP = "40074"
LA_UNION_CDP = "40220"
LA_VILLITA_CDP = "40360"
LAGUNA_CDP = "37070"
LAKE_ARTHUR_TOWN = "37840"
LAKE_ROBERTS_CDP = "37860"
LAKE_ROBERTS_HEIGHTS_CDP = "37862"
LAKE_SUMNER_CDP = "37875"
LAKE_VALLEY_CDP = "37910"
LAMY_CDP = "38890"
LAS_CAMPANAS_CDP = "39332"
LAS_CRUCES_CITY = "39380"
LAS_MARAVILLAS_CDP = "39430"
LAS_NUTRIAS_CDP = "39450"
LAS_PALOMAS_CDP = "39520"
LAS_TUSAS_CDP = "39792"
LAS_VEGAS_CITY = "39940"
LEE_ACRES_CDP = "40525"
LEMITAR_CDP = "40570"
LINDRITH_CDP = "41130"
LITTLE_WALNUT_VILLAGE_CDP = "41340"
LIVINGSTON_WHEELER_CDP = "41420"
LLANO_DEL_MEDIO_CDP = "41620"
LOBO_CANYON_CDP = "41953"
LOCO_HILLS_CDP = "41970"
LOGAN_VILLAGE = "42040"
LORDSBURG_CITY = "42180"
LOS_ALAMOS_CDP = "42320"
LOS_CERRILLOS_CDP = "42600"
LOS_CHAVES_CDP = "42740"
LOS_LUCEROS_CDP = "43300"
LOS_LUNAS_VILLAGE = "43370"
LOS_OJOS_CDP = "43510"
LOS_RANCHOS_DE_ALBUQUERQUE_VILLAGE = "43930"
LOVING_VILLAGE = "44420"
LOVINGTON_CITY = "44490"
LOWER_FRISCO_CDP = "44595"
LUIS_LOPEZ_CDP = "45190"
LUMBERTON_CDP = "45260"
LUNA_CDP = "45330"
LYBROOK_CDP = "45365"
LYDEN_CDP = "45400"
MADRID_CDP = "46100"
MADRONE_CDP = "46170"
MAGDALENA_VILLAGE = "46310"
MALAGA_CDP = "46380"
MANUELITO_CDP = "46660"
MANZANO_CDP = "46730"
MANZANO_SPRINGS_CDP = "46770"
MAXWELL_VILLAGE = "47080"
MAYHILL_CDP = "47150"
MCCARTYS_VILLAGE_CDP = "45690"
MCGAFFEY_CDP = "45890"
MCINTOSH_CDP = "46030"
MEADOW_LAKE_CDP = "47220"
MEDANALES_CDP = "47360"
MELROSE_VILLAGE = "47570"
MESCALERO_CDP = "47920"
MESILLA_TOWN = "48060"
MESITA_CDP = "48200"
MESQUITE_CDP = "48270"
MIDDLE_FRISCO_CDP = "48425"
MIDDLE_MESA_CDP = "48435"
MIDWAY_CDP = "48480"
MILAN_VILLAGE = "48620"
MIMBRES_CDP = "48830"
MOGOLLON_CDP = "49180"
MONTEREY_PARK_CDP = "49515"
MONUMENT_CDP = "49950"
MOQUINO_CDP = "50020"
MORA_CDP = "50090"
MORIARTY_CITY = "50160"
MORNINGSIDE_CDP = "50195"
MOSQUERO_VILLAGE = "50300"
MOUNT_TAYLOR_CDP = "50615"
MOUNTAIN_VIEW_CDP_CIBOLA_COUNTY = "50512"
MOUNTAIN_VIEW_CDP_LUNA_COUNTY = "50515"
MOUNTAINAIR_TOWN = "50370"
NADINE_CDP = "50720"
NAGEEZI_CDP = "50790"
NAKAIBITO_CDP = "50860"
NAMBE_CDP = "50930"
NAPI_HEADQUARTERS_CDP = "51035"
NARA_VISA_CDP = "51140"
NASCHITTI_CDP = "51280"
NAVAJO_CDP = "51420"
NAVAJO_DAM_CDP = "51490"
NENAHNEZAD_CDP = "51715"
NEWCOMB_CDP = "51770"
NEWKIRK_CDP = "51840"
NOGAL_CDP = "52190"
NORTH_ACOMITA_VILLAGE_CDP = "52300"
NORTH_HOBBS_CDP = "52500"
NORTH_HURLEY_CDP = "52540"
NORTH_LIGHT_PLANT_CDP = "52560"
NORTH_SAN_YSIDRO_CDP = "52680"
NORTH_VALLEY_CDP = "52750"
OASIS_CDP = "53010"
OHKAY_OWINGEH_CDP = "53150"
OJO_AMARILLO_CDP = "53485"
OJO_CALIENTE_CDP = "53590"
OJO_ENCINO_CDP = "53620"
OJO_SARCO_CDP = "53730"
OLD_TOWN_CDP = "54097"
ORGAN_CDP = "54430"
OROGRANDE_CDP = "54500"
PAA_KO_CDP = "54675"
PAGUATE_CDP = "54710"
PAJARITO_MESA_CDP = "54940"
PARADISE_HILLS_CDP = "55270"
PARAJE_CDP = "55340"
PASTURA_CDP = "55550"
PEAK_PLACE_CDP = "55595"
PECAN_PARK_CDP = "55605"
PECOS_VILLAGE = "55620"
PERALTA_TOWN = "56180"
PENA_BLANCA_CDP = "55830"
PENASCO_CDP = "55900"
PICACHO_HILLS_CDP = "56748"
PICURIS_PUEBLO_CDP = "56810"
PIE_TOWN_CDP = "56950"
PINEDALE_CDP = "57160"
PINEHAVEN_CDP = "57175"
PINEHILL_CDP = "57190"
PINON_CDP = "57440"
PINOS_ALTOS_CDP = "57510"
PLACITAS_CDP_DONA_ANA_COUNTY = "57990"
PLACITAS_CDP_SANDOVAL_COUNTY = "58070"
PLAYAS_CDP = "58210"
PLEASANTON_CDP = "58420"
POJOAQUE_CDP = "58630"
POLVADERA_CDP = "58910"
PONDEROSA_CDP = "58980"
PONDEROSA_PINE_CDP = "59120"
PORTALES_CITY = "59260"
PREWITT_CDP = "59540"
PUEBLITO_CDP = "59750"
PUEBLITOS_CDP = "59820"
PUEBLO_CDP = "59840"
PUEBLO_PINTADO_CDP = "60000"
PUEBLO_OF_SANDIA_VILLAGE_CDP = "59950"
PUERTO_DE_LUNA_CDP = "60170"
PULPOTIO_BAREAS_CDP = "60205"
PUNTA_DE_AGUA_CDP = "60310"
PURTY_ROCK_CDP = "60327"
QUEMADO_CDP = "60730"
QUESTA_VILLAGE = "60870"
RADIUM_SPRINGS_CDP = "61010"
RAMAH_CDP = "61220"
RANCHO_GRANDE_CDP = "61675"
RANCHOS_DE_TAOS_CDP = "61710"
RATON_CITY = "62060"
RED_RIVER_TOWN = "62200"
RED_ROCK_RANCH_CDP = "62295"
REDROCK_CDP = "62270"
REGINA_CDP = "62340"
RESERVE_VILLAGE = "62620"
RIBERA_CDP = "62760"
RINCON_CDP = "62900"
RIO_CHIQUITO_CDP = "63110"
RIO_COMMUNITIES_CITY = "63145"
RIO_LUCIO_CDP = "63250"
RIO_RANCHO_ESTATES_CDP = "63530"
RIO_RANCHO_CITY = "63460"
RIO_EN_MEDIO_CDP = "63168"
RIVERS_CDP = "63660"
ROCK_SPRINGS_CDP = "64230"
RODEO_CDP = "64370"
RODEY_CDP = "64440"
ROSEDALE_CDP = "64900"
ROSWELL_CITY = "64930"
ROWE_CDP = "65000"
ROY_VILLAGE = "65070"
RUIDOSO_DOWNS_CITY = "65280"
RUIDOSO_VILLAGE = "65210"
SACRAMENTO_CDP = "65560"
SAGAR_CDP = "65595"
SALEM_CDP = "65840"
SAN_ACACIA_CDP = "65910"
SAN_ANTONIO_CDP = "66120"
SAN_ANTONITO_CDP_BERNALILLO_COUNTY = "66330"
SAN_ANTONITO_CDP_SOCORRO_COUNTY = "66400"
SAN_CRISTOBAL_CDP = "66540"
SAN_FELIPE_PUEBLO_CDP = "67450"
SAN_FIDEL_CDP = "67520"
SAN_ILDEFONSO_PUEBLO_CDP = "68010"
SAN_JON_VILLAGE = "68150"
SAN_JOSE_CDP_RIO_ARRIBA_COUNTY = "68430"
SAN_JOSE_CDP_SAN_MIGUEL_COUNTY = "68500"
SAN_LORENZO_CDP = "68920"
SAN_LUIS_CDP = "69060"
SAN_MATEO_CDP = "69270"
SAN_MIGUEL_CDP = "69410"
SAN_PABLO_CDP = "69645"
SAN_PEDRO_CDP = "69825"
SAN_RAFAEL_CDP = "69875"
SAN_YSIDRO_CDP = "71015"
SAN_YSIDRO_VILLAGE = "71020"
SANDIA_HEIGHTS_CDP = "66765"
SANDIA_KNOLLS_CDP = "66890"
SANDIA_PARK_CDP = "66960"
SANOSTEE_CDP = "69620"
SANTA_ANA_PUEBLO_CDP = "70250"
SANTA_CLARA_PUEBLO_CDP = "70390"
SANTA_CLARA_VILLAGE = "70270"
SANTA_CRUZ_CDP = "70460"
SANTA_FE_FOOTHILLS_CDP = "70505"
SANTA_FE_CITY = "70500"
SANTA_ROSA_CITY = "70670"
SANTA_TERESA_CDP = "70700"
SANTO_DOMINGO_PUEBLO_CDP = "70810"
SAUSAL_CDP = "71145"
SEAMA_CDP = "71440"
SEBOYETA_CDP = "71510"
SEDILLO_CDP = "71700"
SENA_CDP = "71790"
SETON_VILLAGE_CDP = "72140"
SHEEP_SPRINGS_CDP = "72600"
SHIPROCK_CDP = "72770"
SILVER_CITY_TOWN = "73260"
SKYLINE_GANIPA_CDP = "73440"
SOCORRO_CITY = "73540"
SOHAM_CDP = "73680"
SOMBRILLO_CDP = "73890"
SOUTH_ACOMITA_VILLAGE_CDP = "73925"
SOUTH_RIVER_CDP = "74275"
SOUTH_VALLEY_CDP = "74520"
SPENCERVILLE_CDP = "74660"
SPRINGER_TOWN = "74800"
STANLEY_CDP = "75010"
STONERIDGE_CDP = "75465"
SUNDANCE_CDP = "75605"
SUNLAND_PARK_CITY = "75640"
SUNLIT_HILLS_CDP = "75650"
SUNSHINE_CDP = "75710"
TAJIQUE_CDP = "76060"
TALPA_CDP = "76130"
TANO_ROAD_CDP = "76165"
TAOS_PUEBLO_CDP = "76410"
TAOS_SKI_VALLEY_VILLAGE = "76480"
TAOS_TOWN = "76200"
TATUM_TOWN = "76620"
TECOLOTE_CDP = "76760"
TECOLOTITO_CDP = "76830"
TESUQUE_CDP = "77040"
TESUQUE_PUEBLO_CDP = "77100"
TEXICO_CITY = "77250"
THOREAU_CDP = "77530"
THUNDER_MOUNTAIN_CDP = "77635"
TIERRA_AMARILLA_CDP = "77670"
TIJERAS_VILLAGE = "77880"
TIMBERLAKE_CDP = "77930"
TIMBERON_CDP = "77950"
TOHATCHI_CDP = "78440"
TOME_CDP = "78650"
TORREON_CDP_SANDOVAL_COUNTY = "79070"
TORREON_CDP_TORRANCE_COUNTY = "79140"
TORTUGAS_CDP = "79210"
TOTAH_VISTA_CDP = "79264"
TRES_ARROYOS_CDP = "79500"
TROUT_VALLEY_CDP = "79680"
TRUCHAS_CDP = "79700"
TRUTH_OR_CONSEQUENCES_CITY = "79840"
TSE_BONITO_CDP = "79885"
TUCUMCARI_CITY = "79910"
TULAROSA_VILLAGE = "79980"
TURLEY_CDP = "80120"
TWIN_FORKS_CDP = "80470"
TWIN_LAKES_CDP = "80540"
TYRONE_CDP = "80820"
UNIVERSITY_PARK_CDP = "81030"
UPPER_FRUITLAND_CDP = "81177"
UTE_PARK_CDP = "81450"
VADITO_CDP = "81520"
VADO_CDP = "81590"
VALENCIA_CDP_SANTA_FE_COUNTY = "81775"
VALENCIA_CDP_VALENCIA_COUNTY = "81800"
VALLE_VISTA_CDP = "82332"
VANDERWAGEN_CDP = "82430"
VAUGHN_TOWN = "82570"
VEGUITA_CDP = "82640"
VELARDE_CDP = "82710"
VENTURA_CDP = "82800"
VILLANUEVA_CDP = "83130"
VIRDEN_VILLAGE = "83200"
WAGON_MOUND_VILLAGE = "83340"
WATERFLOW_CDP = "83760"
WATROUS_CDP = "83830"
WEED_CDP = "83970"
WEST_HAMMOND_CDP = "84200"
WHITE_CLIFFS_CDP = "84505"
WHITE_ROCK_CDP = "84740"
WHITE_SANDS_CDP = "84845"
WHITE_SIGNAL_CDP = "84975"
WHITES_CITY_CDP = "84950"
WILLARD_VILLAGE = "85160"
WILLIAMS_ACRES_CDP = "85230"
WILLIAMSBURG_VILLAGE = "85300"
WINDMILL_CDP = "85485"
WINSTON_CDP = "85720"
YAH_TA_HEY_CDP = "85860"
YOUNGSVILLE_CDP = "86210"
ZIA_PUEBLO_CDP = "86420"
ZUNI_PUEBLO_CDP = "86595"
