# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Idaho."""


ADA = "001"
ADAMS = "003"
BANNOCK = "005"
BEAR_LAKE = "007"
BENEWAH = "009"
BINGHAM = "011"
BLAINE = "013"
BOISE = "015"
BONNER = "017"
BONNEVILLE = "019"
BOUNDARY = "021"
BUTTE = "023"
CAMAS = "025"
CANYON = "027"
CARIBOU = "029"
CASSIA = "031"
CLARK = "033"
CLEARWATER = "035"
CUSTER = "037"
ELMORE = "039"
FRANKLIN = "041"
FREMONT = "043"
GEM = "045"
GOODING = "047"
IDAHO = "049"
JEFFERSON = "051"
JEROME = "053"
KOOTENAI = "055"
LATAH = "057"
LEMHI = "059"
LEWIS = "061"
LINCOLN = "063"
MADISON = "065"
MINIDOKA = "067"
NEZ_PERCE = "069"
ONEIDA = "071"
OWYHEE = "073"
PAYETTE = "075"
POWER = "077"
SHOSHONE = "079"
TETON = "081"
TWIN_FALLS = "083"
VALLEY = "085"
WASHINGTON = "087"
