# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Michigan."""


ALCONA = "001"
ALGER = "003"
ALLEGAN = "005"
ALPENA = "007"
ANTRIM = "009"
ARENAC = "011"
BARAGA = "013"
BARRY = "015"
BAY = "017"
BENZIE = "019"
BERRIEN = "021"
BRANCH = "023"
CALHOUN = "025"
CASS = "027"
CHARLEVOIX = "029"
CHEBOYGAN = "031"
CHIPPEWA = "033"
CLARE = "035"
CLINTON = "037"
CRAWFORD = "039"
DELTA = "041"
DICKINSON = "043"
EATON = "045"
EMMET = "047"
GENESEE = "049"
GLADWIN = "051"
GOGEBIC = "053"
GRAND_TRAVERSE = "055"
GRATIOT = "057"
HILLSDALE = "059"
HOUGHTON = "061"
HURON = "063"
INGHAM = "065"
IONIA = "067"
IOSCO = "069"
IRON = "071"
ISABELLA = "073"
JACKSON = "075"
KALAMAZOO = "077"
KALKASKA = "079"
KENT = "081"
KEWEENAW = "083"
LAKE = "085"
LAPEER = "087"
LEELANAU = "089"
LENAWEE = "091"
LIVINGSTON = "093"
LUCE = "095"
MACKINAC = "097"
MACOMB = "099"
MANISTEE = "101"
MARQUETTE = "103"
MASON = "105"
MECOSTA = "107"
MENOMINEE = "109"
MIDLAND = "111"
MISSAUKEE = "113"
MONROE = "115"
MONTCALM = "117"
MONTMORENCY = "119"
MUSKEGON = "121"
NEWAYGO = "123"
OAKLAND = "125"
OCEANA = "127"
OGEMAW = "129"
ONTONAGON = "131"
OSCEOLA = "133"
OSCODA = "135"
OTSEGO = "137"
OTTAWA = "139"
PRESQUE_ISLE = "141"
ROSCOMMON = "143"
SAGINAW = "145"
SANILAC = "151"
SCHOOLCRAFT = "153"
SHIAWASSEE = "155"
ST_CLAIR = "147"
ST_JOSEPH = "149"
TUSCOLA = "157"
VAN_BUREN = "159"
WASHTENAW = "161"
WAYNE = "163"
WEXFORD = "165"
