# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Maine."""


ANDROSCOGGIN = "001"
AROOSTOOK = "003"
CUMBERLAND = "005"
FRANKLIN = "007"
HANCOCK = "009"
KENNEBEC = "011"
KNOX = "013"
LINCOLN = "015"
OXFORD = "017"
PENOBSCOT = "019"
PISCATAQUIS = "021"
SAGADAHOC = "023"
SOMERSET = "025"
WALDO = "027"
WASHINGTON = "029"
YORK = "031"
