# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Florida."""


ACACIA_VILLAS_CDP = "00075"
ALACHUA_CITY = "00375"
ALAFAYA_CDP = "00410"
ALFORD_TOWN = "00625"
ALLENTOWN_CDP = "00800"
ALTAMONTE_SPRINGS_CITY = "00950"
ALTHA_TOWN = "01000"
ALTOONA_CDP = "01050"
ALTURAS_CDP = "01100"
ALVA_CDP = "01125"
ANDREWS_CDP = "01353"
ANNA_MARIA_CITY = "01475"
APALACHICOLA_CITY = "01625"
APOLLO_BEACH_CDP = "01675"
APOPKA_CITY = "01700"
ARCADIA_CITY = "01750"
ARCHER_CITY = "01775"
ARIPEKA_CDP = "01875"
ASBURY_LAKE_CDP = "02187"
ASTATULA_TOWN = "02250"
ASTOR_CDP = "02275"
ATLANTIC_BEACH_CITY = "02400"
ATLANTIS_CITY = "02500"
AUBURNDALE_CITY = "02550"
AUCILLA_CDP = "02575"
AVALON_CDP = "02660"
AVE_MARIA_CDP = "02677"
AVENTURA_CITY = "02681"
AVON_PARK_CITY = "02750"
AZALEA_PARK_CDP = "02850"
BABSON_PARK_CDP = "02900"
BAGDAD_CDP = "02925"
BAL_HARBOUR_VILLAGE = "03275"
BALDWIN_TOWN = "03250"
BALM_CDP = "03375"
BARDMOOR_CDP = "03480"
BARTOW_CITY = "03675"
BASCOM_TOWN = "03725"
BAY_HARBOR_ISLANDS_TOWN = "03975"
BAY_HILL_CDP = "04070"
BAY_LAKE_CITY = "04150"
BAY_PINES_CDP = "04200"
BAYONET_POINT_CDP = "04162"
BAYPORT_CDP = "04250"
BAYSHORE_GARDENS_CDP = "04350"
BEACON_SQUARE_CDP = "04650"
BEAR_CREEK_CDP = "04735"
BEE_RIDGE_CDP = "04925"
BELL_TOWN = "04975"
BELLAIR_MEADOWBROOK_TERRACE_CDP = "05025"
BELLE_GLADE_CITY = "05200"
BELLE_ISLE_CITY = "05300"
BELLEAIR_BEACH_CITY = "05100"
BELLEAIR_BLUFFS_CITY = "05125"
BELLEAIR_SHORE_TOWN = "05150"
BELLEAIR_TOWN = "05075"
BELLEVIEW_CITY = "05375"
BELLVIEW_CDP = "05462"
BERKSHIRE_LAKES_CDP = "05806"
BERRYDALE_CDP = "05825"
BEVERLY_BEACH_TOWN = "06100"
BEVERLY_HILLS_CDP = "06125"
BIG_COPPITT_KEY_CDP = "06350"
BIG_PINE_KEY_CDP = "06425"
BISCAYNE_PARK_VILLAGE = "06600"
BITHLO_CDP = "06625"
BLACK_DIAMOND_CDP = "06667"
BLACK_HAMMOCK_CDP = "06670"
BLOOMINGDALE_CDP = "06875"
BLOUNTSTOWN_CITY = "06925"
BOCA_RATON_CITY = "07300"
BOKEELIA_CDP = "07375"
BONIFAY_CITY = "07450"
BONITA_SPRINGS_CITY = "07525"
BOULEVARD_GARDENS_CDP = "07687"
BOWLING_GREEN_CITY = "07775"
BOYNTON_BEACH_CITY = "07875"
BRADENTON_BEACH_CITY = "07975"
BRADENTON_CITY = "07950"
BRADFORDVILLE_CDP = "08075"
BRADLEY_JUNCTION_CDP = "08125"
BRANDON_CDP = "08150"
BRANFORD_TOWN = "08175"
BRENT_CDP = "08300"
BRINY_BREEZES_TOWN = "08575"
BRISTOL_CITY = "08600"
BROADVIEW_PARK_CDP = "08650"
BRONSON_TOWN = "08700"
BROOKER_TOWN = "08725"
BROOKRIDGE_CDP = "08762"
BROOKSVILLE_CITY = "08800"
BROWNSDALE_CDP = "08925"
BROWNSVILLE_CDP = "09000"
BUCKHEAD_RIDGE_CDP = "09315"
BUCKINGHAM_CDP = "09350"
BUENAVENTURA_LAKES_CDP = "09415"
BUNNELL_CITY = "09550"
BURNT_STORE_MARINA_CDP = "09612"
BUSHNELL_CITY = "09625"
BUTLER_BEACH_CDP = "09630"
CABANA_COLONY_CDP = "09655"
CALLAHAN_TOWN = "09700"
CALLAWAY_CITY = "09725"
CAMPBELL_CDP = "09875"
CAMPBELLTON_TOWN = "09900"
CANAL_POINT_CDP = "10100"
CAPE_CANAVERAL_CITY = "10250"
CAPE_CORAL_CITY = "10275"
CAPITOLA_CDP = "10350"
CAPTIVA_CDP = "10425"
CARRABELLE_CITY = "10725"
CARROLLWOOD_CDP = "10825"
CARYVILLE_TOWN = "10975"
CASSELBERRY_CITY = "11050"
CEDAR_GROVE_CDP = "11150"
CEDAR_KEY_CITY = "11225"
CELEBRATION_CDP = "11285"
CENTER_HILL_CITY = "11325"
CENTURY_TOWN = "11362"
CHAIRES_CDP = "11525"
CHARLESTON_PARK_CDP = "11597"
CHARLOTTE_HARBOR_CDP = "11625"
CHARLOTTE_PARK_CDP = "11650"
CHATTAHOOCHEE_CITY = "11800"
CHEVAL_CDP = "11912"
CHIEFLAND_CITY = "11925"
CHIPLEY_CITY = "11975"
CHOKOLOSKEE_CDP = "12150"
CHRISTMAS_CDP = "12250"
CHULUOTA_CDP = "12275"
CHUMUCKLA_CDP = "12300"
CINCO_BAYOU_TOWN = "12325"
CITRUS_HILLS_CDP = "12412"
CITRUS_PARK_CDP = "12425"
CITRUS_SPRINGS_CDP = "12450"
CLARCONA_CDP = "12675"
CLEARWATER_CITY = "12875"
CLERMONT_CITY = "12925"
CLEVELAND_CDP = "12950"
CLEWISTON_CITY = "13000"
CLOUD_LAKE_TOWN = "13050"
COBBTOWN_CDP = "13125"
COCOA_BEACH_CITY = "13175"
COCOA_WEST_CDP = "13225"
COCOA_CITY = "13150"
COCONUT_CREEK_CITY = "13275"
COLEMAN_CITY = "13400"
COMBEE_SETTLEMENT_CDP = "13775"
CONNERTON_CDP = "13965"
CONWAY_CDP = "14050"
COOPER_CITY_CITY = "14125"
CORAL_GABLES_CITY = "14250"
CORAL_SPRINGS_CITY = "14400"
CORAL_TERRACE_CDP = "14412"
CORTEZ_CDP = "14700"
COTTONDALE_TOWN = "14850"
COUNTRY_CLUB_CDP = "14895"
COUNTRY_WALK_CDP = "15055"
CRAWFORDVILLE_CDP = "15300"
CRESCENT_BEACH_CDP = "15325"
CRESCENT_CITY_CITY = "15375"
CRESTVIEW_CITY = "15475"
CROOKED_LAKE_PARK_CDP = "15515"
CROSS_CITY_TOWN = "15575"
CRYSTAL_LAKE_CDP = "15725"
CRYSTAL_RIVER_CITY = "15775"
CRYSTAL_SPRINGS_CDP = "15800"
CUDJOE_KEY_CDP = "15862"
CUTLER_BAY_TOWN = "15968"
CYPRESS_GARDENS_CDP = "16050"
CYPRESS_LAKE_CDP = "16062"
CYPRESS_QUARTERS_CDP = "16100"
DADE_CITY_NORTH_CDP = "16175"
DADE_CITY_CITY = "16125"
DANIA_BEACH_CITY = "16335"
DAVENPORT_CITY = "16450"
DAVIE_TOWN = "16475"
DAY_CDP = "16500"
DAYTONA_BEACH_SHORES_CITY = "16550"
DAYTONA_BEACH_CITY = "16525"
DE_LEON_SPRINGS_CDP = "16975"
DEBARY_CITY = "16675"
DEFUNIAK_SPRINGS_CITY = "16800"
DELAND_SOUTHWEST_CDP = "16937"
DELAND_CITY = "16875"
DEERFIELD_BEACH_CITY = "16725"
DELRAY_BEACH_CITY = "17100"
DELTONA_CITY = "17200"
DESOTO_ACRES_CDP = "17273"
DESOTO_LAKES_CDP = "17300"
DESTIN_CITY = "17325"
DICKERSON_CITY_CDP = "17450"
DIXONVILLE_CDP = "17710"
DOCTOR_PHILLIPS_CDP = "17725"
DORAL_CITY = "17935"
DOVER_CDP = "18075"
DUCK_KEY_CDP = "18425"
DUNDEE_TOWN = "18550"
DUNEDIN_CITY = "18575"
DUNNELLON_CITY = "18675"
EAGLE_LAKE_CITY = "18875"
EAST_BRONSON_CDP = "19025"
EAST_LAKE_CDP = "19206"
EAST_LAKE_ORIENT_PARK_CDP = "19212"
EAST_MILTON_CDP = "19275"
EAST_PALATKA_CDP = "19350"
EAST_WILLISTON_CDP = "19575"
EASTPOINT_CDP = "19400"
EATONVILLE_TOWN = "19650"
EBRO_TOWN = "19725"
EDGEWATER_CITY = "19825"
EDGEWOOD_CITY = "19900"
EGLIN_AFB_CDP = "20050"
EGYPT_LAKE_LETO_CDP = "20108"
EL_PORTAL_VILLAGE = "20650"
ELFERS_CDP = "20275"
ELLENTON_CDP = "20375"
ENGLEWOOD_CDP = "20825"
ENSLEY_CDP = "20925"
ESTERO_VILLAGE = "21150"
ESTO_TOWN = "21250"
EUSTIS_CITY = "21350"
EVERGLADES_CITY = "21425"
FAIRVIEW_SHORES_CDP = "21750"
FANNING_SPRINGS_CITY = "21850"
FEATHER_SOUND_CDP = "21945"
FELLSMERE_CITY = "22100"
FERN_PARK_CDP = "22250"
FERNANDINA_BEACH_CITY = "22175"
FERNDALE_CDP = "22225"
FERRY_PASS_CDP = "22275"
FIDELIS_CDP = "22325"
FISH_HAWK_CDP = "22387"
FISHER_ISLAND_CDP = "22375"
FIVE_POINTS_CDP = "22475"
FLAGLER_BEACH_CITY = "22550"
FLAGLER_ESTATES_CDP = "22560"
FLEMING_ISLAND_CDP = "22660"
FLORAL_CITY_CDP = "22775"
FLORIDA_CITY_CITY = "22975"
FLORIDA_GULF_COAST_UNIVERSITY_CDP = "23005"
FLORIDA_RIDGE_CDP = "23050"
FLORIDATOWN_CDP = "23125"
FOREST_CITY_CDP = "23375"
FORT_BRADEN_CDP = "23680"
FORT_DENAUD_CDP = "23730"
FORT_GREEN_CDP = "23850"
FORT_GREEN_SPRINGS_CDP = "23875"
FORT_LAUDERDALE_CITY = "24000"
FORT_MEADE_CITY = "24100"
FORT_MYERS_BEACH_TOWN = "24150"
FORT_MYERS_SHORES_CDP = "24175"
FORT_MYERS_CITY = "24125"
FORT_PIERCE_NORTH_CDP = "24337"
FORT_PIERCE_SOUTH_CDP = "24387"
FORT_PIERCE_CITY = "24300"
FORT_WALTON_BEACH_CITY = "24475"
FORT_WHITE_TOWN = "24500"
FOUNTAINEBLEAU_CDP = "24562"
FOUR_CORNERS_CDP = "24581"
FRANKLIN_PARK_CDP = "24710"
FREEPORT_CITY = "24825"
FROSTPROOF_CITY = "24900"
FRUIT_COVE_CDP = "24925"
FRUITLAND_PARK_CITY = "24975"
FRUITVILLE_CDP = "25000"
FULLER_HEIGHTS_CDP = "25025"
FUSSELS_CORNER_CDP = "25125"
GAINESVILLE_CITY = "25175"
GARCON_POINT_CDP = "25392"
GARDEN_GROVE_CDP = "25475"
GARDNER_CDP = "25550"
GATEWAY_CDP = "25655"
GENEVA_CDP = "25750"
GIBSONTON_CDP = "25900"
GIFFORD_CDP = "25925"
GLADEVIEW_CDP = "25987"
GLEN_RIDGE_TOWN = "26050"
GLEN_ST_MARY_TOWN = "26075"
GLENCOE_CDP = "26000"
GLENVAR_HEIGHTS_CDP = "26100"
GOLDEN_BEACH_TOWN = "26250"
GOLDEN_GATE_CDP = "26300"
GOLDEN_GLADES_CDP = "26375"
GOLDENROD_CDP = "26475"
GOLF_VILLAGE = "26550"
GONZALEZ_CDP = "26700"
GOODLAND_CDP = "26775"
GOTHA_CDP = "26900"
GOULDING_CDP = "26925"
GOULDS_CDP = "26950"
GRACEVILLE_CITY = "27000"
GRAND_RIDGE_TOWN = "27175"
GRANT_VALKARIA_TOWN = "27256"
GREEN_COVE_SPRINGS_CITY = "27400"
GREENACRES_CITY = "27322"
GREENBRIAR_CDP = "27360"
GREENSBORO_TOWN = "27550"
GREENVILLE_TOWN = "27575"
GREENWOOD_TOWN = "27600"
GRENELEFE_CDP = "27635"
GRETNA_CITY = "27650"
GROVE_CITY_CDP = "27775"
GROVELAND_CITY = "27800"
GULF_BREEZE_CITY = "28000"
GULF_GATE_CDP = "28045"
GULF_STREAM_TOWN = "28275"
GULFPORT_CITY = "28175"
GUN_CLUB_ESTATES_CDP = "28305"
HAINES_CITY_CITY = "28400"
HALLANDALE_BEACH_CITY = "28452"
HAMPTON_CITY = "28575"
HARBOR_BLUFFS_CDP = "28650"
HARBOUR_HEIGHTS_CDP = "28800"
HARLEM_CDP = "28925"
HARLEM_HEIGHTS_CDP = "28937"
HAROLD_CDP = "29000"
HASTINGS_CDP = "29100"
HAVANA_TOWN = "29150"
HAVERHILL_TOWN = "29200"
HAWTHORNE_CITY = "29275"
HEATHROW_CDP = "29320"
HERITAGE_BAY_CDP = "29381"
HERITAGE_PINES_CDP = "29385"
HERNANDO_BEACH_CDP = "29437"
HERNANDO_CDP = "29425"
HIALEAH_GARDENS_CITY = "30025"
HIALEAH_CITY = "30000"
HIGH_POINT_CDP = "30494"
HIGH_SPRINGS_CITY = "30525"
HIGHLAND_BEACH_TOWN = "30200"
HIGHLAND_CITY_CDP = "30225"
HIGHLAND_PARK_VILLAGE = "30325"
HILL_N_DALE_CDP = "30800"
HILLCREST_HEIGHTS_TOWN = "30700"
HILLIARD_TOWN = "30750"
HILLSBORO_BEACH_TOWN = "30850"
HILLSBORO_PINES_CDP = "30858"
HOBE_SOUND_CDP = "30975"
HOLDEN_HEIGHTS_CDP = "31025"
HOLDEN_LAKES_CDP = "31030"
HOLIDAY_CDP = "31075"
HOLLEY_CDP = "31275"
HOLLY_HILL_CITY = "31350"
HOLLYWOOD_CITY = "32000"
HOLMES_BEACH_CITY = "32150"
HOMELAND_CDP = "32250"
HOMESTEAD_BASE_CDP = "32325"
HOMESTEAD_CITY = "32275"
HOMOSASSA_CDP = "32375"
HOMOSASSA_SPRINGS_CDP = "32400"
HORIZON_WEST_CDP = "32610"
HORSESHOE_BEACH_TOWN = "32650"
HOSFORD_CDP = "32675"
HOWEY_IN_THE_HILLS_TOWN = "32775"
HUDSON_CDP = "32825"
HUNTERS_CREEK_CDP = "32967"
HURLBURT_FIELD_CDP = "32975"
HUTCHINSON_ISLAND_SOUTH_CDP = "32993"
HYPOLUXO_TOWN = "33150"
IMMOKALEE_CDP = "33250"
INDIALANTIC_TOWN = "33375"
INDIAN_CREEK_VILLAGE = "33425"
INDIAN_HARBOUR_BEACH_CITY = "33450"
INDIAN_LAKE_ESTATES_CDP = "33500"
INDIAN_RIVER_ESTATES_CDP = "33585"
INDIAN_RIVER_SHORES_TOWN = "33600"
INDIAN_ROCKS_BEACH_CITY = "33625"
INDIAN_SHORES_TOWN = "33675"
INDIANTOWN_VILLAGE = "33700"
INGLIS_TOWN = "33800"
INTERLACHEN_TOWN = "33900"
INVERNESS_HIGHLANDS_NORTH_CDP = "33958"
INVERNESS_HIGHLANDS_SOUTH_CDP = "33966"
INVERNESS_CITY = "33950"
INWOOD_CDP = "34000"
IONA_CDP = "34012"
ISLAMORADA = "34132"
ISLAND_WALK_CDP = "34185"
ISTACHATTA_CDP = "34275"
IVES_ESTATES_CDP = "34400"
JACKSONVILLE_BEACH_CITY = "35050"
JACKSONVILLE_CITY = "35000"
JACOB_CITY_CITY = "35200"
JAN_PHYL_VILLAGE_CDP = "35300"
JASMINE_ESTATES_CDP = "35350"
JASPER_CITY = "35375"
JAY_TOWN = "35425"
JENNINGS_TOWN = "35525"
JENSEN_BEACH_CDP = "35550"
JUNE_PARK_CDP = "35800"
JUNO_BEACH_TOWN = "35850"
JUNO_RIDGE_CDP = "35862"
JUPITER_FARMS_CDP = "35890"
JUPITER_INLET_COLONY_TOWN = "35900"
JUPITER_ISLAND_TOWN = "35925"
JUPITER_TOWN = "35875"
KATHLEEN_CDP = "35950"
KENDALE_LAKES_CDP = "36062"
KENDALL_CDP = "36100"
KENDALL_WEST_CDP = "36121"
KENNETH_CITY_TOWN = "36175"
KENSINGTON_PARK_CDP = "36200"
KENWOOD_ESTATES_CDP = "36220"
KEY_BISCAYNE_VILLAGE = "36300"
KEY_COLONY_BEACH_CITY = "36325"
KEY_LARGO_CDP = "36375"
KEY_VISTA_CDP = "36535"
KEY_WEST_CITY = "36550"
KEYSTONE_CDP = "36462"
KEYSTONE_HEIGHTS_CITY = "36475"
KISSIMMEE_CITY = "36950"
LA_CROSSE_TOWN = "37300"
LABELLE_CITY = "37225"
LACOOCHEE_CDP = "37275"
LADY_LAKE_TOWN = "37375"
LAGUNA_BEACH_CDP = "37500"
LAKE_ALFRED_CITY = "37525"
LAKE_BELVEDERE_ESTATES_CDP = "37542"
LAKE_BUENA_VISTA_CITY = "37625"
LAKE_BUTLER_CDP = "37648"
LAKE_BUTLER_CITY = "37650"
LAKE_CITY_CITY = "37775"
LAKE_CLARKE_SHORES_TOWN = "37800"
LAKE_HAMILTON_TOWN = "37975"
LAKE_HARBOR_CDP = "38000"
LAKE_HART_CDP = "38012"
LAKE_HELEN_CITY = "38025"
LAKE_KATHRYN_CDP = "38162"
LAKE_KERR_CDP = "38238"
LAKE_LINDSEY_CDP = "38275"
LAKE_LORRAINE_CDP = "38287"
LAKE_MACK_FOREST_HILLS_CDP = "38332"
LAKE_MAGDALENE_CDP = "38350"
LAKE_MARY_JANE_CDP = "38430"
LAKE_MARY_CITY = "38425"
LAKE_MYSTIC_CDP = "38519"
LAKE_PANASOFFKEE_CDP = "38575"
LAKE_PARK_TOWN = "38600"
LAKE_PLACID_TOWN = "38625"
LAKE_SARASOTA_CDP = "38690"
LAKE_WALES_CITY = "38950"
LAKE_WORTH_BEACH_CITY = "39081"
LAKELAND_HIGHLANDS_CDP = "38262"
LAKELAND_CITY = "38250"
LAKESIDE_CDP = "38813"
LAKEWOOD_PARK_CDP = "39062"
LAKEWOOD_RANCH_CDP = "39067"
LAMONT_CDP = "39100"
LAND_O_LAKES_CDP = "39200"
LANTANA_TOWN = "39375"
LARGO_CITY = "39425"
LAUDERDALE_LAKES_CITY = "39525"
LAUDERDALE_BY_THE_SEA_TOWN = "39475"
LAUDERHILL_CITY = "39550"
LAUREL_CDP = "39600"
LAUREL_HILL_CITY = "39650"
LAWTEY_CITY = "39700"
LAYTON_CITY = "39725"
LAZY_LAKE_VILLAGE = "39750"
LEALMAN_CDP = "39775"
LECANTO_CDP = "39825"
LEE_TOWN = "39850"
LEESBURG_CITY = "39875"
LEHIGH_ACRES_CDP = "39925"
LEISURE_CITY_CDP = "39950"
LELY_CDP = "39987"
LELY_RESORT_CDP = "40037"
LEMON_GROVE_CDP = "40100"
LIBERTY_TRIANGLE_CDP = "40387"
LIGHTHOUSE_POINT_CITY = "40450"
LIMESTONE_CDP = "40525"
LIMESTONE_CREEK_CDP = "40562"
LISBON_CDP = "40750"
LIVE_OAK_CITY = "40875"
LLOYD_CDP = "40950"
LOCHMOOR_WATERWAY_ESTATES_CDP = "40985"
LOCKHART_CDP = "41025"
LONGBOAT_KEY_TOWN = "41150"
LONGWOOD_CITY = "41250"
LOUGHMAN_CDP = "41400"
LOWER_GRAND_LAGOON_CDP = "41562"
LOXAHATCHEE_GROVES_TOWN = "41577"
LUTZ_CDP = "41775"
LYNN_HAVEN_CITY = "41825"
MACCLENNY_CITY = "41950"
MADEIRA_BEACH_CITY = "42400"
MADISON_CITY = "42425"
MAITLAND_CITY = "42575"
MALABAR_TOWN = "42625"
MALONE_TOWN = "42650"
MANALAPAN_TOWN = "42700"
MANASOTA_KEY_CDP = "42750"
MANATEE_ROAD_CDP = "42787"
MANGO_CDP = "42850"
MANGONIA_PARK_TOWN = "42900"
MARATHON_CITY = "43000"
MARCO_ISLAND_CITY = "43083"
MARCO_SHORES_HAMMOCK_BAY_CDP = "43090"
MARGATE_CITY = "43125"
MARIANNA_CITY = "43175"
MARINELAND_TOWN = "43250"
MARION_OAKS_CDP = "43300"
MARY_ESTHER_CITY = "43375"
MASARYKTOWN_CDP = "43400"
MASCOTTE_CITY = "43425"
MATLACHA_CDP = "43475"
MATLACHA_ISLES_MATLACHA_SHORES_CDP = "43484"
MAYO_TOWN = "43575"
MCGREGOR_CDP = "42090"
MCINTOSH_TOWN = "42150"
MEADOW_OAKS_CDP = "43785"
MEADOW_WOODS_CDP = "43800"
MEDLEY_TOWN = "43900"
MEDULLA_CDP = "43925"
MELBOURNE_BEACH_TOWN = "44000"
MELBOURNE_VILLAGE_TOWN = "44075"
MELBOURNE_CITY = "43975"
MEMPHIS_CDP = "44175"
MERRITT_ISLAND_CDP = "44275"
MEXICO_BEACH_CITY = "44300"
MIAMI_BEACH_CITY = "45025"
MIAMI_GARDENS_CITY = "45060"
MIAMI_LAKES_TOWN = "45100"
MIAMI_SHORES_VILLAGE = "45175"
MIAMI_SPRINGS_CITY = "45200"
MIAMI_CITY = "45000"
MICANOPY_TOWN = "45225"
MICCO_CDP = "45275"
MICCOSUKEE_CDP = "45300"
MIDDLEBURG_CDP = "45350"
MIDWAY_CDP_SANTA_ROSA_COUNTY = "45465"
MIDWAY_CDP_SEMINOLE_COUNTY = "45475"
MIDWAY_CITY = "45425"
MILTON_CITY = "45750"
MIMS_CDP = "45775"
MINNEOLA_CITY = "45900"
MIRAMAR_BEACH_CDP = "46000"
MIRAMAR_CITY = "45975"
MOLINO_CDP = "46225"
MONTICELLO_CITY = "46500"
MONTURA_CDP = "46520"
MONTVERDE_TOWN = "46525"
MOON_LAKE_CDP = "46540"
MOORE_HAVEN_CITY = "46550"
MORRISTON_CDP = "46725"
MOUNT_CARMEL_CDP = "47000"
MOUNT_DORA_CITY = "47050"
MOUNT_PLYMOUTH_CDP = "47125"
MULAT_CDP = "47175"
MULBERRY_CITY = "47200"
MUNSON_CDP = "47300"
MYRTLE_GROVE_CDP = "47550"
NAPLES_MANOR_CDP = "47650"
NAPLES_PARK_CDP = "47675"
NAPLES_CITY = "47625"
NARANJA_CDP = "47700"
NASSAU_VILLAGE_RATLIFF_CDP = "47787"
NAVARRE_BEACH_CDP = "48055"
NAVARRE_CDP = "48050"
NEPTUNE_BEACH_CITY = "48100"
NEW_PORT_RICHEY_EAST_CDP = "48525"
NEW_PORT_RICHEY_CITY = "48500"
NEW_SMYRNA_BEACH_CITY = "48625"
NEWBERRY_CITY = "48200"
NICEVILLE_CITY = "48750"
NOBLETON_CDP = "48825"
NOCATEE_CDP = "48850"
NOKOMIS_CDP = "48875"
NOMA_TOWN = "48900"
NORTH_BAY_VILLAGE_CITY = "49225"
NORTH_BROOKSVILLE_CDP = "49237"
NORTH_DELAND_CDP = "49275"
NORTH_FORT_MYERS_CDP = "49350"
NORTH_KEY_LARGO_CDP = "49406"
NORTH_LAUDERDALE_CITY = "49425"
NORTH_MERRITT_ISLAND_CDP = "49435"
NORTH_MIAMI_BEACH_CITY = "49475"
NORTH_MIAMI_CITY = "49450"
NORTH_PALM_BEACH_VILLAGE = "49600"
NORTH_PORT_CITY = "49675"
NORTH_REDINGTON_BEACH_TOWN = "49725"
NORTH_RIVER_SHORES_CDP = "49750"
NORTH_SARASOTA_CDP = "49787"
NORTH_WEEKI_WACHEE_CDP = "49905"
NORTHDALE_CDP = "49260"
OAK_HILL_CITY = "50450"
OAK_RIDGE_CDP = "50638"
OAKLAND_PARK_CITY = "50575"
OAKLAND_TOWN = "50525"
OAKLEAF_PLANTATION_CDP = "50630"
OCALA_ESTATES_CDP = "50756"
OCALA_CITY = "50750"
OCEAN_BREEZE_TOWN = "50875"
OCEAN_CITY_CDP = "50925"
OCEAN_RIDGE_TOWN = "50950"
OCKLAWAHA_CDP = "51050"
OCOEE_CITY = "51075"
ODESSA_CDP = "51100"
OJUS_CDP = "51125"
OKAHUMPKA_CDP = "51150"
OKEECHOBEE_CITY = "51200"
OLD_MIAKKA_CDP = "51342"
OLDSMAR_CITY = "51350"
OLGA_CDP = "51400"
OLYMPIA_HEIGHTS_CDP = "51475"
ON_TOP_OF_THE_WORLD_CDP = "51587"
ONA_CDP = "51500"
OPA_LOCKA_CITY = "51650"
ORANGE_CITY_CITY = "51825"
ORANGE_PARK_TOWN = "52125"
ORANGETREE_CDP = "52162"
ORCHID_TOWN = "52175"
ORIOLE_BEACH_CDP = "52250"
ORLANDO_CITY = "53000"
ORLOVISTA_CDP = "53100"
ORMOND_BEACH_CITY = "53150"
ORMOND_BY_THE_SEA_CDP = "53200"
OSPREY_CDP = "53425"
OTTER_CREEK_TOWN = "53500"
OVIEDO_CITY = "53575"
PACE_CDP = "53725"
PAGE_PARK_CDP = "53775"
PAHOKEE_CITY = "53800"
PAISLEY_CDP = "53850"
PALATKA_CITY = "53875"
PALM_BAY_CITY = "54000"
PALM_BEACH_GARDENS_CITY = "54075"
PALM_BEACH_SHORES_TOWN = "54150"
PALM_BEACH_TOWN = "54025"
PALM_CITY_CDP = "54175"
PALM_COAST_CITY = "54200"
PALM_HARBOR_CDP = "54350"
PALM_RIVER_CLAIR_MEL_CDP = "54387"
PALM_SHORES_TOWN = "54425"
PALM_SPRINGS_NORTH_CDP = "54500"
PALM_SPRINGS_VILLAGE = "54450"
PALM_VALLEY_CDP = "54525"
PALMER_RANCH_CDP = "54238"
PALMETTO_BAY_VILLAGE = "54275"
PALMETTO_ESTATES_CDP = "54300"
PALMETTO_CITY = "54250"
PALMONA_PARK_CDP = "54357"
PANACEA_CDP = "54625"
PANAMA_CITY_BEACH_CITY = "54725"
PANAMA_CITY_CITY = "54700"
PARADISE_HEIGHTS_CDP = "54912"
PARKER_CITY = "55075"
PARKLAND_CITY = "55125"
PASADENA_HILLS_CDP = "55305"
PATRICK_AFB_CDP = "55375"
PAXTON_TOWN = "55475"
PEA_RIDGE_CDP = "55532"
PEBBLE_CREEK_CDP = "55540"
PELICAN_BAY_CDP = "55650"
PELICAN_MARSH_CDP = "55680"
PEMBROKE_PARK_TOWN = "55750"
PEMBROKE_PINES_CITY = "55775"
PENNEY_FARMS_TOWN = "55875"
PENSACOLA_STATION_CDP = "56004"
PENSACOLA_CITY = "55925"
PERRY_CITY = "56150"
PIERSON_TOWN = "56425"
PINE_AIR_CDP = "56475"
PINE_CASTLE_CDP = "56500"
PINE_HILLS_CDP = "56825"
PINE_ISLAND_CDP = "56840"
PINE_ISLAND_CENTER_CDP = "56850"
PINE_LAKES_CDP = "56865"
PINE_LEVEL_CDP = "56955"
PINE_MANOR_CDP = "57025"
PINE_RIDGE_CDP_CITRUS_COUNTY = "57058"
PINE_RIDGE_CDP_COLLIER_COUNTY = "57066"
PINECRAFT_CDP = "56525"
PINECREST_VILLAGE = "56625"
PINELAND_CDP = "56875"
PINELLAS_PARK_CITY = "56975"
PINEWOOD_CDP = "57250"
PIONEER_CDP = "57320"
PITTMAN_CDP = "57380"
PLANT_CITY_CITY = "57550"
PLANTATION_CDP = "57450"
PLANTATION_ISLAND_CDP = "57492"
PLANTATION_MOBILE_HOME_PARK_CDP = "57518"
PLANTATION_CITY = "57425"
POINCIANA_CDP = "57900"
POINT_BAKER_CDP = "57908"
POLK_CITY_TOWN = "57950"
POMONA_PARK_TOWN = "58025"
POMPANO_BEACH_CITY = "58050"
PONCE_INLET_TOWN = "58200"
PONCE_DE_LEON_TOWN = "58175"
PORT_CHARLOTTE_CDP = "58350"
PORT_LABELLE_CDP = "58420"
PORT_ORANGE_CITY = "58575"
PORT_RICHEY_CITY = "58600"
PORT_SALERNO_CDP = "58727"
PORT_ST_JOE_CITY = "58675"
PORT_ST_JOHN_CDP = "58700"
PORT_ST_LUCIE_CITY = "58715"
PRETTY_BAYOU_CDP = "58962"
PRINCETON_CDP = "58975"
PROGRESS_VILLAGE_CDP = "59050"
PUNTA_GORDA_CITY = "59200"
PUNTA_RASSA_CDP = "59250"
QUAIL_RIDGE_CDP = "59311"
QUINCY_CITY = "59325"
RAIFORD_TOWN = "59400"
RAINBOW_LAKES_ESTATES_CDP = "59450"
RAINBOW_PARK_CDP = "59466"
RAINBOW_SPRINGS_CDP = "59470"
RALEIGH_CDP = "59475"
REDDICK_TOWN = "59675"
REDINGTON_BEACH_TOWN = "59725"
REDINGTON_SHORES_TOWN = "59750"
RICHMOND_HEIGHTS_CDP = "60225"
RICHMOND_WEST_CDP = "60230"
RIDGE_MANOR_CDP = "60325"
RIDGE_WOOD_HEIGHTS_CDP = "60475"
RIDGECREST_CDP = "60275"
RIO_CDP = "60550"
RIO_PINAR_CDP = "60562"
RIVER_PARK_CDP = "60785"
RIVER_RIDGE_CDP = "60835"
RIVERVIEW_CDP = "60950"
RIVIERA_BEACH_CITY = "60975"
ROCKLEDGE_CITY = "61500"
ROEVILLE_CDP = "61615"
ROOSEVELT_GARDENS_CDP = "61807"
ROSELAND_CDP = "61875"
ROTONDA_CDP = "61937"
ROYAL_PALM_BEACH_VILLAGE = "62100"
ROYAL_PALM_ESTATES_CDP = "62118"
RUSKIN_CDP = "62275"
SAFETY_HARBOR_CITY = "62425"
SAMOSET_CDP = "63225"
SAMSULA_SPRUCE_CREEK_CDP = "63362"
SAN_ANTONIO_CITY = "63375"
SAN_CARLOS_PARK_CDP = "63425"
SAN_CASTLE_CDP = "63435"
SANFORD_CITY = "63650"
SANIBEL_CITY = "63700"
SARASOTA_SPRINGS_CDP = "64325"
SARASOTA_CITY = "64175"
SATELLITE_BEACH_CITY = "64400"
SAWGRASS_CDP = "64525"
SCHALL_CIRCLE_CDP = "64547"
SCOTTSMOOR_CDP = "64625"
SEA_RANCH_LAKES_VILLAGE = "64725"
SEBASTIAN_CITY = "64825"
SEBRING_CITY = "64875"
SEFFNER_CDP = "64925"
SEMINOLE_MANOR_CDP = "65100"
SEMINOLE_CITY = "64975"
SEVILLE_CDP = "65200"
SEWALLS_POINT_TOWN = "65225"
SHADY_HILLS_CDP = "65385"
SHALIMAR_TOWN = "65425"
SHARPES_CDP = "65525"
SIESTA_KEY_CDP = "66000"
SILVER_LAKE_CDP = "66062"
SILVER_SPRINGS_CDP = "66125"
SILVER_SPRINGS_SHORES_CDP = "66175"
SILVER_SPRINGS_SHORES_EAST_CDP = "66179"
SKY_LAKE_CDP = "66425"
SNEADS_TOWN = "66725"
SOLANA_CDP = "66875"
SOPCHOPPY_CITY = "66925"
SORRENTO_CDP = "66975"
SOUTH_APOPKA_CDP = "67163"
SOUTH_BAY_CITY = "67175"
SOUTH_BEACH_CDP = "67192"
SOUTH_BRADENTON_CDP = "67258"
SOUTH_BROOKSVILLE_CDP = "67266"
SOUTH_DAYTONA_CITY = "67325"
SOUTH_GATE_RIDGE_CDP = "67450"
SOUTH_HIGHPOINT_CDP = "67462"
SOUTH_MIAMI_HEIGHTS_CDP = "67575"
SOUTH_MIAMI_CITY = "67550"
SOUTH_PALM_BEACH_TOWN = "67650"
SOUTH_PASADENA_CITY = "67675"
SOUTH_PATRICK_SHORES_CDP = "67725"
SOUTH_SARASOTA_CDP = "67887"
SOUTH_VENICE_CDP = "68100"
SOUTHCHASE_CDP = "67270"
SOUTHEAST_ARCADIA_CDP = "67355"
SOUTHGATE_CDP = "67425"
SOUTHWEST_RANCHES_TOWN = "68135"
SPRING_HILL_CDP = "68350"
SPRING_LAKE_CDP = "68375"
SPRING_RIDGE_CDP = "68435"
SPRINGFIELD_CITY = "68275"
SPRINGHILL_CDP = "68365"
ST_AUGUSTINE_BEACH_CITY = "62525"
ST_AUGUSTINE_SHORES_CDP = "62550"
ST_AUGUSTINE_SOUTH_CDP = "62562"
ST_AUGUSTINE_CITY = "62500"
ST_CLOUD_CITY = "62625"
ST_GEORGE_ISLAND_CDP = "62650"
ST_JAMES_CITY_CDP = "62675"
ST_LEO_TOWN = "62775"
ST_LUCIE_VILLAGE_TOWN = "62800"
ST_MARKS_CITY = "62825"
ST_PETE_BEACH_CITY = "62885"
ST_PETERSBURG_CITY = "63000"
STACEY_STREET_CDP = "68487"
STARKE_CITY = "68525"
STEINHATCHEE_CDP = "68625"
STOCK_ISLAND_CDP = "68800"
STUART_CITY = "68875"
SUGARMILL_WOODS_CDP = "68950"
SUMATRA_CDP = "69025"
SUN_CITY_CENTER_CDP = "69250"
SUNCOAST_ESTATES_CDP = "69275"
SUNNY_ISLES_BEACH_CITY = "69555"
SUNRISE_CITY = "69700"
SUNSET_CDP = "69812"
SURFSIDE_TOWN = "70075"
SWEETWATER_CITY = "70345"
TAFT_CDP = "70525"
TALLAHASSEE_CITY = "70600"
TAMARAC_CITY = "70675"
TAMIAMI_CDP = "70700"
TAMPA_CITY = "71000"
TANGELO_PARK_CDP = "71075"
TANGERINE_CDP = "71100"
TARPON_SPRINGS_CITY = "71150"
TAVARES_CITY = "71225"
TAVERNIER_CDP = "71250"
TAYLOR_CREEK_CDP = "71300"
TEMPLE_TERRACE_CITY = "71400"
TEQUESTA_VILLAGE = "71525"
THE_ACREAGE_CDP = "71564"
THE_CROSSINGS_CDP = "71567"
THE_HAMMOCKS_CDP = "71569"
THE_MEADOWS_CDP = "71580"
THE_VILLAGES_CDP = "71625"
THONOTOSASSA_CDP = "71725"
THREE_LAKES_CDP = "71741"
THREE_OAKS_CDP = "71758"
TICE_CDP = "71800"
TIERRA_VERDE_CDP = "71825"
TIGER_POINT_CDP = "71842"
TILDENVILLE_CDP = "71850"
TIMBER_PINES_CDP = "71867"
TITUSVILLE_CITY = "71900"
TOWN_N_COUNTRY_CDP = "72145"
TREASURE_ISLAND_CITY = "72325"
TRENTON_CITY = "72350"
TRILBY_CDP = "72425"
TRINITY_CDP = "72442"
TROPICAL_PARK_CDP = "72521"
TYNDALL_AFB_CDP = "72875"
UMATILLA_CITY = "73025"
UNION_PARK_CDP = "73075"
UNIVERSITY_CDP_HILLSBOROUGH_COUNTY = "73163"
UNIVERSITY_CDP_ORANGE_COUNTY = "73172"
UPPER_GRAND_LAGOON_CDP = "73312"
VALPARAISO_CITY = "73675"
VALRICO_CDP = "73700"
VAMO_CDP = "73725"
VENICE_GARDENS_CDP = "73950"
VENICE_CITY = "73900"
VERANDAH_CDP = "74016"
VERNON_CITY = "74125"
VERO_BEACH_SOUTH_CDP = "74200"
VERO_BEACH_CITY = "74150"
VERO_LAKE_ESTATES_CDP = "74225"
VERONA_WALK_CDP = "74235"
VIERA_EAST_CDP = "74368"
VIERA_WEST_CDP = "74370"
VILANO_BEACH_CDP = "74400"
VILLAS_CDP = "74512"
VINEYARDS_CDP = "74562"
VIRGINIA_GARDENS_VILLAGE = "74575"
WABASSO_BEACH_CDP = "74635"
WABASSO_CDP = "74625"
WACISSA_CDP = "74700"
WAHNETA_CDP = "74775"
WALDO_CITY = "74925"
WALLACE_CDP = "74975"
WARM_MINERAL_SPRINGS_CDP = "75175"
WARRINGTON_CDP = "75200"
WASHINGTON_PARK_CDP = "75225"
WATERGATE_CDP = "75275"
WATERTOWN_CDP = "75300"
WAUCHULA_CITY = "75375"
WAUKEENAH_CDP = "75425"
WAUSAU_TOWN = "75450"
WAVERLY_CDP = "75475"
WEBSTER_CITY = "75600"
WEDGEFIELD_CDP = "75612"
WEEKI_WACHEE_GARDENS_CDP = "75641"
WEKIWA_SPRINGS_CDP = "75725"
WELAKA_TOWN = "75750"
WELLINGTON_VILLAGE = "75812"
WESLEY_CHAPEL_CDP = "75875"
WEST_BRADENTON_CDP = "76050"
WEST_CANAVERAL_GROVES_CDP = "76058"
WEST_DELAND_CDP = "76087"
WEST_LEALMAN_CDP = "76481"
WEST_LITTLE_RIVER_CDP = "76487"
WEST_MELBOURNE_CITY = "76500"
WEST_MIAMI_CITY = "76525"
WEST_PALM_BEACH_CITY = "76600"
WEST_PARK_CITY = "76658"
WEST_PENSACOLA_CDP = "76675"
WEST_PERRINE_CDP = "76700"
WEST_SAMOSET_CDP = "76740"
WEST_VERO_CORRIDOR_CDP = "76937"
WESTCHASE_CDP = "76062"
WESTCHESTER_CDP = "76075"
WESTGATE_CDP = "76290"
WESTLAKE_CITY = "76417"
WESTON_CITY = "76582"
WESTVIEW_CDP = "76950"
WESTVILLE_TOWN = "76975"
WESTWOOD_LAKES_CDP = "77075"
WEWAHITCHKA_CITY = "77100"
WHISKEY_CREEK_CDP = "77137"
WHITE_CITY_CDP = "77275"
WHITE_SPRINGS_TOWN = "77400"
WHITFIELD_CDP_MANATEE_COUNTY = "77467"
WHITFIELD_CDP_SANTA_ROSA_COUNTY = "77470"
WILDWOOD_CITY = "77675"
WILLIAMSBURG_CDP = "77735"
WILLISTON_HIGHLANDS_CDP = "77837"
WILLISTON_CITY = "77825"
WILLOW_OAK_CDP = "77862"
WILTON_MANORS_CITY = "78000"
WIMAUMA_CDP = "78025"
WINDERMERE_TOWN = "78050"
WINDING_CYPRESS_CDP = "78063"
WINDSOR_CDP = "78110"
WINTER_BEACH_CDP = "78225"
WINTER_GARDEN_CITY = "78250"
WINTER_HAVEN_CITY = "78275"
WINTER_PARK_CITY = "78300"
WINTER_SPRINGS_CITY = "78325"
WISCON_CDP = "78340"
WOODLAWN_BEACH_CDP = "78500"
WOODVILLE_CDP = "78700"
WORLD_GOLF_VILLAGE_CDP = "78740"
WORTHINGTON_SPRINGS_TOWN = "78775"
WRIGHT_CDP = "78800"
YALAHA_CDP = "78900"
YANKEETOWN_TOWN = "78925"
YEEHAW_JUNCTION_CDP = "78975"
YULEE_CDP = "79175"
ZELLWOOD_CDP = "79200"
ZEPHYRHILLS_NORTH_CDP = "79231"
ZEPHYRHILLS_SOUTH_CDP = "79237"
ZEPHYRHILLS_WEST_CDP = "79243"
ZEPHYRHILLS_CITY = "79225"
ZOLFO_SPRINGS_TOWN = "79250"
