# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Nebraska."""


ABIE_VILLAGE = "00205"
ADAMS_VILLAGE = "00240"
AGNEW_CDP = "00380"
AINSWORTH_CITY = "00415"
ALBION_CITY = "00555"
ALDA_VILLAGE = "00625"
ALEXANDRIA_VILLAGE = "00730"
ALLEN_VILLAGE = "00870"
ALLIANCE_CITY = "00905"
ALMA_CITY = "00975"
ALVO_VILLAGE = "01150"
AMES_CDP = "01220"
AMHERST_VILLAGE = "01290"
ANOKA_VILLAGE = "01465"
ANSELMO_VILLAGE = "01500"
ANSLEY_VILLAGE = "01535"
ARAPAHOE_CITY = "01780"
ARCADIA_VILLAGE = "01850"
ARCHER_CDP = "01920"
ARLINGTON_VILLAGE = "01990"
ARNOLD_VILLAGE = "02095"
ARTHUR_VILLAGE = "02200"
ASHLAND_CITY = "02305"
ASHTON_VILLAGE = "02375"
ATEN_CDP = "02480"
ATKINSON_CITY = "02550"
ATLANTA_VILLAGE = "02620"
AUBURN_CITY = "02655"
AURORA_CITY = "02690"
AVOCA_VILLAGE = "02795"
AXTELL_VILLAGE = "02830"
AYR_VILLAGE = "02865"
BANCROFT_VILLAGE = "03005"
BARADA_VILLAGE = "03040"
BARNESTON_VILLAGE = "03075"
BARTLETT_VILLAGE = "03145"
BARTLEY_VILLAGE = "03180"
BASSETT_CITY = "03215"
BATTLE_CREEK_CITY = "03250"
BAYARD_CITY = "03285"
BAZILE_MILLS_VILLAGE = "03355"
BEACON_VIEW_CDP = "03377"
BEATRICE_CITY = "03390"
BEAVER_CITY_CITY = "03495"
BEAVER_CROSSING_VILLAGE = "03530"
BEE_VILLAGE = "03600"
BEEMER_VILLAGE = "03635"
BELDEN_VILLAGE = "03775"
BELGRADE_VILLAGE = "03810"
BELLEVUE_CITY = "03950"
BELLWOOD_VILLAGE = "04020"
BELMAR_CDP = "04055"
BELVIDERE_VILLAGE = "04160"
BENEDICT_VILLAGE = "04195"
BENKELMAN_CITY = "04230"
BENNET_VILLAGE = "04300"
BENNINGTON_CITY = "04405"
BEREA_CDP = "04545"
BERTRAND_VILLAGE = "04615"
BERWYN_VILLAGE = "04650"
BIG_SPRINGS_VILLAGE = "04895"
BLADEN_VILLAGE = "05140"
BLAIR_CITY = "05350"
BLOOMFIELD_CITY = "05455"
BLOOMINGTON_VILLAGE = "05490"
BLUE_HILL_CITY = "05560"
BLUE_SPRINGS_CITY = "05630"
BOW_VALLEY_CDP = "05980"
BOYS_TOWN_VILLAGE = "06015"
BRADSHAW_VILLAGE = "06050"
BRADY_VILLAGE = "06085"
BRAINARD_VILLAGE = "06120"
BREWSTER_VILLAGE = "06260"
BRIDGEPORT_CITY = "06295"
BRISTOW_VILLAGE = "06400"
BROADWATER_VILLAGE = "06470"
BROCK_VILLAGE = "06505"
BROKEN_BOW_CITY = "06610"
BROWNLEE_CDP = "06680"
BROWNVILLE_VILLAGE = "06750"
BRULE_VILLAGE = "06785"
BRUNING_VILLAGE = "06820"
BRUNO_VILLAGE = "06855"
BRUNSWICK_VILLAGE = "06890"
BURCHARD_VILLAGE = "07065"
BURR_VILLAGE = "07205"
BURTON_VILLAGE = "07310"
BURWELL_CITY = "07345"
BUSHNELL_VILLAGE = "07415"
BUTTE_VILLAGE = "07485"
BYRON_VILLAGE = "07555"
CAIRO_VILLAGE = "07625"
CALLAWAY_VILLAGE = "07660"
CAMBRIDGE_CITY = "07730"
CAMPBELL_VILLAGE = "07870"
CARLETON_VILLAGE = "07975"
CARROLL_VILLAGE = "08010"
CEDAR_BLUFFS_VILLAGE = "08150"
CEDAR_CREEK_VILLAGE = "08185"
CEDAR_RAPIDS_VILLAGE = "08220"
CENTER_VILLAGE = "08360"
CENTRAL_CITY_CITY = "08535"
CERESCO_VILLAGE = "08570"
CHADRON_CITY = "08605"
CHALCO_CDP = "08640"
CHAMBERS_VILLAGE = "08675"
CHAMPION_CDP = "08745"
CHAPMAN_VILLAGE = "08780"
CHAPPELL_CITY = "08885"
CHENEY_CDP = "08990"
CHESTER_VILLAGE = "09095"
CLARKS_VILLAGE = "09165"
CLARKSON_CITY = "09200"
CLATONIA_VILLAGE = "09270"
CLAY_CENTER_CITY = "09375"
CLEARWATER_VILLAGE = "09445"
CLINTON_VILLAGE = "09655"
CODY_VILLAGE = "09760"
COLERIDGE_VILLAGE = "09865"
COLON_VILLAGE = "10005"
COLUMBUS_CITY = "10110"
COMSTOCK_VILLAGE = "10180"
CONCORD_VILLAGE = "10250"
COOK_VILLAGE = "10390"
CORDOVA_VILLAGE = "10495"
CORNLEA_VILLAGE = "10600"
CORTLAND_VILLAGE = "10635"
COTESFIELD_VILLAGE = "10740"
COWLES_VILLAGE = "10985"
COZAD_CITY = "11020"
CRAB_ORCHARD_VILLAGE = "11055"
CRAIG_VILLAGE = "11090"
CRAWFORD_CITY = "11195"
CREIGHTON_CITY = "11230"
CRESTON_VILLAGE = "11300"
CRETE_CITY = "11370"
CROFTON_CITY = "11440"
CROOKSTON_VILLAGE = "11475"
CULBERTSON_VILLAGE = "11615"
CURTIS_CITY = "11825"
CUSHING_VILLAGE = "11860"
DAKOTA_CITY_CITY = "12000"
DALTON_VILLAGE = "12070"
DANBURY_VILLAGE = "12105"
DANNEBROG_VILLAGE = "12140"
DAVENPORT_VILLAGE = "12245"
DAVEY_VILLAGE = "12280"
DAVID_CITY_CITY = "12315"
DAWSON_VILLAGE = "12420"
DAYKIN_VILLAGE = "12455"
DE_WITT_VILLAGE = "13015"
DECATUR_VILLAGE = "12525"
DENTON_VILLAGE = "12770"
DESHLER_CITY = "12840"
DEWEESE_VILLAGE = "12945"
DILLER_VILLAGE = "13085"
DIX_VILLAGE = "13190"
DIXON_VILLAGE = "13225"
DODGE_VILLAGE = "13295"
DONIPHAN_VILLAGE = "13365"
DORCHESTER_VILLAGE = "13435"
DOUGLAS_VILLAGE = "13505"
DU_BOIS_VILLAGE = "13750"
DUNBAR_VILLAGE = "13855"
DUNCAN_VILLAGE = "13890"
DUNNING_VILLAGE = "13960"
DWIGHT_VILLAGE = "14065"
EAGLE_VILLAGE = "14100"
EDDYVILLE_VILLAGE = "14380"
EDGAR_CITY = "14450"
EDISON_VILLAGE = "14520"
ELBA_VILLAGE = "14555"
ELGIN_CITY = "14730"
ELK_CREEK_VILLAGE = "14975"
ELM_CREEK_VILLAGE = "15360"
ELMWOOD_VILLAGE = "15430"
ELSIE_VILLAGE = "15500"
ELWOOD_VILLAGE = "15570"
ELYRIA_VILLAGE = "15605"
EMERALD_CDP = "15675"
EMERSON_VILLAGE = "15710"
EMMET_VILLAGE = "15815"
ENDERS_CDP = "15885"
ENDICOTT_VILLAGE = "15920"
ERICSON_VILLAGE = "16025"
EUSTIS_VILLAGE = "16165"
EWING_VILLAGE = "16270"
EXETER_VILLAGE = "16340"
FAIRBURY_CITY = "16410"
FAIRFIELD_CITY = "16445"
FAIRMONT_VILLAGE = "16550"
FALLS_CITY_CITY = "16655"
FARNAM_VILLAGE = "16725"
FARWELL_VILLAGE = "16760"
FILLEY_VILLAGE = "16830"
FIRTH_VILLAGE = "16935"
FONTANELLE_CDP = "17040"
FORDYCE_VILLAGE = "17110"
FORT_CALHOUN_CITY = "17145"
FOSTER_VILLAGE = "17320"
FRANKLIN_CITY = "17530"
FREMONT_CITY = "17670"
FRIEND_CITY = "17775"
FULLERTON_CITY = "17810"
FUNK_VILLAGE = "17880"
GANDY_VILLAGE = "17950"
GARLAND_VILLAGE = "18230"
GARRISON_VILLAGE = "18300"
GENEVA_CITY = "18405"
GENOA_CITY = "18475"
GERING_CITY = "18580"
GIBBON_CITY = "18615"
GILEAD_VILLAGE = "18720"
GILTNER_VILLAGE = "18825"
GLENVIL_VILLAGE = "19070"
GLENWOOD_CDP = "19160"
GOEHNER_VILLAGE = "19245"
GORDON_CITY = "19350"
GOTHENBURG_CITY = "19385"
GRAFTON_VILLAGE = "19455"
GRAND_ISLAND_CITY = "19595"
GRANT_CITY = "19910"
GREELEY_CENTER_VILLAGE = "20050"
GREENWOOD_VILLAGE = "20190"
GRESHAM_VILLAGE = "20225"
GRETNA_CITY = "20260"
GROSS_VILLAGE = "20295"
GUIDE_ROCK_VILLAGE = "20365"
GURLEY_VILLAGE = "20435"
HADAR_VILLAGE = "20470"
HAIGLER_VILLAGE = "20540"
HALLAM_VILLAGE = "20610"
HALSEY_VILLAGE = "20680"
HAMLET_VILLAGE = "20750"
HAMPTON_VILLAGE = "20785"
HARBINE_VILLAGE = "20960"
HARDY_VILLAGE = "20995"
HARRISBURG_CDP = "21030"
HARRISON_VILLAGE = "21240"
HARTINGTON_CITY = "21275"
HARVARD_CITY = "21345"
HASTINGS_CITY = "21415"
HAY_SPRINGS_VILLAGE = "21730"
HAYES_CENTER_VILLAGE = "21660"
HAZARD_VILLAGE = "21765"
HEARTWELL_VILLAGE = "21835"
HEBRON_CITY = "21905"
HEMINGFORD_VILLAGE = "22045"
HENDERSON_CITY = "22080"
HENDLEY_VILLAGE = "22115"
HENRY_VILLAGE = "22150"
HERMAN_VILLAGE = "22185"
HERSHEY_VILLAGE = "22290"
HICKMAN_CITY = "22325"
HILDRETH_VILLAGE = "22430"
HOLBROOK_VILLAGE = "22605"
HOLDREGE_CITY = "22640"
HOLMESVILLE_CDP = "22780"
HOLSTEIN_VILLAGE = "22815"
HOMER_VILLAGE = "22920"
HOOPER_CITY = "23025"
HORDVILLE_VILLAGE = "23200"
HOSKINS_VILLAGE = "23235"
HOWARD_CITY_BOELUS_VILLAGE = "23270"
HOWELLS_VILLAGE = "23340"
HUBBARD_VILLAGE = "23375"
HUBBELL_VILLAGE = "23410"
HUMBOLDT_CITY = "23445"
HUMPHREY_CITY = "23480"
HUNTLEY_VILLAGE = "23550"
HYANNIS_VILLAGE = "23655"
IMPERIAL_CITY = "23690"
INAVALE_CDP = "23725"
INDIANOLA_CITY = "23830"
INGLEWOOD_VILLAGE = "23970"
INLAND_CDP = "24005"
INMAN_VILLAGE = "24075"
ITHACA_VILLAGE = "24285"
JACKSON_VILLAGE = "24355"
JANSEN_VILLAGE = "24530"
JOHNSON_VILLAGE = "24670"
JOHNSTOWN_VILLAGE = "24740"
JULIAN_VILLAGE = "24915"
JUNIATA_VILLAGE = "24950"
KEARNEY_CITY = "25055"
KENESAW_VILLAGE = "25160"
KENNARD_VILLAGE = "25230"
KEYSTONE_CDP = "25335"
KILGORE_VILLAGE = "25405"
KIMBALL_CITY = "25475"
KING_LAKE_CDP = "25510"
KRAMER_CDP = "25720"
LA_PLATTE_CDP = "26315"
LA_VISTA_CITY = "26385"
LAKEVIEW_CDP = "26150"
LAMAR_VILLAGE = "26175"
LAUREL_CITY = "26350"
LAWRENCE_VILLAGE = "26420"
LEBANON_VILLAGE = "26455"
LEIGH_VILLAGE = "26560"
LEMOYNE_CDP = "26595"
LESHARA_VILLAGE = "26630"
LEWELLEN_VILLAGE = "26805"
LEWISTON_VILLAGE = "26875"
LEXINGTON_CITY = "26910"
LIBERTY_VILLAGE = "26980"
LINCOLN_CITY = "28000"
LINDSAY_VILLAGE = "28105"
LINDY_CDP = "28140"
LINOMA_BEACH_CDP = "28165"
LINWOOD_VILLAGE = "28245"
LISCO_CDP = "28315"
LITCHFIELD_VILLAGE = "28350"
LODGEPOLE_VILLAGE = "28420"
LONG_PINE_CITY = "29050"
LOOMIS_VILLAGE = "29085"
LORENZO_CDP = "29120"
LORETTO_CDP = "29155"
LORTON_VILLAGE = "29175"
LOUISVILLE_CITY = "29260"
LOUP_CITY_CITY = "29470"
LUSHTON_VILLAGE = "29645"
LYMAN_VILLAGE = "29715"
LYNCH_VILLAGE = "29750"
LYONS_CITY = "29855"
MACY_CDP = "30170"
MADISON_CITY = "30240"
MADRID_VILLAGE = "30275"
MAGNET_VILLAGE = "30310"
MALCOLM_VILLAGE = "30345"
MALMO_VILLAGE = "30380"
MANLEY_VILLAGE = "30415"
MARQUETTE_VILLAGE = "30730"
MARTELL_CDP = "30835"
MARTIN_CDP = "30905"
MARTINSBURG_VILLAGE = "30940"
MASKELL_VILLAGE = "31045"
MASON_CITY_VILLAGE = "31115"
MAX_CDP = "31150"
MAXWELL_VILLAGE = "31220"
MAYWOOD_VILLAGE = "31325"
MCCOOK_CITY = "29925"
MCCOOL_JUNCTION_VILLAGE = "29960"
MCGREW_VILLAGE = "30030"
MCLEAN_VILLAGE = "30065"
MEAD_VILLAGE = "31395"
MEADOW_GROVE_VILLAGE = "31465"
MELBETA_VILLAGE = "31570"
MELIA_CDP = "31605"
MEMPHIS_VILLAGE = "31640"
MERNA_VILLAGE = "31780"
MERRIMAN_VILLAGE = "31815"
MILFORD_CITY = "32060"
MILLER_VILLAGE = "32130"
MILLIGAN_VILLAGE = "32200"
MINATARE_CITY = "32305"
MINDEN_CITY = "32340"
MITCHELL_CITY = "32410"
MONOWI_VILLAGE = "32550"
MONROE_VILLAGE = "32585"
MOOREFIELD_VILLAGE = "32760"
MORRILL_VILLAGE = "32830"
MORSE_BLUFF_VILLAGE = "32865"
MULLEN_VILLAGE = "33250"
MURDOCK_VILLAGE = "33320"
MURRAY_VILLAGE = "33425"
NAPER_VILLAGE = "33530"
NAPONEE_VILLAGE = "33565"
NEBRASKA_CITY_CITY = "33705"
NEHAWKA_VILLAGE = "33740"
NELIGH_CITY = "33775"
NELSON_CITY = "33880"
NEMAHA_VILLAGE = "33950"
NENZEL_VILLAGE = "33985"
NEWCASTLE_VILLAGE = "34090"
NEWMAN_GROVE_CITY = "34230"
NEWPORT_VILLAGE = "34265"
NICKERSON_VILLAGE = "34300"
NIOBRARA_VILLAGE = "34370"
NORA_VILLAGE = "34545"
NORFOLK_CITY = "34615"
NORMAN_VILLAGE = "34650"
NORTH_BEND_CITY = "34720"
NORTH_LOUP_VILLAGE = "34825"
NORTH_PLATTE_CITY = "35000"
ONEILL_CITY = "37105"
OAK_VILLAGE = "35245"
OAKDALE_VILLAGE = "35385"
OAKLAND_CITY = "35490"
OBERT_VILLAGE = "35560"
OCONTO_VILLAGE = "35665"
OCTAVIA_VILLAGE = "35700"
ODELL_VILLAGE = "35735"
ODESSA_CDP = "35770"
OFFUTT_AFB_CDP = "35875"
OGALLALA_CITY = "35980"
OHIOWA_VILLAGE = "36015"
OMAHA_CITY = "37000"
ONG_VILLAGE = "37140"
ORCHARD_VILLAGE = "37210"
ORD_CITY = "37280"
ORLEANS_VILLAGE = "37420"
OSCEOLA_CITY = "37525"
OSHKOSH_CITY = "37560"
OSMOND_CITY = "37595"
OTOE_VILLAGE = "37630"
OVERLAND_CDP = "37735"
OVERTON_VILLAGE = "37770"
OXFORD_VILLAGE = "37910"
PAGE_VILLAGE = "38085"
PALISADE_VILLAGE = "38130"
PALMER_VILLAGE = "38160"
PALMYRA_VILLAGE = "38190"
PANAMA_VILLAGE = "38225"
PAPILLION_CITY = "38295"
PARKS_CDP = "38365"
PAWNEE_CITY_CITY = "38575"
PAXTON_VILLAGE = "38610"
PENDER_VILLAGE = "38750"
PERU_CITY = "38960"
PETERSBURG_VILLAGE = "38995"
PHILLIPS_VILLAGE = "39030"
PICKRELL_VILLAGE = "39065"
PIERCE_CITY = "39100"
PILGER_VILLAGE = "39135"
PLAINVIEW_CITY = "39170"
PLATTE_CENTER_VILLAGE = "39310"
PLATTSMOUTH_CITY = "39345"
PLEASANT_DALE_VILLAGE = "39380"
PLEASANTON_VILLAGE = "39450"
PLYMOUTH_VILLAGE = "39590"
POLK_VILLAGE = "39660"
PONCA_CITY = "39695"
POOLE_CDP = "39835"
POTTER_VILLAGE = "39870"
PRAGUE_VILLAGE = "39975"
PRAIRIE_HOME_CDP = "40255"
PRESTON_VILLAGE = "40325"
PRIMROSE_VILLAGE = "40360"
PRINCETON_CDP = "40395"
PROSSER_VILLAGE = "40430"
RAEVILLE_CDP = "40535"
RAGAN_VILLAGE = "40570"
RALSTON_CITY = "40605"
RANDOLPH_CITY = "40675"
RAVENNA_CITY = "40710"
RAYMOND_VILLAGE = "40780"
RED_CLOUD_CITY = "40920"
REPUBLICAN_CITY_VILLAGE = "41130"
REYNOLDS_VILLAGE = "41235"
RICHFIELD_CDP = "41340"
RICHLAND_VILLAGE = "41375"
RISING_CITY_VILLAGE = "41480"
RIVERDALE_VILLAGE = "41515"
RIVERTON_VILLAGE = "41760"
ROCA_VILLAGE = "41830"
ROCKVILLE_VILLAGE = "42075"
ROGERS_VILLAGE = "42145"
ROSALIE_VILLAGE = "42250"
ROSCOE_CDP = "42285"
ROSELAND_VILLAGE = "42355"
ROYAL_VILLAGE = "42495"
RULO_VILLAGE = "42670"
RUSHVILLE_CITY = "42775"
RUSKIN_VILLAGE = "42810"
SALEM_VILLAGE = "43370"
SANTEE_VILLAGE = "43475"
SARBEN_CDP = "43650"
SARGENT_CITY = "43685"
SARONVILLE_VILLAGE = "43755"
SCHUYLER_CITY = "44035"
SCOTIA_VILLAGE = "44070"
SCOTTSBLUFF_CITY = "44245"
SCRIBNER_CITY = "44280"
SENECA_CDP = "44385"
SEWARD_CITY = "44420"
SHELBY_VILLAGE = "44595"
SHELTON_VILLAGE = "44700"
SHICKLEY_VILLAGE = "45085"
SHOLES_VILLAGE = "45190"
SHUBERT_VILLAGE = "45225"
SIDNEY_CITY = "45295"
SILVER_CREEK_VILLAGE = "45400"
SMITHFIELD_VILLAGE = "45575"
SNYDER_VILLAGE = "45610"
SOUTH_BEND_VILLAGE = "45680"
SOUTH_SIOUX_CITY_CITY = "46030"
SPALDING_VILLAGE = "46135"
SPENCER_VILLAGE = "46275"
SPRAGUE_VILLAGE = "46380"
SPRINGFIELD_CITY = "46520"
SPRINGVIEW_VILLAGE = "46625"
ST_EDWARD_CITY = "43055"
ST_HELENA_VILLAGE = "43090"
ST_LIBORY_CDP = "43160"
ST_PAUL_CITY = "43265"
STAMFORD_VILLAGE = "46695"
STANTON_CITY = "46800"
STAPLEHURST_VILLAGE = "46835"
STAPLETON_VILLAGE = "46870"
STEELE_CITY_VILLAGE = "47010"
STEINAUER_VILLAGE = "47080"
STELLA_VILLAGE = "47115"
STERLING_VILLAGE = "47150"
STOCKHAM_VILLAGE = "47220"
STOCKVILLE_VILLAGE = "47290"
STRANG_VILLAGE = "47360"
STRATTON_VILLAGE = "47395"
STROMSBURG_CITY = "47465"
STUART_VILLAGE = "47500"
SUMNER_VILLAGE = "47675"
SUNOL_CDP = "47745"
SUPERIOR_CITY = "47815"
SURPRISE_VILLAGE = "47850"
SUTHERLAND_VILLAGE = "47920"
SUTTON_CITY = "47955"
SWANTON_VILLAGE = "48060"
SYRACUSE_CITY = "48235"
TABLE_ROCK_VILLAGE = "48270"
TALMAGE_VILLAGE = "48305"
TAMORA_CDP = "48340"
TARNOV_VILLAGE = "48410"
TAYLOR_VILLAGE = "48445"
TECUMSEH_CITY = "48480"
TEKAMAH_CITY = "48515"
TERRYTOWN_CITY = "48585"
THAYER_VILLAGE = "48690"
THEDFORD_VILLAGE = "48760"
THURSTON_VILLAGE = "48900"
TILDEN_CITY = "48935"
TOBIAS_VILLAGE = "49005"
TRENTON_VILLAGE = "49145"
TRUMBULL_VILLAGE = "49285"
TRYON_CDP = "49320"
UEHLING_VILLAGE = "49425"
ULYSSES_VILLAGE = "49460"
UNADILLA_VILLAGE = "49530"
UNION_VILLAGE = "49635"
UPLAND_VILLAGE = "49880"
UTICA_VILLAGE = "49915"
VALENTINE_CITY = "49950"
VALLEY_CITY = "50020"
VALPARAISO_VILLAGE = "50125"
VENANGO_VILLAGE = "50230"
VENICE_CDP = "50265"
VERDEL_VILLAGE = "50335"
VERDIGRE_VILLAGE = "50370"
VERDON_VILLAGE = "50510"
VIRGINIA_VILLAGE = "50790"
WACO_VILLAGE = "50895"
WAHOO_CITY = "50965"
WAKEFIELD_CITY = "51070"
WALLACE_VILLAGE = "51175"
WALTHILL_VILLAGE = "51245"
WALTON_CDP = "51280"
WANN_CDP = "51350"
WASHINGTON_VILLAGE = "51595"
WATERBURY_VILLAGE = "51630"
WATERLOO_VILLAGE = "51665"
WAUNETA_VILLAGE = "51700"
WAUSA_VILLAGE = "51735"
WAVERLY_CITY = "51770"
WAYNE_CITY = "51840"
WEEPING_WATER_CITY = "52015"
WELLFLEET_VILLAGE = "52085"
WEST_POINT_CITY = "52575"
WESTERN_VILLAGE = "52295"
WESTERVILLE_CDP = "52330"
WESTON_VILLAGE = "52540"
WHITE_CLAY_CDP = "52855"
WHITNEY_VILLAGE = "52925"
WILBER_CITY = "52960"
WILCOX_VILLAGE = "52995"
WILLOW_ISLAND_CDP = "53205"
WILSONVILLE_VILLAGE = "53240"
WINNEBAGO_VILLAGE = "53275"
WINNETOON_VILLAGE = "53345"
WINSIDE_VILLAGE = "53380"
WINSLOW_VILLAGE = "53415"
WISNER_CITY = "53450"
WOLBACH_VILLAGE = "53520"
WOOD_LAKE_VILLAGE = "53555"
WOOD_RIVER_CITY = "53660"
WOODLAND_HILLS_CDP = "53575"
WOODLAND_PARK_CDP = "53580"
WYMORE_CITY = "53835"
WYNOT_VILLAGE = "53905"
YANKEE_HILL_CDP = "54020"
YORK_CITY = "54045"
YUTAN_CITY = "54115"
