# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Alaska."""


ADAK_CITY = "00065"
AKHIOK_CITY = "00650"
AKIACHAK_CDP = "00760"
AKIAK_CITY = "00870"
AKUTAN_CITY = "01090"
ALAKANUK_CITY = "01200"
ALATNA_CDP = "01305"
ALCAN_BORDER_CDP = "01390"
ALEKNAGIK_CITY = "01420"
ALENEVA_CDP = "01560"
ALLAKAKET_CITY = "01860"
AMBLER_CITY = "01970"
ANAKTUVUK_PASS_CITY = "02080"
ANCHOR_POINT_CDP = "03110"
ANCHORAGE_MUNICIPALITY = "03000"
ANDERSON_CITY = "03220"
ANGOON_CITY = "03440"
ANIAK_CITY = "03550"
ANVIK_CITY = "03880"
ARCTIC_VILLAGE_CDP = "03990"
ATKA_CITY = "04210"
ATMAUTLUAK_CDP = "04430"
ATQASUK_CITY = "04500"
ATTU_STATION_CDP = "04670"
BADGER_CDP = "05000"
BEAR_CREEK_CDP = "05585"
BEAVER_CDP = "05750"
BELUGA_CDP = "06245"
BETHEL_CITY = "06520"
BETTLES_CITY = "06630"
BIG_DELTA_CDP = "06850"
BIG_LAKE_CDP = "07070"
BIRCH_CREEK_CDP = "07620"
BREVIG_MISSION_CITY = "08740"
BUCKLAND_CITY = "09600"
BUFFALO_SOAPSTONE_CDP = "09657"
BUTTE_CDP = "09710"
CANTWELL_CDP = "10150"
CENTRAL_CDP = "11690"
CHALKYITSIK_CDP = "11800"
CHASE_CDP = "12350"
CHEFORNAK_CITY = "12680"
CHENA_RIDGE_CDP = "12920"
CHENEGA_CDP = "12970"
CHEVAK_CITY = "13230"
CHICKALOON_CDP = "13340"
CHICKEN_CDP = "13450"
CHIGNIK_LAGOON_CDP = "13670"
CHIGNIK_LAKE_CDP = "13780"
CHIGNIK_CITY = "13550"
CHINIAK_CDP = "13860"
CHISANA_CDP = "13890"
CHISTOCHINA_CDP = "14000"
CHITINA_CDP = "14110"
CHUATHBALUK_CITY = "14330"
CIRCLE_CDP = "14880"
CLAM_GULCH_CDP = "15320"
CLARKS_POINT_CITY = "15430"
COFFMAN_COVE_CITY = "16360"
COHOE_CDP = "16420"
COLD_BAY_CITY = "16530"
COLDFOOT_CDP = "16630"
COLLEGE_CDP = "16750"
COOPER_LANDING_CDP = "17190"
COPPER_CENTER_CDP = "17300"
CORDOVA_CITY = "17410"
COVENANT_LIFE_CDP = "17670"
CRAIG_CITY = "17740"
CROOKED_CREEK_CDP = "17850"
CROWN_POINT_CDP = "17960"
DEERING_CITY = "18510"
DELTA_JUNCTION_CITY = "18620"
DELTANA_CDP = "18675"
DENALI_PARK_CDP = "18805"
DIAMOND_RIDGE_CDP = "18925"
DILLINGHAM_CITY = "18950"
DIOMEDE_CITY = "19060"
DOT_LAKE_CDP = "19720"
DOT_LAKE_VILLAGE_CDP = "19750"
DRY_CREEK_CDP = "20020"
EAGLE_VILLAGE_CDP = "20600"
EAGLE_CITY = "20380"
EARECKSON_STATION_CDP = "20716"
EDNA_BAY_CITY = "20970"
EEK_CITY = "21040"
EGEGIK_CITY = "21150"
EIELSON_AFB_CDP = "21370"
EKWOK_CITY = "21810"
ELFIN_COVE_CDP = "22140"
ELIM_CITY = "22250"
EMMONAK_CITY = "22910"
ESTER_CDP = "23460"
EUREKA_ROADHOUSE_CDP = "23720"
EVANSVILLE_CDP = "23790"
EXCURSION_INLET_CDP = "23900"
FAIRBANKS_CITY = "24230"
FALSE_PASS_CITY = "24660"
FARM_LOOP_CDP = "25000"
FARMERS_LOOP_CDP = "24980"
FERRY_CDP = "25220"
FISHHOOK_CDP = "25550"
FLAT_CDP = "25880"
FORT_GREELY_CDP = "26100"
FORT_YUKON_CITY = "26760"
FOUR_MILE_ROAD_CDP = "26835"
FOX_CDP = "26870"
FOX_RIVER_CDP = "26910"
FRITZ_CREEK_CDP = "27090"
FUNNY_RIVER_CDP = "27145"
GAKONA_CDP = "27420"
GALENA_CITY = "27530"
GAMBELL_CITY = "27640"
GAME_CREEK_CDP = "27700"
GATEWAY_CDP = "28200"
GLACIER_VIEW_CDP = "28590"
GLENNALLEN_CDP = "28740"
GOLDSTREAM_CDP = "29130"
GOLOVIN_CITY = "29180"
GOODNEWS_BAY_CITY = "29290"
GRAYLING_CITY = "30060"
GULKANA_CDP = "30500"
GUSTAVUS_CITY = "30940"
HAINES_CDP = "31050"
HALIBUT_COVE_CDP = "31270"
HAPPY_VALLEY_CDP = "31710"
HARDING_BIRCH_LAKES_CDP = "31765"
HEALY_CDP = "32150"
HEALY_LAKE_CDP = "32310"
HOBART_BAY_CDP = "32550"
HOLLIS_CDP = "32810"
HOLY_CROSS_CITY = "33030"
HOMER_CITY = "33140"
HOONAH_CITY = "33360"
HOOPER_BAY_CITY = "33470"
HOPE_CDP = "33580"
HOUSTON_CITY = "33800"
HUGHES_CITY = "33910"
HUSLIA_CITY = "34350"
HYDABURG_CITY = "34460"
HYDER_CDP = "34570"
IGIUGIG_CDP = "34790"
ILIAMNA_CDP = "35120"
IVANOF_BAY_CDP = "35890"
JUNEAU_CITY_AND_BOROUGH = "36400"
KACHEMAK_CITY = "36540"
KAKE_CITY = "36770"
KAKTOVIK_CITY = "36990"
KALIFORNSKY_CDP = "37250"
KALTAG_CITY = "37430"
KARLUK_CDP = "37540"
KASAAN_CITY = "37650"
KASIGLUK_CDP = "37975"
KASILOF_CDP = "38090"
KENAI_CITY = "38420"
KENNY_LAKE_CDP = "38910"
KETCHIKAN_CITY = "38970"
KIANA_CITY = "39300"
KING_COVE_CITY = "39410"
KING_SALMON_CDP = "39630"
KIPNUK_CDP = "39740"
KIVALINA_CITY = "39960"
KLAWOCK_CITY = "40400"
KLUKWAN_CDP = "40510"
KNIK_RIVER_CDP = "40670"
KNIK_FAIRVIEW_CDP = "40645"
KOBUK_CITY = "40840"
KODIAK_STATION_CDP = "41210"
KODIAK_CITY = "40950"
KOKHANOK_CDP = "41280"
KOLIGANEK_CDP = "41500"
KONGIGANAK_CDP = "41610"
KOTLIK_CITY = "41720"
KOTZEBUE_CITY = "41830"
KOYUK_CITY = "41940"
KOYUKUK_CITY = "42050"
KUPREANOF_CITY = "42160"
KWETHLUK_CITY = "42380"
KWIGILLINGOK_CDP = "42490"
LAKE_LOUISE_CDP = "42805"
LAKE_MINCHUMINA_CDP = "42820"
LARSEN_BAY_CITY = "43040"
LAZY_MOUNTAIN_CDP = "43260"
LEVELOCK_CDP = "43810"
LIME_VILLAGE_CDP = "44030"
LIVENGOOD_CDP = "44580"
LORING_CDP = "45020"
LOWELL_POINT_CDP = "45295"
LOWER_KALSKAG_CITY = "45460"
LUTAK_CDP = "45700"
MANLEY_HOT_SPRINGS_CDP = "46780"
MANOKOTAK_CITY = "46890"
MARSHALL_CITY = "47000"
MCCARTHY_CDP = "45790"
MCGRATH_CITY = "46010"
MEADOW_LAKES_CDP = "47735"
MEKORYUK_CITY = "47990"
MENDELTNA_CDP = "48200"
MENTASTA_LAKE_CDP = "48540"
MERTARVIK_CDP = "48590"
METLAKATLA_CDP = "48870"
MILL_BAY_CDP = "49200"
MINTO_CDP = "49530"
MOOSE_CREEK_CDP = "50080"
MOOSE_PASS_CDP = "50190"
MOSQUITO_LAKE_CDP = "50800"
MOUNTAIN_VILLAGE_CITY = "51180"
MUD_BAY_CDP = "51455"
NABESNA_CDP = "51960"
NAKNEK_CDP = "52060"
NANWALEK_CDP = "52210"
NAPAKIAK_CITY = "52390"
NAPASKIAK_CITY = "52720"
NAUKATI_BAY_CDP = "52845"
NELCHINA_CDP = "52915"
NELSON_LAGOON_CDP = "52940"
NENANA_CITY = "53050"
NEW_STUYAHOK_CITY = "53710"
NEWHALEN_CITY = "53270"
NEWTOK_CDP = "53820"
NIGHTMUTE_CITY = "53930"
NIKISKI_CDP = "54050"
NIKOLAEVSK_CDP = "54085"
NIKOLAI_CITY = "54150"
NIKOLSKI_CDP = "54260"
NINILCHIK_CDP = "54480"
NOATAK_CDP = "54700"
NOME_CITY = "54920"
NONDALTON_CITY = "55030"
NOORVIK_CITY = "55140"
NORTH_LAKES_CDP = "55745"
NORTH_POLE_CITY = "55910"
NORTHWAY_CDP = "56220"
NUIQSUT_CITY = "56320"
NULATO_CITY = "56350"
NUNAM_IQUA_CITY = "56600"
NUNAPITCHUK_CITY = "56680"
OLD_HARBOR_CITY = "57340"
OSCARVILLE_CDP = "58330"
OUZINKIE_CITY = "58550"
PALMER_CITY = "58660"
PAXSON_CDP = "59320"
PEDRO_BAY_CDP = "59540"
PELICAN_CITY = "59650"
PERRYVILLE_CDP = "60200"
PETERSBURG_CDP = "60310"
PETERSVILLE_CDP = "60460"
PILOT_POINT_CITY = "60640"
PILOT_STATION_CITY = "60750"
PITKAS_POINT_CDP = "60860"
PLATINUM_CITY = "61080"
PLEASANT_VALLEY_CDP = "61120"
POINT_BAKER_CDP = "61190"
POINT_HOPE_CITY = "61630"
POINT_LAY_CDP = "61700"
POINT_MACKENZIE_CDP = "61788"
POINT_POSSESSION_CDP = "61825"
POPE_VANNOY_LANDING_CDP = "62125"
PORT_ALEXANDER_CITY = "62510"
PORT_ALSWORTH_CDP = "62620"
PORT_CLARENCE_CDP = "63170"
PORT_GRAHAM_CDP = "63280"
PORT_HEIDEN_CITY = "63390"
PORT_LIONS_CITY = "63610"
PORT_PROTECTION_CDP = "63870"
PORTAGE_CREEK_CDP = "62285"
PRIMROSE_CDP = "64240"
PRUDHOE_BAY_CDP = "64380"
QUINHAGAK_CITY = "64600"
RAMPART_CDP = "64820"
RED_DEVIL_CDP = "64930"
RED_DOG_MINE_CDP = "64980"
RIDGEWAY_CDP = "65345"
RUBY_CITY = "65590"
RUSSIAN_MISSION_CITY = "65700"
SALAMATOF_CDP = "66510"
SALCHA_CDP = "66550"
SAND_POINT_CITY = "67020"
SAVOONGA_CITY = "67460"
SAXMAN_CITY = "67570"
SCAMMON_BAY_CITY = "67680"
SELAWIK_CITY = "68230"
SELDOVIA_VILLAGE_CDP = "68370"
SELDOVIA_CITY = "68340"
SEWARD_CITY = "68560"
SHAGELUK_CITY = "68670"
SHAKTOOLIK_CITY = "68890"
SHISHMAREF_CITY = "69770"
SHUNGNAK_CITY = "70100"
SILVER_SPRINGS_CDP = "70320"
SITKA_CITY_AND_BOROUGH = "70540"
SKAGWAY_CDP = "70760"
SKWENTNA_CDP = "70870"
SLANA_CDP = "70930"
SLEETMUTE_CDP = "71090"
SOLDOTNA_CITY = "71640"
SOUTH_LAKES_CDP = "72135"
SOUTH_NAKNEK_CDP = "72190"
SOUTH_VAN_HORN_CDP = "72230"
ST_GEORGE_CITY = "65800"
ST_MARYS_CITY = "66140"
ST_MICHAEL_CITY = "66360"
ST_PAUL_CITY = "66470"
STEBBINS_CITY = "72960"
STEELE_CREEK_CDP = "72985"
STERLING_CDP = "73070"
STEVENS_VILLAGE_CDP = "73290"
STONY_RIVER_CDP = "73400"
SUNRISE_CDP = "73950"
SUSITNA_CDP = "74340"
SUSITNA_NORTH_CDP = "74350"
SUTTON_ALPINE_CDP = "74525"
TAKOTNA_CDP = "74610"
TALKEETNA_CDP = "74830"
TANACROSS_CDP = "75050"
TANAINA_CDP = "75077"
TANANA_CITY = "75160"
TATITLEK_CDP = "75380"
TAZLINA_CDP = "75480"
TELLER_CITY = "75930"
TENAKEE_SPRINGS_CITY = "76260"
TETLIN_CDP = "76590"
THORNE_BAY_CITY = "77140"
TOGIAK_CITY = "77690"
TOK_CDP = "77800"
TOKSOOK_BAY_CITY = "78240"
TOLSONA_CDP = "78297"
TONSINA_CDP = "78350"
TRAPPER_CREEK_CDP = "78680"
TULUKSAK_CDP = "78790"
TUNTUTULIAK_CDP = "79120"
TUNUNAK_CDP = "79230"
TWIN_HILLS_CDP = "79780"
TWO_RIVERS_CDP = "79830"
TYONEK_CDP = "79890"
UGASHIK_CDP = "80100"
UNALAKLEET_CITY = "80660"
UNALASKA_CITY = "80770"
UPPER_KALSKAG_CITY = "81320"
UTQIAĠVIK_CITY = "81920"
VALDEZ_CITY = "82200"
VENETIE_CDP = "82420"
WAINWRIGHT_CITY = "82750"
WALES_CITY = "82860"
WASILLA_CITY = "83080"
WHALE_PASS_CITY = "84000"
WHITE_MOUNTAIN_CITY = "84070"
WHITESTONE_CDP = "84120"
WHITESTONE_LOGGING_CAMP_CDP = "84200"
WHITTIER_CITY = "84510"
WILLOW_CDP = "85280"
WILLOW_CREEK_CDP = "85290"
WISEMAN_CDP = "85610"
WOMENS_BAY_CDP = "85680"
WRANGELL_CITY_AND_BOROUGH = "86380"
YAKUTAT_CDP = "86490"
