# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Florida."""


ALACHUA = "001"
BAKER = "003"
BAY = "005"
BRADFORD = "007"
BREVARD = "009"
BROWARD = "011"
CALHOUN = "013"
CHARLOTTE = "015"
CITRUS = "017"
CLAY = "019"
COLLIER = "021"
COLUMBIA = "023"
DESOTO = "027"
DIXIE = "029"
DUVAL = "031"
ESCAMBIA = "033"
FLAGLER = "035"
FRANKLIN = "037"
GADSDEN = "039"
GILCHRIST = "041"
GLADES = "043"
GULF = "045"
HAMILTON = "047"
HARDEE = "049"
HENDRY = "051"
HERNANDO = "053"
HIGHLANDS = "055"
HILLSBOROUGH = "057"
HOLMES = "059"
INDIAN_RIVER = "061"
JACKSON = "063"
JEFFERSON = "065"
LAFAYETTE = "067"
LAKE = "069"
LEE = "071"
LEON = "073"
LEVY = "075"
LIBERTY = "077"
MADISON = "079"
MANATEE = "081"
MARION = "083"
MARTIN = "085"
MIAMI_DADE = "086"
MONROE = "087"
NASSAU = "089"
OKALOOSA = "091"
OKEECHOBEE = "093"
ORANGE = "095"
OSCEOLA = "097"
PALM_BEACH = "099"
PASCO = "101"
PINELLAS = "103"
POLK = "105"
PUTNAM = "107"
SANTA_ROSA = "113"
SARASOTA = "115"
SEMINOLE = "117"
ST_JOHNS = "109"
ST_LUCIE = "111"
SUMTER = "119"
SUWANNEE = "121"
TAYLOR = "123"
UNION = "125"
VOLUSIA = "127"
WAKULLA = "129"
WALTON = "131"
WASHINGTON = "133"
