# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Pennsylvania."""


ADAMS = "001"
ALLEGHENY = "003"
ARMSTRONG = "005"
BEAVER = "007"
BEDFORD = "009"
BERKS = "011"
BLAIR = "013"
BRADFORD = "015"
BUCKS = "017"
BUTLER = "019"
CAMBRIA = "021"
CAMERON = "023"
CARBON = "025"
CENTRE = "027"
CHESTER = "029"
CLARION = "031"
CLEARFIELD = "033"
CLINTON = "035"
COLUMBIA = "037"
CRAWFORD = "039"
CUMBERLAND = "041"
DAUPHIN = "043"
DELAWARE = "045"
ELK = "047"
ERIE = "049"
FAYETTE = "051"
FOREST = "053"
FRANKLIN = "055"
FULTON = "057"
GREENE = "059"
HUNTINGDON = "061"
INDIANA = "063"
JEFFERSON = "065"
JUNIATA = "067"
LACKAWANNA = "069"
LANCASTER = "071"
LAWRENCE = "073"
LEBANON = "075"
LEHIGH = "077"
LUZERNE = "079"
LYCOMING = "081"
MCKEAN = "083"
MERCER = "085"
MIFFLIN = "087"
MONROE = "089"
MONTGOMERY = "091"
MONTOUR = "093"
NORTHAMPTON = "095"
NORTHUMBERLAND = "097"
PERRY = "099"
PHILADELPHIA = "101"
PIKE = "103"
POTTER = "105"
SCHUYLKILL = "107"
SNYDER = "109"
SOMERSET = "111"
SULLIVAN = "113"
SUSQUEHANNA = "115"
TIOGA = "117"
UNION = "119"
VENANGO = "121"
WARREN = "123"
WASHINGTON = "125"
WAYNE = "127"
WESTMORELAND = "129"
WYOMING = "131"
YORK = "133"
