# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Minnesota."""


ADA_CITY = "00172"
ADAMS_CITY = "00190"
ADRIAN_CITY = "00262"
AFTON_CITY = "00316"
AITKIN_CITY = "00460"
AKELEY_CITY = "00496"
ALBANY_CITY = "00622"
ALBERT_LEA_CITY = "00694"
ALBERTA_CITY = "00676"
ALBERTVILLE_CITY = "00730"
ALDEN_CITY = "00838"
ALDRICH_CITY = "00892"
ALEXANDRIA_CITY = "00928"
ALPHA_CITY = "01162"
ALTURA_CITY = "01234"
ALVARADO_CITY = "01252"
AMBOY_CITY = "01324"
ANDOVER_CITY = "01486"
ANGLE_INLET_CDP = "01558"
ANNANDALE_CITY = "01684"
ANOKA_CITY = "01720"
APPLE_VALLEY_CITY = "01900"
APPLETON_CITY = "01864"
ARCO_CITY = "01972"
ARDEN_HILLS_CITY = "02026"
ARGYLE_CITY = "02134"
ARLINGTON_CITY = "02152"
ASHBY_CITY = "02422"
ASKOV_CITY = "02548"
ATWATER_CITY = "02692"
AUDUBON_CITY = "02728"
AURORA_CITY = "02872"
AUSTIN_CITY = "02908"
AVOCA_CITY = "03052"
AVON_CITY = "03070"
BABBITT_CITY = "03106"
BACKUS_CITY = "03124"
BADGER_CITY = "03160"
BAGLEY_CITY = "03196"
BAKER_CDP = "03214"
BALATON_CITY = "03250"
BALL_CLUB_CDP = "03376"
BARNESVILLE_CITY = "03574"
BARNUM_CITY = "03628"
BARRETT_CITY = "03682"
BARRY_CITY = "03718"
BATTLE_LAKE_CITY = "03970"
BAUDETTE_CITY = "04024"
BAXTER_CITY = "04042"
BAYPORT_CITY = "04114"
BEARDSLEY_CITY = "04204"
BEAULIEU_CDP = "04348"
BEAVER_BAY_CITY = "04456"
BEAVER_CREEK_CITY = "04492"
BECKER_CITY = "04618"
BEJOU_CITY = "04672"
BELGRADE_CITY = "04762"
BELLE_PLAINE_CITY = "04834"
BELLECHESTER_CITY = "04798"
BELLINGHAM_CITY = "04960"
BELTRAMI_CITY = "05014"
BELVIEW_CITY = "05050"
BEMIDJI_CITY = "05068"
BENA_CITY = "05104"
BENSON_CITY = "05212"
BERTHA_CITY = "05482"
BETHEL_CITY = "05554"
BIG_FALLS_CITY = "05680"
BIG_LAKE_CDP = "05744"
BIG_LAKE_CITY = "05752"
BIGELOW_CITY = "05644"
BIGFORK_CITY = "05698"
BINGHAM_LAKE_CITY = "05896"
BIRCHWOOD_VILLAGE_CITY = "06058"
BIRD_ISLAND_CITY = "06076"
BISCAY_CITY = "06112"
BIWABIK_CITY = "06148"
BLACKDUCK_CITY = "06256"
BLAINE_CITY = "06382"
BLOMKEST_CITY = "06490"
BLOOMING_PRAIRIE_CITY = "06580"
BLOOMINGTON_CITY = "06616"
BLUE_EARTH_CITY = "06688"
BLUFFTON_CITY = "06778"
BOCK_CITY = "06814"
BORUP_CITY = "07030"
BOVEY_CITY = "07048"
BOWLUS_CITY = "07066"
BOY_RIVER_CITY = "07174"
BOYD_CITY = "07138"
BRAHAM_CITY = "07282"
BRAINERD_CITY = "07300"
BRANDON_CITY = "07336"
BRECKENRIDGE_CITY = "07462"
BREEZY_POINT_CITY = "07516"
BREWSTER_CITY = "07660"
BRICELYN_CITY = "07678"
BROOK_PARK_CITY = "07984"
BROOKLYN_CENTER_CITY = "07948"
BROOKLYN_PARK_CITY = "07966"
BROOKS_CITY = "08038"
BROOKSTON_CITY = "08056"
BROOTEN_CITY = "08092"
BROWERVILLE_CITY = "08110"
BROWNS_VALLEY_CITY = "08200"
BROWNSDALE_CITY = "08164"
BROWNSVILLE_CITY = "08218"
BROWNTON_CITY = "08254"
BRUNO_CITY = "08290"
BUCKMAN_CITY = "08416"
BUFFALO_LAKE_CITY = "08488"
BUFFALO_CITY = "08452"
BUHL_CITY = "08524"
BURNSVILLE_CITY = "08794"
BURTRUM_CITY = "08902"
BUTTERFIELD_CITY = "08992"
BYRON_CITY = "09154"
CALEDONIA_CITY = "09226"
CALLAWAY_CITY = "09280"
CALUMET_CITY = "09316"
CAMBRIDGE_CITY = "09370"
CAMPBELL_CITY = "09496"
CANBY_CITY = "09604"
CANNON_FALLS_CITY = "09730"
CANTON_CITY = "09802"
CARLOS_CITY = "09964"
CARLTON_CITY = "10018"
CARVER_CITY = "10144"
CASS_LAKE_CITY = "10252"
CEDAR_MILLS_CITY = "10468"
CENTER_CITY_CITY = "10576"
CENTERVILLE_CITY = "10648"
CEYLON_CITY = "10792"
CHAMPLIN_CITY = "10846"
CHANDLER_CITY = "10900"
CHANHASSEN_CITY = "10918"
CHASKA_CITY = "10972"
CHATFIELD_CITY = "11008"
CHICKAMAW_BEACH_CITY = "11296"
CHISAGO_CITY_CITY = "11350"
CHISHOLM_CITY = "11386"
CHOKIO_CITY = "11440"
CIRCLE_PINES_CITY = "11494"
CLARA_CITY_CITY = "11548"
CLAREMONT_CITY = "11566"
CLARISSA_CITY = "11602"
CLARKFIELD_CITY = "11656"
CLARKS_GROVE_CITY = "11674"
CLEAR_LAKE_CITY = "11764"
CLEARBROOK_CITY = "11746"
CLEARWATER_CITY = "11800"
CLEMENTS_CITY = "11836"
CLEVELAND_CITY = "11872"
CLIMAX_CITY = "11962"
CLINTON_CITY = "11980"
CLITHERALL_CITY = "12088"
CLONTARF_CITY = "12124"
CLOQUET_CITY = "12160"
COATES_CITY = "12376"
COBDEN_CITY = "12394"
COHASSET_CITY = "12412"
COKATO_CITY = "12430"
COLD_SPRING_CITY = "12484"
COLERAINE_CITY = "12502"
COLOGNE_CITY = "12664"
COLUMBIA_HEIGHTS_CITY = "12700"
COLUMBUS_CITY = "12718"
COMFREY_CITY = "12772"
COMSTOCK_CITY = "12862"
CONGER_CITY = "12952"
COOK_CITY = "13006"
COON_RAPIDS_CITY = "13114"
CORCORAN_CITY = "13168"
CORRELL_CITY = "13384"
COSMOS_CITY = "13420"
COTTAGE_GROVE_CITY = "13456"
COTTONWOOD_CITY = "13564"
COURTLAND_CITY = "13582"
CREDIT_RIVER_CITY = "13708"
CROMWELL_CITY = "13780"
CROOKSTON_CITY = "13870"
CROSBY_CITY = "13924"
CROSSLAKE_CITY = "13978"
CROWN_COLLEGE_CDP = "14054"
CRYSTAL_CITY = "14158"
CURRIE_CITY = "14320"
CUYUNA_CITY = "14428"
CYRUS_CITY = "14446"
DAKOTA_CITY = "14518"
DALTON_CITY = "14626"
DANUBE_CITY = "14716"
DANVERS_CITY = "14734"
DARFUR_CITY = "14770"
DARWIN_CITY = "14842"
DASSEL_CITY = "14878"
DAWSON_CITY = "14968"
DAYTON_CITY = "15022"
DE_GRAFF_CITY = "15418"
DEEPHAVEN_CITY = "15148"
DEER_CREEK_CITY = "15184"
DEER_RIVER_CITY = "15310"
DEERWOOD_CITY = "15346"
DELANO_CITY = "15454"
DELAVAN_CITY = "15472"
DELHI_CITY = "15544"
DELLWOOD_CITY = "15616"
DENHAM_CITY = "15670"
DENNISON_CITY = "15706"
DENT_CITY = "15724"
DETROIT_LAKES_CITY = "15832"
DEXTER_CITY = "15886"
DILWORTH_CITY = "15976"
DODGE_CENTER_CITY = "15994"
DONALDSON_CITY = "16030"
DONNELLY_CITY = "16084"
DORAN_CITY = "16156"
DOVER_CITY = "16264"
DOVRAY_CITY = "16300"
DRESBACH_CDP = "16390"
DULUTH_CITY = "17000"
DUMONT_CITY = "17090"
DUNDAS_CITY = "17126"
DUNDEE_CITY = "17144"
DUNNELL_CITY = "17180"
EAGAN_CITY = "17288"
EAGLE_BEND_CITY = "17342"
EAGLE_LAKE_CITY = "17378"
EAST_BETHEL_CITY = "17486"
EAST_GRAND_FORKS_CITY = "17612"
EAST_GULL_LAKE_CITY = "17630"
EASTON_CITY = "17738"
EBRO_CDP = "17882"
ECHO_CITY = "17900"
EDEN_PRAIRIE_CITY = "18116"
EDEN_VALLEY_CITY = "18134"
EDGERTON_CITY = "18152"
EDINA_CITY = "18188"
EFFIE_CITY = "18260"
EITZEN_CITY = "18368"
ELBA_CITY = "18386"
ELBOW_LAKE_CDP = "18440"
ELBOW_LAKE_CITY = "18458"
ELGIN_CITY = "18530"
ELIZABETH_CITY = "18566"
ELK_RIVER_CITY = "18674"
ELKO_NEW_MARKET_CITY = "18662"
ELKTON_CITY = "18728"
ELLENDALE_CITY = "18746"
ELLSWORTH_CITY = "18836"
ELMDALE_CITY = "18872"
ELMORE_CITY = "18998"
ELROSA_CITY = "19088"
ELY_CITY = "19142"
ELYSIAN_CITY = "19160"
EMILY_CITY = "19286"
EMMONS_CITY = "19340"
ERHARD_CITY = "19556"
ERSKINE_CITY = "19700"
ESKO_CDP = "19718"
ESSIG_CDP = "19754"
EVAN_CITY = "19880"
EVANSVILLE_CITY = "19898"
EVELETH_CITY = "19934"
EXCELSIOR_CITY = "20078"
EYOTA_CITY = "20114"
FAIRFAX_CITY = "20222"
FAIRHAVEN_CDP = "20276"
FAIRMONT_CITY = "20330"
FALCON_HEIGHTS_CITY = "20420"
FARIBAULT_CITY = "20546"
FARMINGTON_CITY = "20618"
FARWELL_CITY = "20690"
FEDERAL_DAM_CITY = "20798"
FELTON_CITY = "20834"
FERGUS_FALLS_CITY = "20906"
FERTILE_CITY = "20978"
FIFTY_LAKES_CITY = "21032"
FINLAND_CDP = "21104"
FINLAYSON_CITY = "21122"
FISH_LAKE_CDP = "21196"
FISHER_CITY = "21158"
FLENSBURG_CITY = "21266"
FLOODWOOD_CITY = "21338"
FLORENCE_CITY = "21410"
FOLEY_CITY = "21536"
FORADA_CITY = "21608"
FOREST_LAKE_CITY = "21770"
FORESTON_CITY = "21824"
FORT_RIPLEY_CITY = "21932"
FOSSTON_CITY = "21986"
FOUNTAIN_CITY = "22094"
FOXHOME_CITY = "22202"
FRANKLIN_CITY = "22364"
FRAZEE_CITY = "22472"
FREEBORN_CITY = "22526"
FREEPORT_CITY = "22652"
FRIDLEY_CITY = "22814"
FRONTENAC_CDP = "22904"
FROST_CITY = "22940"
FULDA_CITY = "22958"
FUNKLEY_CITY = "22976"
GARDEN_CITY_CDP = "23084"
GARFIELD_CITY = "23120"
GARRISON_CITY = "23192"
GARVIN_CITY = "23228"
GARY_CITY = "23246"
GAYLORD_CITY = "23300"
GEM_LAKE_CITY = "23318"
GENEVA_CITY = "23354"
GENOLA_CITY = "23444"
GEORGETOWN_CITY = "23498"
GHENT_CITY = "23660"
GIBBON_CITY = "23678"
GILBERT_CITY = "23714"
GILMAN_CITY = "23804"
GLENCOE_CITY = "23948"
GLENVILLE_CITY = "24056"
GLENWOOD_CITY = "24074"
GLYNDON_CITY = "24182"
GOLDEN_VALLEY_CITY = "24308"
GONVICK_CITY = "24344"
GOOD_THUNDER_CITY = "24506"
GOODHUE_CITY = "24398"
GOODLAND_CDP = "24434"
GOODRIDGE_CITY = "24470"
GOODVIEW_CITY = "24524"
GRACEVILLE_CITY = "24758"
GRANADA_CITY = "24884"
GRAND_MARAIS_CITY = "24992"
GRAND_MEADOW_CITY = "25010"
GRAND_RAPIDS_CITY = "25118"
GRANITE_FALLS_CITY = "25280"
GRANT_CITY = "25334"
GRASSTON_CITY = "25424"
GREEN_ISLE_CITY = "25658"
GREENBUSH_CITY = "25604"
GREENFIELD_CITY = "25622"
GREENWALD_CITY = "25874"
GREENWOOD_CITY = "25918"
GREY_EAGLE_CITY = "26000"
GROVE_CITY_CITY = "26126"
GRYGLA_CITY = "26216"
GULLY_CITY = "26270"
HACKENSACK_CITY = "26378"
HADLEY_CITY = "26450"
HALLOCK_CITY = "26576"
HALMA_CITY = "26612"
HALSTAD_CITY = "26630"
HAM_LAKE_CITY = "26738"
HAMBURG_CITY = "26666"
HAMMOND_CITY = "26828"
HAMPTON_CITY = "26864"
HANCOCK_CITY = "26936"
HANLEY_FALLS_CITY = "26972"
HANOVER_CITY = "26990"
HANSKA_CITY = "27008"
HARDING_CITY = "27098"
HARDWICK_CITY = "27116"
HARMONY_CITY = "27188"
HARRIS_CITY = "27278"
HARTLAND_CITY = "27404"
HASTINGS_CITY = "27530"
HATFIELD_CITY = "27566"
HAWLEY_CITY = "27746"
HAYFIELD_CITY = "27872"
HAYWARD_CITY = "27944"
HAZEL_RUN_CITY = "28016"
HECTOR_CITY = "28124"
HEIDELBERG_CITY = "28214"
HENDERSON_CITY = "28394"
HENDRICKS_CITY = "28430"
HENDRUM_CITY = "28484"
HENNING_CITY = "28520"
HENRIETTE_CITY = "28574"
HERMAN_CITY = "28646"
HERMANTOWN_CITY = "28682"
HERON_LAKE_CITY = "28700"
HEWITT_CITY = "28754"
HIBBING_CITY = "28790"
HIGH_FOREST_CDP = "28862"
HILL_CITY_CITY = "29096"
HILLMAN_CITY = "29150"
HILLS_CITY = "29204"
HILLTOP_CITY = "29258"
HINCKLEY_CITY = "29294"
HITTERDAL_CITY = "29402"
HOFFMAN_CITY = "29474"
HOKAH_CITY = "29510"
HOLDINGFORD_CITY = "29582"
HOLLAND_CITY = "29618"
HOLLANDALE_CITY = "29636"
HOLLOWAY_CITY = "29672"
HOLT_CITY = "29870"
HOMER_CDP = "30014"
HOPKINS_CITY = "30140"
HOUSTON_CITY = "30230"
HOWARD_LAKE_CITY = "30284"
HOYT_LAKES_CITY = "30302"
HUBBARD_CDP = "30320"
HUGO_CITY = "30392"
HUMBOLDT_CITY = "30446"
HUTCHINSON_CITY = "30644"
IHLEN_CITY = "30806"
INDEPENDENCE_CITY = "30842"
INGER_CDP = "30950"
INTERNATIONAL_FALLS_CITY = "31040"
INVER_GROVE_HEIGHTS_CITY = "31076"
IONA_CITY = "31094"
IRON_JUNCTION_CITY = "31238"
IRONTON_CITY = "31274"
ISANTI_CITY = "31328"
ISLE_CITY = "31472"
IVANHOE_CITY = "31526"
JACKSON_CITY = "31562"
JANESVILLE_CITY = "31706"
JASPER_CITY = "31760"
JEFFERS_CITY = "31796"
JENKINS_CITY = "31832"
JOHNSON_CITY = "32012"
JORDAN_CITY = "32174"
KANDIYOHI_CITY = "32372"
KARLSTAD_CITY = "32444"
KASOTA_CITY = "32462"
KASSON_CITY = "32498"
KEEWATIN_CITY = "32570"
KELLIHER_CITY = "32606"
KELLOGG_CITY = "32642"
KENNEDY_CITY = "32732"
KENNETH_CITY = "32750"
KENSINGTON_CITY = "32768"
KENT_CITY = "32786"
KENYON_CITY = "32840"
KERKHOVEN_CITY = "32876"
KERRICK_CITY = "32912"
KETTLE_RIVER_CITY = "32966"
KIESTER_CITY = "33056"
KILKENNY_CITY = "33110"
KIMBALL_CITY = "33164"
KINBRAE_CITY = "33236"
KINGSTON_CITY = "33344"
KINNEY_CITY = "33416"
KNIFE_RIVER_CDP = "33578"
LA_CRESCENT_CITY = "33866"
LA_PRAIRIE_CITY = "35648"
LA_SALLE_CITY = "35702"
LAFAYETTE_CITY = "33920"
LAKE_BENTON_CITY = "34100"
LAKE_BRONSON_CITY = "34136"
LAKE_CITY_CITY = "34172"
LAKE_CRYSTAL_CITY = "34190"
LAKE_ELMO_CITY = "34244"
LAKE_GEORGE_CDP = "34370"
LAKE_HENRY_CITY = "34478"
LAKE_LILLIAN_CITY = "34676"
LAKE_PARK_CITY = "34784"
LAKE_SHORE_CITY = "34928"
LAKE_ST_CROIX_BEACH_CITY = "34865"
LAKE_WILSON_CITY = "35198"
LAKEFIELD_CITY = "34316"
LAKELAND_SHORES_CITY = "34658"
LAKELAND_CITY = "34622"
LAKEVILLE_CITY = "35180"
LAMBERTON_CITY = "35288"
LANCASTER_CITY = "35378"
LANDFALL_CITY = "35414"
LANESBORO_CITY = "35450"
LANSING_CDP = "35558"
LAPORTE_CITY = "35612"
LASTRUP_CITY = "35720"
LAUDERDALE_CITY = "35738"
LE_CENTER_CITY = "36134"
LE_ROY_CITY = "36620"
LE_SUEUR_CITY = "36746"
LENGBY_CITY = "36404"
LEONARD_CITY = "36494"
LEONIDAS_CITY = "36530"
LEOTA_CDP = "36548"
LESTER_PRAIRIE_CITY = "36728"
LEWISTON_CITY = "36800"
LEWISVILLE_CITY = "36818"
LEXINGTON_CITY = "36836"
LILYDALE_CITY = "37016"
LINDSTROM_CITY = "37304"
LINO_LAKES_CITY = "37322"
LISMORE_CITY = "37412"
LITCHFIELD_CITY = "37448"
LITTLE_CANADA_CITY = "37502"
LITTLE_FALLS_CITY = "37556"
LITTLE_ROCK_CDP = "37656"
LITTLEFORK_CITY = "37592"
LONG_BEACH_CITY = "37970"
LONG_LAKE_CITY = "38006"
LONG_PRAIRIE_CITY = "38060"
LONGVILLE_CITY = "38114"
LONSDALE_CITY = "38150"
LORETTO_CITY = "38222"
LOUISBURG_CITY = "38258"
LOWRY_CITY = "38366"
LUCAN_CITY = "38420"
LUTSEN_CDP = "38546"
LUVERNE_CITY = "38564"
LYLE_CITY = "38654"
LYND_CITY = "38708"
MABEL_CITY = "38888"
MADELIA_CITY = "39230"
MADISON_LAKE_CITY = "39320"
MADISON_CITY = "39266"
MAGNOLIA_CITY = "39338"
MAHNOMEN_CDP = "39394"
MAHNOMEN_CITY = "39392"
MAHTOMEDI_CITY = "39428"
MAHTOWA_CDP = "39446"
MANCHESTER_CITY = "39716"
MANHATTAN_BEACH_CITY = "39806"
MANKATO_CITY = "39878"
MANTORVILLE_CITY = "39986"
MAPLE_GROVE_CITY = "40166"
MAPLE_LAKE_CITY = "40220"
MAPLE_PLAIN_CITY = "40256"
MAPLETON_CITY = "40310"
MAPLEVIEW_CITY = "40346"
MAPLEWOOD_CITY = "40382"
MARBLE_CITY = "40418"
MARIETTA_CITY = "40526"
MARINE_ON_ST_CROIX_CITY = "40562"
MARION_CDP = "40598"
MARSHALL_CITY = "40688"
MARTIN_LAKE_CDP = "40814"
MAYER_CITY = "41138"
MAYNARD_CITY = "41210"
MAZEPPA_CITY = "41282"
MCGRATH_CITY = "38996"
MCGREGOR_CITY = "39014"
MCINTOSH_CITY = "39050"
MCKINLEY_CITY = "39140"
MEADOWLANDS_CITY = "41372"
MEDFORD_CITY = "41426"
MEDICINE_LAKE_CITY = "41462"
MEDINA_CITY = "41480"
MEIRE_GROVE_CITY = "41534"
MELROSE_CITY = "41570"
MENAHGA_CITY = "41660"
MENDOTA_HEIGHTS_CITY = "41696"
MENDOTA_CITY = "41678"
MENTOR_CITY = "41714"
MERRIFIELD_CDP = "41804"
MIDDLE_RIVER_CITY = "41912"
MIDWAY_CDP = "42010"
MIESVILLE_CITY = "42092"
MILACA_CITY = "42110"
MILAN_CITY = "42146"
MILLERVILLE_CITY = "42254"
MILLVILLE_CITY = "42290"
MILROY_CITY = "42362"
MILTONA_CITY = "42398"
MINNEAPOLIS_CITY = "43000"
MINNEISKA_CITY = "43036"
MINNEOTA_CITY = "43126"
MINNESOTA_CITY_CITY = "43144"
MINNESOTA_LAKE_CITY = "43198"
MINNETONKA_BEACH_CITY = "43270"
MINNETONKA_CITY = "43252"
MINNETRISTA_CITY = "43306"
MIZPAH_CITY = "43540"
MONTEVIDEO_CITY = "43720"
MONTGOMERY_CITY = "43738"
MONTICELLO_CITY = "43774"
MONTROSE_CITY = "43810"
MOORHEAD_CITY = "43864"
MOOSE_LAKE_CITY = "43954"
MORA_CITY = "44044"
MORGAN_CITY = "44116"
MORRIS_CITY = "44242"
MORRISTOWN_CITY = "44296"
MORTON_CITY = "44368"
MOTLEY_CITY = "44422"
MOUND_CITY = "44476"
MOUNDS_VIEW_CITY = "44530"
MOUNTAIN_IRON_CITY = "44548"
MOUNTAIN_LAKE_CITY = "44566"
MURDOCK_CITY = "44818"
MYRTLE_CITY = "44890"
NASHUA_CITY = "44944"
NASHWAUK_CITY = "44980"
NASSAU_CITY = "45016"
NAYTAHWAUSH_CDP = "45052"
NELSON_CITY = "45106"
NERSTRAND_CITY = "45196"
NETT_LAKE_CDP = "45279"
NEVIS_CITY = "45340"
NEW_AUBURN_CITY = "45376"
NEW_BRIGHTON_CITY = "45430"
NEW_GERMANY_CITY = "45556"
NEW_HOPE_CITY = "45628"
NEW_LONDON_CITY = "45682"
NEW_MUNICH_CITY = "45772"
NEW_PRAGUE_CITY = "45808"
NEW_RICHLAND_CITY = "45862"
NEW_TRIER_CITY = "46024"
NEW_ULM_CITY = "46042"
NEW_YORK_MILLS_CITY = "46060"
NEWFOLDEN_CITY = "45520"
NEWPORT_CITY = "45790"
NICOLLET_CITY = "46150"
NIELSVILLE_CITY = "46258"
NIMROD_CITY = "46294"
NISSWA_CITY = "46348"
NORCROSS_CITY = "46492"
NORTH_BRANCH_CITY = "46798"
NORTH_MANKATO_CITY = "47068"
NORTH_OAKS_CITY = "47104"
NORTH_ST_PAUL_CITY = "47221"
NORTHFIELD_CITY = "46924"
NORTHOME_CITY = "47122"
NORTHROP_CITY = "47212"
NORWOOD_YOUNG_AMERICA_CITY = "47520"
NOWTHEN_CITY = "47536"
OAK_GROVE_CITY = "47690"
OAK_PARK_HEIGHTS_CITY = "47914"
OAKDALE_CITY = "47680"
ODESSA_CITY = "48058"
ODIN_CITY = "48094"
OGEMA_CITY = "48130"
OGILVIE_CITY = "48166"
OKABENA_CITY = "48184"
OKLEE_CITY = "48202"
OLIVIA_CITY = "48256"
ONAMIA_CITY = "48310"
ORMSBY_CITY = "48562"
ORONO_CITY = "48580"
ORONOCO_CITY = "48598"
ORR_CITY = "48634"
ORTONVILLE_CITY = "48706"
OSAGE_CDP = "48760"
OSAKIS_CITY = "48796"
OSLO_CITY = "48976"
OSSEO_CITY = "49012"
OSTRANDER_CITY = "49030"
OTSEGO_CITY = "49138"
OTTERTAIL_CITY = "49210"
OWATONNA_CITY = "49300"
PALISADE_CITY = "49498"
PARK_RAPIDS_CITY = "49768"
PARKERS_PRAIRIE_CITY = "49732"
PAYNESVILLE_CITY = "49966"
PEASE_CITY = "50056"
PELICAN_RAPIDS_CITY = "50164"
PEMBERTON_CITY = "50200"
PENNOCK_CITY = "50344"
PEQUOT_LAKES_CITY = "50416"
PERHAM_CITY = "50470"
PERLEY_CITY = "50506"
PETERSON_CITY = "50596"
PICKWICK_CDP = "50740"
PIERZ_CITY = "50776"
PILLAGER_CITY = "50902"
PINE_BEND_CDP = "51028"
PINE_CITY_CITY = "51064"
PINE_ISLAND_CITY = "51136"
PINE_POINT_CDP = "51234"
PINE_RIVER_CITY = "51280"
PINE_SPRINGS_CITY = "51316"
PIPESTONE_CITY = "51388"
PLAINVIEW_CITY = "51424"
PLATO_CITY = "51460"
PLUMMER_CITY = "51712"
PLYMOUTH_CITY = "51730"
PONEMAH_CDP = "51892"
PORTER_CITY = "52144"
PRESTON_CITY = "52450"
PRINCETON_CITY = "52522"
PRINSBURG_CITY = "52558"
PRIOR_LAKE_CITY = "52594"
PROCTOR_CITY = "52630"
QUAMBA_CITY = "52756"
RACINE_CITY = "52882"
RAMSEY_CITY = "53026"
RANDALL_CITY = "53080"
RANDOLPH_CITY = "53098"
RANIER_CITY = "53134"
RAYMOND_CITY = "53296"
RED_LAKE_CDP = "53458"
RED_LAKE_FALLS_CITY = "53476"
RED_WING_CITY = "53620"
REDBY_CDP = "53386"
REDWOOD_FALLS_CITY = "53656"
REGAL_CITY = "53710"
REMER_CITY = "53782"
RENVILLE_CITY = "53890"
REVERE_CITY = "53908"
RICE_LAKE_CDP = "54056"
RICE_LAKE_CITY = "54060"
RICE_CITY = "53998"
RICHFIELD_CITY = "54214"
RICHMOND_CITY = "54268"
RICHVILLE_CITY = "54340"
RIVERLAND_CDP = "54596"
RIVERTON_CITY = "54736"
ROBBINSDALE_CITY = "54808"
ROCHESTER_CITY = "54880"
ROCK_CREEK_CITY = "54934"
ROCKFORD_CITY = "55006"
ROCKVILLE_CITY = "55078"
ROGERS_CITY = "55186"
ROLLINGSTONE_CITY = "55276"
RONNEBY_CDP = "55366"
ROOSEVELT_CITY = "55438"
ROSCOE_CITY = "55510"
ROSE_CREEK_CITY = "55600"
ROSEAU_CITY = "55546"
ROSEMOUNT_CITY = "55726"
ROSEVILLE_CITY = "55852"
ROTHSAY_CITY = "56014"
ROUND_LAKE_CITY = "56086"
ROY_LAKE_CDP = "56212"
ROYALTON_CITY = "56176"
RUSH_CITY_CITY = "56266"
RUSHFORD_VILLAGE_CITY = "56302"
RUSHFORD_CITY = "56284"
RUSHMORE_CITY = "56338"
RUSSELL_CITY = "56428"
RUTHTON_CITY = "56482"
RUTLEDGE_CITY = "56518"
SABIN_CITY = "56554"
SACRED_HEART_CITY = "56572"
SANBORN_CITY = "58306"
SANDSTONE_CITY = "58396"
SARGEANT_CITY = "58576"
SARTELL_CITY = "58612"
SAUK_CENTRE_CITY = "58648"
SAUK_RAPIDS_CITY = "58684"
SAVAGE_CITY = "58738"
SCANDIA_CITY = "58900"
SCANLON_CITY = "58936"
SEAFORTH_CITY = "59098"
SEARLES_CDP = "59116"
SEBEKA_CITY = "59152"
SEDAN_CITY = "59188"
SHAFER_CITY = "59314"
SHAKOPEE_CITY = "59350"
SHELLY_CITY = "59566"
SHERBURN_CITY = "59620"
SHEVLIN_CITY = "59782"
SHOREVIEW_CITY = "59998"
SHOREWOOD_CITY = "60016"
SILVER_BAY_CITY = "60250"
SILVER_CREEK_CDP = "60322"
SILVER_LAKE_CITY = "60376"
SKYLINE_CITY = "60754"
SLAYTON_CITY = "60808"
SLEEPY_EYE_CITY = "60844"
SOBIESKI_CITY = "61006"
SOLWAY_CITY = "61114"
SOUDAN_CDP = "61204"
SOUTH_END_CDP = "61340"
SOUTH_HAVEN_CITY = "61402"
SOUTH_ST_PAUL_CITY = "61492"
SPICER_CITY = "61690"
SPRING_GROVE_CITY = "61852"
SPRING_HILL_CITY = "61888"
SPRING_LAKE_PARK_CITY = "61996"
SPRING_PARK_CITY = "62014"
SPRING_VALLEY_CITY = "62104"
SPRINGFIELD_CITY = "61816"
SQUAW_LAKE_CITY = "62284"
ST_ANTHONY_CITY_HENNEPIN_AND_RAMSEY_COUNTIES = "56680"
ST_ANTHONY_CITY_STEARNS_COUNTY = "56698"
ST_AUGUSTA_CITY = "56724"
ST_BONIFACIUS_CITY = "56770"
ST_CHARLES_CITY = "56788"
ST_CLAIR_CITY = "56824"
ST_CLOUD_CITY = "56896"
ST_FRANCIS_CITY = "56950"
ST_HILAIRE_CITY = "57022"
ST_JAMES_CITY = "57040"
ST_JOHNS_UNIVERSITY_CDP = "57094"
ST_JOSEPH_CITY = "57130"
ST_LEO_CITY = "57202"
ST_LOUIS_PARK_CITY = "57220"
ST_MARTIN_CITY = "57238"
ST_MARYS_POINT_CITY = "57292"
ST_MICHAEL_CITY = "57346"
ST_PAUL_PARK_CITY = "58018"
ST_PAUL_CITY = "58000"
ST_PETER_CITY = "58036"
ST_ROSA_CITY = "58072"
ST_STEPHEN_CITY = "58090"
ST_VINCENT_CITY = "58144"
STACY_CITY = "62320"
STANCHFIELD_CDP = "62356"
STAPLES_CITY = "62446"
STARBUCK_CITY = "62500"
STEEN_CITY = "62662"
STEPHEN_CITY = "62698"
STEWART_CITY = "62788"
STEWARTVILLE_CITY = "62806"
STILLWATER_CITY = "62824"
STOCKTON_CITY = "62896"
STORDEN_CITY = "63022"
STRANDQUIST_CITY = "63112"
STRATHCONA_CITY = "63130"
STURGEON_LAKE_CITY = "63220"
SUNBURG_CITY = "63454"
SUNFISH_LAKE_CITY = "63544"
SWANVILLE_CITY = "63778"
TACONITE_CITY = "64048"
TAMARACK_CITY = "64156"
TAOPI_CITY = "64210"
TAUNTON_CITY = "64264"
TAYLORS_FALLS_CITY = "64318"
TENSTRIKE_CITY = "64444"
THE_LAKES_CDP = "64543"
THE_RANCH_CDP = "64547"
THIEF_RIVER_FALLS_CITY = "64570"
TINTAH_CITY = "64948"
TONKA_BAY_CITY = "65164"
TOWER_CITY = "65272"
TRACY_CITY = "65308"
TRAIL_CITY = "65344"
TRIMONT_CITY = "65470"
TROMMALD_CITY = "65506"
TROSKY_CITY = "65542"
TRUMAN_CITY = "65668"
TURTLE_RIVER_CITY = "65794"
TWIN_LAKES_CDP = "65927"
TWIN_LAKES_CITY = "65920"
TWIN_VALLEY_CITY = "65938"
TWO_HARBORS_CITY = "65956"
TYLER_CITY = "66046"
ULEN_CITY = "66136"
UNDERWOOD_CITY = "66172"
UPSALA_CITY = "66334"
URBANK_CITY = "66388"
UTICA_CITY = "66424"
VADNAIS_HEIGHTS_CITY = "66460"
VERGAS_CITY = "66766"
VERMILLION_CITY = "66802"
VERNDALE_CITY = "66874"
VERNON_CENTER_CITY = "66910"
VESTA_CITY = "66982"
VICTORIA_CITY = "67036"
VIKING_CITY = "67090"
VILLARD_CITY = "67144"
VINELAND_CDP = "67180"
VINING_CITY = "67216"
VIRGINIA_CITY = "67288"
WABASHA_CITY = "67378"
WABASSO_CITY = "67396"
WACONIA_CITY = "67432"
WADENA_CITY = "67504"
WAHKON_CITY = "67558"
WAITE_PARK_CITY = "67612"
WALDORF_CITY = "67756"
WALKER_CITY = "67792"
WALNUT_GROVE_CITY = "67846"
WALTERS_CITY = "67900"
WALTHAM_CITY = "67918"
WANAMINGO_CITY = "67972"
WANDA_CITY = "68008"
WARBA_CITY = "68080"
WARREN_CITY = "68170"
WARROAD_CITY = "68224"
WARSAW_CDP = "68260"
WASECA_CITY = "68296"
WATERTOWN_CITY = "68548"
WATERVILLE_CITY = "68584"
WATKINS_CITY = "68620"
WATSON_CITY = "68656"
WAUBUN_CITY = "68674"
WAVERLY_CITY = "68764"
WAYZATA_CITY = "68818"
WELCOME_CITY = "69070"
WELLS_CITY = "69106"
WENDELL_CITY = "69142"
WEST_CONCORD_CITY = "69304"
WEST_ROY_LAKE_CDP = "69690"
WEST_ST_PAUL_CITY = "69700"
WEST_UNION_CITY = "69736"
WESTBROOK_CITY = "69250"
WESTPORT_CITY = "69628"
WHALAN_CITY = "69808"
WHEATON_CITY = "69844"
WHIPHOLT_CDP = "69880"
WHITE_BEAR_LAKE_CITY = "69970"
WHITE_EARTH_CDP = "70006"
WILDER_CITY = "70258"
WILLERNIE_CITY = "70366"
WILLIAMS_CITY = "70402"
WILLMAR_CITY = "70420"
WILLOW_RIVER_CITY = "70492"
WILMONT_CITY = "70582"
WILTON_CITY = "70708"
WINDOM_CITY = "70798"
WINGER_CITY = "70870"
WINNEBAGO_CITY = "70924"
WINONA_CITY = "71032"
WINSTED_CITY = "71086"
WINTHROP_CITY = "71122"
WINTON_CITY = "71140"
WOLF_LAKE_CITY = "71338"
WOLVERTON_CITY = "71392"
WOOD_LAKE_CITY = "71446"
WOODBURY_CITY = "71428"
WOODLAND_CITY = "71500"
WOODSTOCK_CITY = "71680"
WORTHINGTON_CITY = "71734"
WRENSHALL_CITY = "71788"
WRIGHT_CITY = "71824"
WYKOFF_CITY = "71950"
WYOMING_CITY = "72022"
ZEMPLE_CITY = "72184"
ZIMMERMAN_CITY = "72238"
ZUMBRO_FALLS_CITY = "72310"
ZUMBROTA_CITY = "72328"
