# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Hawaii."""


AHUIMANU_CDP = "00400"
AIEA_CDP = "00550"
AINALOA_CDP = "01085"
ANAHOLA_CDP = "02200"
BLACK_SANDS_CDP = "02832"
CAPTAIN_COOK_CDP = "03850"
DISCOVERY_HARBOUR_CDP = "05900"
EAST_HONOLULU_CDP = "06290"
EAST_KAPOLEI_CDP = "06300"
EDEN_ROC_CDP = "06325"
ELEELE_CDP = "07000"
EWA_BEACH_CDP = "07450"
EWA_GENTRY_CDP = "07470"
EWA_VILLAGES_CDP = "07485"
FERN_ACRES_CDP = "07542"
FERN_FOREST_CDP = "07675"
HAENA_CDP = "08950"
HAIKU_PAUWELA_CDP = "09260"
HALAULA_CDP = "09700"
HALAWA_CDP = "10000"
HALEIWA_CDP = "10750"
HALIIMAILE_CDP = "10900"
HANA_CDP = "11350"
HANALEI_CDP = "11500"
HANAMAULU_CDP = "11650"
HANAPEPE_CDP = "11800"
HAUULA_CDP = "12400"
HAWAIIAN_ACRES_CDP = "12450"
HAWAIIAN_BEACHES_CDP = "12500"
HAWAIIAN_OCEAN_VIEW_CDP = "12530"
HAWAIIAN_PARADISE_PARK_CDP = "12600"
HAWI_CDP = "13600"
HEEIA_CDP = "13900"
HELEMANO_CDP = "13970"
HICKAM_HOUSING_CDP = "14200"
HILO_CDP = "14650"
HOLUALOA_CDP = "15700"
HONALO_CDP = "16000"
HONAUNAU_NAPOOPOO_CDP = "16160"
HONOKAA_CDP = "16450"
HONOMU_CDP = "17450"
IROQUOIS_POINT_CDP = "19100"
KAAAWA_CDP = "19550"
KAANAPALI_CDP = "20000"
KAHALUU_CDP = "21200"
KAHALUU_KEAUHOU_CDP = "21230"
KAHUKU_CDP = "22250"
KAHULUI_CDP = "22700"
KAILUA_CDP_HAWAII_COUNTY = "23000"
KAILUA_CDP_HONOLULU_COUNTY = "23150"
KAIMINANI_CDP = "23675"
KALAELOA_CDP = "24850"
KALAHEO_CDP = "24950"
KALAPANA_CDP = "25700"
KALIHIWAI_CDP = "26750"
KALOKO_CDP = "26867"
KAMAILI_CDP = "27350"
KANEOHE_BASE_CDP = "28287"
KANEOHE_CDP = "28250"
KAPAA_CDP = "28850"
KAPAAU_CDP = "29000"
KAPALUA_CDP = "29725"
KAPOLEI_CDP = "30300"
KAUMAKANI_CDP = "30650"
KAUNAKAKAI_CDP = "31100"
KAWELA_BAY_CDP = "32700"
KEAAU_CDP = "32900"
KEALAKEKUA_CDP = "33950"
KEKAHA_CDP = "35600"
KEOKEA_CDP = "36050"
KIHEI_CDP = "36500"
KILAUEA_CDP = "36650"
KO_OLINA_CDP = "39400"
KOLOA_CDP = "39200"
KUALAPUU_CDP = "39500"
KUKUIHAELE_CDP = "41000"
KULA_CDP = "41600"
KURTISTOWN_CDP = "42800"
LAHAINA_CDP = "42950"
LAIE_CDP = "43250"
LANAI_CITY_CDP = "43700"
LAUNIUPOKO_CDP = "44075"
LAUPAHOEHOE_CDP = "44150"
LAWAI_CDP = "44450"
LEILANI_ESTATES_CDP = "44562"
LIHUE_CDP = "45200"
MAALAEA_CDP = "46400"
MAHINAHINA_CDP = "47050"
MAILI_CDP = "47300"
MAKAHA_CDP = "47450"
MAKAHA_VALLEY_CDP = "47560"
MAKAKILO_CDP = "47600"
MAKAWAO_CDP = "48050"
MAKENA_CDP = "48350"
MANELE_CDP = "49425"
MAUNA_LOA_ESTATES_CDP = "50375"
MAUNALOA_CDP = "50150"
MAUNAWILI_CDP = "50750"
MILILANI_MAUKA_CDP = "51000"
MILILANI_TOWN_CDP = "51050"
MOKULEIA_CDP = "52550"
MOUNTAIN_VIEW_CDP = "53300"
NAALEHU_CDP = "53600"
NANAKULI_CDP = "53900"
NANAWALE_ESTATES_CDP = "53975"
NAPILI_HONOKOWAI_CDP = "54100"
OCEAN_POINTE_CDP = "56685"
OLINDA_CDP = "57350"
OLOWALU_CDP = "57650"
OMAO_CDP = "57800"
ORCHIDLANDS_ESTATES_CDP = "58775"
PAAUILO_CDP = "59300"
PAHALA_CDP = "59750"
PAHOA_CDP = "59900"
PAIA_CDP = "60200"
PAKALA_VILLAGE_CDP = "60350"
PAPAIKOU_CDP = "61550"
PAUKAA_CDP = "61700"
PEARL_CITY_CDP = "62600"
PEPEEKEO_CDP = "63650"
POIPU_CDP = "64550"
PRINCEVILLE_CDP = "65075"
PUAKO_CDP = "65150"
PUHI_CDP = "65750"
PUKALANI_CDP = "65900"
PUNALUU_CDP = "66500"
PUPUKEA_CDP = "66800"
ROYAL_HAWAIIAN_ESTATES_CDP = "68807"
ROYAL_KUNIA_CDP = "68815"
SCHOFIELD_BARRACKS_CDP = "69050"
SEAVIEW_CDP = "69238"
TIKI_GARDENS_CDP = "70280"
UALAPUE_CDP = "70700"
URBAN_HONOLULU_CDP = "71550"
VOLCANO_CDP = "72350"
VOLCANO_GOLF_COURSE_CDP = "72468"
WAHIAWA_CDP = "72650"
WAIAHOLE_WAIKANE_CDP = "72957"
WAIALUA_CDP = "74000"
WAIANAE_CDP = "74450"
WAIHEE_WAIEHU_CDP = "75510"
WAIKAPU_CDP = "75950"
WAIKELE_CDP = "76250"
WAIKOLOA_BEACH_RESORT_CDP = "76584"
WAIKOLOA_VILLAGE_CDP = "76600"
WAILEA_CDP = "76925"
WAILUA_CDP = "77000"
WAILUA_HOMESTEADS_CDP = "77225"
WAILUKU_CDP = "77450"
WAIMALU_CDP = "77750"
WAIMANALO_BEACH_CDP = "78200"
WAIMANALO_CDP = "78050"
WAIMEA_CDP_HAWAII_COUNTY = "78500"
WAIMEA_CDP_KAUAI_COUNTY = "78800"
WAINAKU_CDP = "78950"
WAINIHA_CDP = "79250"
WAIOHINU_CDP = "79550"
WAIPAHU_CDP = "79700"
WAIPIO_ACRES_CDP = "80000"
WAIPIO_CDP = "79860"
WEST_LOCH_ESTATE_CDP = "80470"
WHEELER_AFB_CDP = "80600"
WHITMORE_VILLAGE_CDP = "80900"
