# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Ohio."""


ADAMS = "001"
ALLEN = "003"
ASHLAND = "005"
ASHTABULA = "007"
ATHENS = "009"
AUGLAIZE = "011"
BELMONT = "013"
BROWN = "015"
BUTLER = "017"
CARROLL = "019"
CHAMPAIGN = "021"
CLARK = "023"
CLERMONT = "025"
CLINTON = "027"
COLUMBIANA = "029"
COSHOCTON = "031"
CRAWFORD = "033"
CUYAHOGA = "035"
DARKE = "037"
DEFIANCE = "039"
DELAWARE = "041"
ERIE = "043"
FAIRFIELD = "045"
FAYETTE = "047"
FRANKLIN = "049"
FULTON = "051"
GALLIA = "053"
GEAUGA = "055"
GREENE = "057"
GUERNSEY = "059"
HAMILTON = "061"
HANCOCK = "063"
HARDIN = "065"
HARRISON = "067"
HENRY = "069"
HIGHLAND = "071"
HOCKING = "073"
HOLMES = "075"
HURON = "077"
JACKSON = "079"
JEFFERSON = "081"
KNOX = "083"
LAKE = "085"
LAWRENCE = "087"
LICKING = "089"
LOGAN = "091"
LORAIN = "093"
LUCAS = "095"
MADISON = "097"
MAHONING = "099"
MARION = "101"
MEDINA = "103"
MEIGS = "105"
MERCER = "107"
MIAMI = "109"
MONROE = "111"
MONTGOMERY = "113"
MORGAN = "115"
MORROW = "117"
MUSKINGUM = "119"
NOBLE = "121"
OTTAWA = "123"
PAULDING = "125"
PERRY = "127"
PICKAWAY = "129"
PIKE = "131"
PORTAGE = "133"
PREBLE = "135"
PUTNAM = "137"
RICHLAND = "139"
ROSS = "141"
SANDUSKY = "143"
SCIOTO = "145"
SENECA = "147"
SHELBY = "149"
STARK = "151"
SUMMIT = "153"
TRUMBULL = "155"
TUSCARAWAS = "157"
UNION = "159"
VAN_WERT = "161"
VINTON = "163"
WARREN = "165"
WASHINGTON = "167"
WAYNE = "169"
WILLIAMS = "171"
WOOD = "173"
WYANDOT = "175"
